c
c======================================================================
c VP_HLMNT_v1_3nonr (version 1.3, no narrow resonances, 10 Mar 2010)
c======================================================================
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
c changes by Henryk Czyz (9 July 2010):
c  1) 'main' program taken out
c  2) li3 function taken out. The program uses now dli3 from Fred Jegerlehner's
c     vacpol. It was checked that both functions are numerically identical
c     up to a numerical noise.
c
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
c
c Fortran Code for the hadronic and leptonic vacuum polarisation 
c  in the space- and time-like region;
c   - hadronic contributions based on the compilation of the hadronic 
c     cross section as used for g-2 and \Delta\alpha(M_Z^2) by HLMNT
c      (K Hagiwara, R Liao, A D Martin, D Nomura, T Teubner)
c   - subroutines coded by Daisuke Nomura, wrapper by Thomas Teubner
c
c ---------------------------------------------------------------------
c NOTE: This version does not contain the hadronic contributions from 
c       the narrow resonances J/psi, psi', Upsilon(1-6S). 
c !!!!! In applications they have to be added separately by the user!
c ---------------------------------------------------------------------
c
c References: 
c  [1] K Hagiwara et al., Phys. Rev. D 69 (2004) 093003
c  [2] K Hagiwara et al., Phys. Lett. B 649 (2007) 173-179
c  [3] S Actis et al., arXiv:0912.0749, to appear in Eur. Phys. J C
c  see also: [4] T Teubner, AIP Conf. Proc. 1078 (2008) 102-107
c  
c Daisuke Nomura and Thomas Teubner, 10 March 2010.
c E-mail: thomas.teubner@liverpool.ac.uk
c         dnomura@post.kek.jp
c
c======================================================================
c
c Description: 
c
c  This self contained package of Fortran subroutines provides the real
c  and imaginary part of the hadronic and leptonic vacuum polarisation 
c  of the photon for both space- and time-like momentum squared q^2.
c     The leptonic contributions are evaluated from the well-known 
c  analytic expressions up to next-to-leading order (NLO) in alpha and 
c  also include the NNLO contributions as a mass expansion as published
c  in M Steinhauser, Phys. Lett. B 429 (1998) 158. (See [3] for further 
c  References.)
c     The hadronic contributions are based on the compilation of data 
c  for e+e- -> hadrons as used by HLMNT for the prediction of g-2. 
c  Data are supplemented by chiral perturbation theory at thresholds 
c  and iso-spin relations for channels not constrained by data; above 
c  11.09 GeV perturbative QCD is used, see [1] for details. 
c  The data input is as of [2]; in addition we have used KLOE data in 
c  the 2pi channel (Phys. Lett. B670 (2009) 285-291) and recent data 
c  from BES (Phys. Rev. Lett. 97 (2006) 262001) and CLEO (Phys. Rev. 
c  D 76 (2007) 072008).
c  The routines below for the real and imaginary part of the vacuum 
c  polarisation perform an interpolation on a suitably chosen grid 
c  provided in the routines.
c  Note: The errors given for the hadronic imaginary part stem from the
c  diagonal elements of the full covariance matrices of the chi^2_{min} 
c  fits of the data compilation in the contributing hadronic channels, 
c  so should be taken only as indicative or for display purposes. For a 
c  complete error analysis the full covariance matrices are needed.
c  As usual the hadronic contributions are the five-flavour 
c  contributions. For completeness the tiny top quark corrections to 
c  \Delta\alpha(q^2) are given by the perturbative LO plus NLO results  
c  for both space- and time-like q^2. These contributions are e.g. 
c  needed for the complete \Delta\alpha(M_Z^2).
c
c Usage of subroutine vphlmntv1nonr (9 real*8 parameters):
c  input: (1) energy in GeV
c  output: real part of the 5-flavour hadronic vacuum polarisation (VP) 
c          in the (2) space- and (3) time-like, (4) imaginary part of 
c          the 5-flavour hadronic VP, real part of the leptonic VP in 
c          the (5) space- and (6) time-like, (7) imaginary part of 
c          leptonic VP, top quark contribution to \Delta\alpha in the 
c          (8) space- and (9) time-like.
c          
c The normalisation of the vacuum polarisation function \Pi is such
c that  \alpha(q^2) = \alpha/(1-\Delta\alpha(q^2)) = 
c                     \alpha/(1-\Re\Pi(q^2)) .
c
c The energy ranges where the hadronic contributions are tabulated are 
c  0.01 ... 100 GeV for \Delta\alpha and
c  0.326 ... 100 GeV for R_had.
c Outside these ranges a zero result is returned for the real and 
c imaginary parts of the vacuum polarisation, and ERROR warnings are 
c given.
c
c======================================================================
c
c
c
ctt
c Subroutine vphlmntv1nonr to obtain all contributions (real and imaginary 
c  part of the five-flavour hadronic and the leptonic contributions, real 
c  part of the top quark contribution, real parts for space- and time-like 
c  momentum) with one single call, using for the individual contributions:
c      subroutine d_alpha_nores
c     &       ( w_input, a_sp_out, da_sp_out, a_tm_out, da_tm_out )
c      subroutine r_intpl( w_input, r_out, dr_out )
c      real*8 function alf_lep(gen_lep, s)
c      real*8 function R_lepton( s )
c      real*8 function alf_top( s )
ctt
      subroutine vphlmntv1nonr(energy, 
     & vprehadsp,vprehadtm,vpimhad,vprelepsp,vpreleptm,vpimlep,
     & vpretopsp,vpretoptm)
      implicit NONE
      real*8 w_input, a_sp_out, da_sp_out, a_tm_out, da_tm_out,
     &       r_out, dr_out, s,
     &       vprehadsp, vprehadtm, vpimhad,
     &       vprelepsp, vpreleptm, vpimlep,
     &       vpretopsp, vpretoptm, alpha, energy, pi,
     &       alf_lep, R_lepton, alf_top
      integer gen_lep
      parameter (pi=3.141592653589793238d0, 
     &           alpha=1.d0/137.035999710d0)
      external alf_lep, R_lepton, alf_top
c
      w_input=energy
c
c Time- and space-like \Delta\alpha_{had}^{(5)} = Re\Pi_{had}^{(5)}
      call d_alpha_nores
     &       ( w_input, a_sp_out, da_sp_out, a_tm_out, da_tm_out )
      vprehadsp=alpha*a_sp_out
      vprehadtm=alpha*a_tm_out
c
c Routines for imaginary parts give R_had and R_lep.
c Our normalisation for the VP includes the factor -e^2, 
c  hence \Pi =- 4\pi\alpha/(12\pi) R.
c
c Im\Pi_{had}^{(5)}
      call r_intpl( w_input, r_out, dr_out )
      vpimhad=-alpha/3.d0*r_out
c
      s=energy**2
c Time-like \Delta\alpha_{lep}^{(5)} = Re\Pi_{lep}^{(5)}
      vpreleptm=alf_lep(1,s)+alf_lep(2,s)+alf_lep(3,s)
c Im\Pi_{lep}^{(5)}
      vpimlep=-alpha/3.d0*R_lepton(s)
c Time-like \Delta\alpha_{top} = Re\Pi_{top}
      vpretoptm=alf_top(s)
c
      s=-energy**2
c Space-like \Delta\alpha_{lep}^{(5)} = Re\Pi_{lep}^{(5)}
      vprelepsp=alf_lep(1,s)+alf_lep(2,s)+alf_lep(3,s)
c Space-like \Delta\alpha_{top} = Re\Pi_{top}
      vpretopsp=alf_top(s)
c
      return
c
      end
c
c
ctt
c Routine for \Delta\alpha_{had}^{(5)}/alpha w/out narrow resonances
ctt
      subroutine d_alpha_nores
     &       ( w_input, a_sp_out, da_sp_out, a_tm_out, da_tm_out )
      implicit NONE
C
C Version prepared by Daisuke Nomura, 28 Jan 2010.
C
cccc5cccc0ccccccccc0ccccccccc0ccccccccc0ccccccccc0ccccccccc0
c
c Returns the value of Delta alpha_{had, 5-fl}(q^2)
c (WITHOUT NARROW RESONANCES) and its uncertainty
c for space- and time-like q^2 by interpolation
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c tmp vars -------------------------------------------------
      integer IMAX, i
      Parameter( IMAX = 1542 )
c explicit input var. --------------------------------------
      real*8 w_input
c output var. ----------------------------------------------
      real*8 a_sp_out, da_sp_out, a_tm_out, da_tm_out
c input as data blocks -------------------------------------
      real*8 w(IMAX), a_sp(IMAX), da_sp(IMAX),a_tm(IMAX), da_tm(IMAX)
c data -----------------------------------------------------

      data  ( w(i), i=   1,  95) /
     & 0.100010d-1, 0.200010d-1, 0.300010d-1, 0.400010d-1, 0.500010d-1,
     & 0.600010d-1, 0.700010d-1, 0.800010d-1, 0.900010d-1, 0.100001d0,
     & 0.110001d0, 0.120001d0, 0.130001d0, 0.140001d0, 0.150001d0,
     & 0.160001d0, 0.170001d0, 0.180001d0, 0.190001d0, 0.200001d0,
     & 0.210001d0, 0.220001d0, 0.230001d0, 0.240001d0, 0.250001d0,
     & 0.260001d0, 0.270001d0, 0.288651d0, 0.307301d0, 0.325951d0,
     & 0.344601d0, 0.363251d0, 0.381901d0, 0.400551d0, 0.419201d0,
     & 0.437851d0, 0.456501d0, 0.475151d0, 0.493801d0, 0.512451d0,
     & 0.531101d0, 0.549751d0, 0.568401d0, 0.587051d0, 0.605701d0,
     & 0.610701d0, 0.615701d0, 0.620701d0, 0.625701d0, 0.630701d0,
     & 0.635701d0, 0.640701d0, 0.645701d0, 0.650701d0, 0.655701d0,
     & 0.660701d0, 0.665701d0, 0.670701d0, 0.675701d0, 0.680701d0,
     & 0.685701d0, 0.690701d0, 0.695701d0, 0.700701d0, 0.705701d0,
     & 0.710701d0, 0.715701d0, 0.720701d0, 0.725701d0, 0.730701d0,
     & 0.735701d0, 0.740701d0, 0.745701d0, 0.750701d0, 0.752701d0,
     & 0.754701d0, 0.756701d0, 0.758701d0, 0.760701d0, 0.762701d0,
     & 0.764701d0, 0.766701d0, 0.768701d0, 0.770701d0, 0.771101d0,
     & 0.771501d0, 0.771901d0, 0.772301d0, 0.772701d0, 0.773101d0,
     & 0.773501d0, 0.773901d0, 0.774301d0, 0.774701d0, 0.775101d0/

      data ( w(i), i=  96, 190) /
     & 0.775501d0, 0.775901d0, 0.776301d0, 0.776701d0, 0.777101d0,
     & 0.777501d0, 0.777901d0, 0.778301d0, 0.778746d0, 0.779146d0,
     & 0.779546d0, 0.780036d0, 0.780436d0, 0.780836d0, 0.781236d0,
     & 0.781636d0, 0.782081d0, 0.782481d0, 0.782926d0, 0.783326d0,
     & 0.783726d0, 0.784126d0, 0.784526d0, 0.784926d0, 0.785326d0,
     & 0.785726d0, 0.786126d0, 0.786526d0, 0.786926d0, 0.787326d0,
     & 0.787726d0, 0.788126d0, 0.788526d0, 0.788926d0, 0.789326d0,
     & 0.789726d0, 0.790126d0, 0.790626d0, 0.791126d0, 0.791626d0,
     & 0.792126d0, 0.792626d0, 0.793126d0, 0.793626d0, 0.794126d0,
     & 0.794626d0, 0.795126d0, 0.796126d0, 0.797126d0, 0.798126d0,
     & 0.799126d0, 0.800126d0, 0.801126d0, 0.802126d0, 0.803126d0,
     & 0.804126d0, 0.805126d0, 0.806126d0, 0.807126d0, 0.808126d0,
     & 0.809126d0, 0.810126d0, 0.811126d0, 0.812126d0, 0.813126d0,
     & 0.814126d0, 0.815126d0, 0.816126d0, 0.817126d0, 0.818126d0,
     & 0.819126d0, 0.820126d0, 0.822126d0, 0.824126d0, 0.826126d0,
     & 0.828126d0, 0.830126d0, 0.832126d0, 0.834126d0, 0.836126d0,
     & 0.838126d0, 0.840126d0, 0.842126d0, 0.844126d0, 0.846126d0,
     & 0.848126d0, 0.850126d0, 0.852126d0, 0.854126d0, 0.856126d0,
     & 0.858126d0, 0.860126d0, 0.862126d0, 0.864126d0, 0.866126d0/

      data ( w(i), i= 191, 285) /
     & 0.868126d0, 0.870126d0, 0.872126d0, 0.874126d0, 0.876126d0,
     & 0.878126d0, 0.880126d0, 0.882126d0, 0.884126d0, 0.886126d0,
     & 0.888126d0, 0.890126d0, 0.892126d0, 0.894126d0, 0.896126d0,
     & 0.898126d0, 0.900126d0, 0.902126d0, 0.904126d0, 0.906126d0,
     & 0.908126d0, 0.910126d0, 0.912126d0, 0.914126d0, 0.916126d0,
     & 0.918126d0, 0.920126d0, 0.924126d0, 0.928126d0, 0.932126d0,
     & 0.936126d0, 0.940126d0, 0.944126d0, 0.948126d0, 0.952126d0,
     & 0.956126d0, 0.960126d0, 0.964126d0, 0.968126d0, 0.972126d0,
     & 0.976126d0, 0.980126d0, 0.984126d0, 0.988126d0, 0.992126d0,
     & 0.996126d0, 0.100013d1, 0.100413d1, 0.100813d1, 0.101213d1,
     & 0.101263d1, 0.101313d1, 0.101363d1, 0.101413d1, 0.101463d1,
     & 0.101513d1, 0.101563d1, 0.101613d1, 0.101663d1, 0.101713d1,
     & 0.101763d1, 0.101813d1, 0.101867d1, 0.101917d1, 0.101967d1,
     & 0.102017d1, 0.102072d1, 0.102122d1, 0.102172d1, 0.102222d1,
     & 0.102272d1, 0.102322d1, 0.102372d1, 0.102422d1, 0.102472d1,
     & 0.102522d1, 0.102572d1, 0.102622d1, 0.102697d1, 0.102772d1,
     & 0.103772d1, 0.104772d1, 0.105772d1, 0.106772d1, 0.107772d1,
     & 0.108772d1, 0.109772d1, 0.110772d1, 0.111772d1, 0.112772d1,
     & 0.113772d1, 0.114772d1, 0.115772d1, 0.116772d1, 0.117772d1/

      data ( w(i), i= 286, 380) /
     & 0.118772d1, 0.119772d1, 0.120772d1, 0.121772d1, 0.122772d1,
     & 0.123772d1, 0.124772d1, 0.125772d1, 0.126772d1, 0.127772d1,
     & 0.128772d1, 0.129772d1, 0.130772d1, 0.131772d1, 0.132772d1,
     & 0.133772d1, 0.134772d1, 0.135772d1, 0.136772d1, 0.137772d1,
     & 0.138772d1, 0.139772d1, 0.140772d1, 0.141772d1, 0.142772d1,
     & 0.143772d1, 0.144772d1, 0.145772d1, 0.146772d1, 0.147772d1,
     & 0.148772d1, 0.149772d1, 0.150772d1, 0.151772d1, 0.152772d1,
     & 0.153772d1, 0.154772d1, 0.155772d1, 0.156772d1, 0.157772d1,
     & 0.158772d1, 0.159772d1, 0.160772d1, 0.161772d1, 0.162772d1,
     & 0.163772d1, 0.164772d1, 0.165772d1, 0.166772d1, 0.167772d1,
     & 0.168772d1, 0.169772d1, 0.170772d1, 0.171772d1, 0.172772d1,
     & 0.173772d1, 0.174772d1, 0.175772d1, 0.176772d1, 0.177772d1,
     & 0.178772d1, 0.179772d1, 0.180772d1, 0.181772d1, 0.182772d1,
     & 0.183772d1, 0.184772d1, 0.185772d1, 0.186772d1, 0.187772d1,
     & 0.188772d1, 0.189772d1, 0.190772d1, 0.191772d1, 0.192772d1,
     & 0.193772d1, 0.194772d1, 0.195772d1, 0.196772d1, 0.197772d1,
     & 0.198772d1, 0.199772d1, 0.200772d1, 0.202772d1, 0.204772d1,
     & 0.206772d1, 0.208772d1, 0.210772d1, 0.215772d1, 0.220772d1,
     & 0.225772d1, 0.230772d1, 0.235772d1, 0.240772d1, 0.245772d1/

      data ( w(i), i= 381, 475) /
     & 0.250772d1, 0.255772d1, 0.260772d1, 0.265772d1, 0.270772d1,
     & 0.275772d1, 0.280772d1, 0.285772d1, 0.290772d1, 0.295772d1,
     & 0.300772d1, 0.300972d1, 0.301172d1, 0.301372d1, 0.301572d1,
     & 0.301772d1, 0.301972d1, 0.302172d1, 0.302372d1, 0.302572d1,
     & 0.302772d1, 0.302972d1, 0.303172d1, 0.303372d1, 0.303572d1,
     & 0.303772d1, 0.303972d1, 0.304172d1, 0.304372d1, 0.304572d1,
     & 0.304772d1, 0.304972d1, 0.305172d1, 0.305372d1, 0.305572d1,
     & 0.305772d1, 0.305972d1, 0.306172d1, 0.306372d1, 0.306572d1,
     & 0.306772d1, 0.306972d1, 0.307172d1, 0.307222d1, 0.307272d1,
     & 0.307322d1, 0.307372d1, 0.307422d1, 0.307472d1, 0.307522d1,
     & 0.307572d1, 0.307622d1, 0.307672d1, 0.307722d1, 0.307772d1,
     & 0.307822d1, 0.307872d1, 0.307922d1, 0.307972d1, 0.308022d1,
     & 0.308072d1, 0.308122d1, 0.308172d1, 0.308222d1, 0.308272d1,
     & 0.308322d1, 0.308372d1, 0.308422d1, 0.308472d1, 0.308522d1,
     & 0.308572d1, 0.308622d1, 0.308672d1, 0.308722d1, 0.308772d1,
     & 0.308822d1, 0.308872d1, 0.308922d1, 0.308972d1, 0.309022d1,
     & 0.309072d1, 0.309122d1, 0.309172d1, 0.309222d1, 0.309272d1,
     & 0.309322d1, 0.309372d1, 0.309422d1, 0.309447d1, 0.309472d1,
     & 0.309497d1, 0.309522d1, 0.309547d1, 0.309572d1, 0.309597d1/

      data ( w(i), i= 476, 570) /
     & 0.309622d1, 0.309632d1, 0.309642d1, 0.309652d1, 0.309668d1,
     & 0.309673d1, 0.309678d1, 0.309682d1, 0.309687d1, 0.309689d1,
     & 0.309692d1, 0.309694d1, 0.309696d1, 0.309701d1, 0.309711d1,
     & 0.309721d1, 0.309731d1, 0.309741d1, 0.309751d1, 0.309761d1,
     & 0.309771d1, 0.309781d1, 0.309791d1, 0.309801d1, 0.309826d1,
     & 0.309851d1, 0.309876d1, 0.309901d1, 0.309926d1, 0.309951d1,
     & 0.309976d1, 0.310001d1, 0.310051d1, 0.310101d1, 0.310151d1,
     & 0.310201d1, 0.310251d1, 0.310301d1, 0.310351d1, 0.310401d1,
     & 0.310451d1, 0.310501d1, 0.310551d1, 0.310601d1, 0.310651d1,
     & 0.310701d1, 0.310751d1, 0.310801d1, 0.310851d1, 0.310901d1,
     & 0.310951d1, 0.311001d1, 0.311051d1, 0.311101d1, 0.311151d1,
     & 0.311201d1, 0.311251d1, 0.311301d1, 0.311351d1, 0.311401d1,
     & 0.311451d1, 0.311501d1, 0.311551d1, 0.311601d1, 0.311651d1,
     & 0.311701d1, 0.311751d1, 0.311801d1, 0.311851d1, 0.311901d1,
     & 0.311951d1, 0.312001d1, 0.312101d1, 0.312201d1, 0.312301d1,
     & 0.312401d1, 0.312501d1, 0.312601d1, 0.312701d1, 0.312801d1,
     & 0.312901d1, 0.313001d1, 0.313101d1, 0.313201d1, 0.313301d1,
     & 0.313401d1, 0.313501d1, 0.313601d1, 0.313701d1, 0.313801d1,
     & 0.313901d1, 0.314001d1, 0.314101d1, 0.314201d1, 0.314301d1/

      data ( w(i), i= 571, 665) /
     & 0.314401d1, 0.314501d1, 0.314601d1, 0.314701d1, 0.314801d1,
     & 0.314901d1, 0.315001d1, 0.315101d1, 0.315201d1, 0.315301d1,
     & 0.315401d1, 0.315501d1, 0.315601d1, 0.315701d1, 0.315801d1,
     & 0.315901d1, 0.316001d1, 0.316101d1, 0.316201d1, 0.316301d1,
     & 0.316401d1, 0.316501d1, 0.316601d1, 0.316701d1, 0.316801d1,
     & 0.316901d1, 0.317001d1, 0.317101d1, 0.317201d1, 0.317301d1,
     & 0.317401d1, 0.317501d1, 0.317601d1, 0.317701d1, 0.317801d1,
     & 0.317901d1, 0.318001d1, 0.318101d1, 0.318201d1, 0.318301d1,
     & 0.318401d1, 0.318501d1, 0.318601d1, 0.318701d1, 0.318801d1,
     & 0.318901d1, 0.319001d1, 0.319101d1, 0.319201d1, 0.319301d1,
     & 0.319401d1, 0.319501d1, 0.319601d1, 0.319701d1, 0.319801d1,
     & 0.319901d1, 0.320051d1, 0.321051d1, 0.322051d1, 0.323051d1,
     & 0.324051d1, 0.325051d1, 0.326051d1, 0.327051d1, 0.328051d1,
     & 0.329051d1, 0.330051d1, 0.331051d1, 0.332051d1, 0.333051d1,
     & 0.334051d1, 0.335051d1, 0.336051d1, 0.337051d1, 0.338051d1,
     & 0.339051d1, 0.340051d1, 0.342051d1, 0.344051d1, 0.346051d1,
     & 0.348051d1, 0.350051d1, 0.352051d1, 0.354051d1, 0.356051d1,
     & 0.358051d1, 0.360051d1, 0.360551d1, 0.361051d1, 0.361551d1,
     & 0.362051d1, 0.362551d1, 0.363051d1, 0.363551d1, 0.364051d1/

      data ( w(i), i= 666, 760) /
     & 0.364551d1, 0.365051d1, 0.365551d1, 0.366051d1, 0.366551d1,
     & 0.367051d1, 0.367551d1, 0.367651d1, 0.367751d1, 0.367851d1,
     & 0.367951d1, 0.368051d1, 0.368151d1, 0.368251d1, 0.368351d1,
     & 0.368451d1, 0.368551d1, 0.368552d1, 0.368566d1, 0.368581d1,
     & 0.368595d1, 0.368602d1, 0.368609d1, 0.368616d1, 0.368624d1,
     & 0.368638d1, 0.368688d1, 0.368738d1, 0.368788d1, 0.368838d1,
     & 0.368938d1, 0.369038d1, 0.369138d1, 0.369238d1, 0.369338d1,
     & 0.369438d1, 0.369538d1, 0.369638d1, 0.369738d1, 0.369838d1,
     & 0.369938d1, 0.370038d1, 0.370138d1, 0.370238d1, 0.370338d1,
     & 0.370438d1, 0.370538d1, 0.370638d1, 0.370738d1, 0.370838d1,
     & 0.370938d1, 0.371038d1, 0.371538d1, 0.372038d1, 0.372538d1,
     & 0.373038d1, 0.373538d1, 0.374038d1, 0.374538d1, 0.375088d1,
     & 0.375588d1, 0.376088d1, 0.376588d1, 0.377088d1, 0.377588d1,
     & 0.378088d1, 0.378588d1, 0.379088d1, 0.379588d1, 0.380088d1,
     & 0.381088d1, 0.382088d1, 0.383088d1, 0.384088d1, 0.385088d1,
     & 0.386088d1, 0.387088d1, 0.388088d1, 0.389088d1, 0.390088d1,
     & 0.391088d1, 0.392088d1, 0.393088d1, 0.394088d1, 0.395088d1,
     & 0.396088d1, 0.397088d1, 0.398088d1, 0.399088d1, 0.400088d1,
     & 0.401088d1, 0.402088d1, 0.403088d1, 0.404088d1, 0.405088d1/

      data ( w(i), i= 761, 855) /
     & 0.406088d1, 0.407088d1, 0.408088d1, 0.409088d1, 0.410088d1,
     & 0.411088d1, 0.412088d1, 0.413088d1, 0.414088d1, 0.415088d1,
     & 0.416088d1, 0.417088d1, 0.418088d1, 0.419088d1, 0.420088d1,
     & 0.422088d1, 0.424088d1, 0.426088d1, 0.428088d1, 0.430088d1,
     & 0.432088d1, 0.434088d1, 0.436088d1, 0.438088d1, 0.440088d1,
     & 0.442088d1, 0.444088d1, 0.446088d1, 0.448088d1, 0.450088d1,
     & 0.452088d1, 0.454088d1, 0.456088d1, 0.458088d1, 0.460088d1,
     & 0.462088d1, 0.464088d1, 0.466088d1, 0.468088d1, 0.470088d1,
     & 0.472088d1, 0.474088d1, 0.476088d1, 0.478088d1, 0.480088d1,
     & 0.482088d1, 0.484088d1, 0.486088d1, 0.488088d1, 0.490088d1,
     & 0.492088d1, 0.494088d1, 0.496088d1, 0.498088d1, 0.500088d1,
     & 0.502088d1, 0.504088d1, 0.506088d1, 0.508088d1, 0.510088d1,
     & 0.512088d1, 0.514088d1, 0.516088d1, 0.518088d1, 0.520088d1,
     & 0.522088d1, 0.524088d1, 0.526088d1, 0.528088d1, 0.530088d1,
     & 0.532088d1, 0.534088d1, 0.536088d1, 0.538088d1, 0.540088d1,
     & 0.542088d1, 0.544088d1, 0.546088d1, 0.548088d1, 0.550088d1,
     & 0.552088d1, 0.554088d1, 0.556088d1, 0.558088d1, 0.560088d1,
     & 0.562088d1, 0.564088d1, 0.566088d1, 0.568088d1, 0.570088d1,
     & 0.574088d1, 0.578088d1, 0.582088d1, 0.586088d1, 0.590088d1/

      data ( w(i), i= 856, 950) /
     & 0.594088d1, 0.598088d1, 0.602088d1, 0.606088d1, 0.610088d1,
     & 0.614088d1, 0.618088d1, 0.622088d1, 0.626088d1, 0.630088d1,
     & 0.634088d1, 0.638088d1, 0.642088d1, 0.646088d1, 0.650088d1,
     & 0.654088d1, 0.658088d1, 0.662088d1, 0.666088d1, 0.670088d1,
     & 0.674088d1, 0.678088d1, 0.682088d1, 0.686088d1, 0.690088d1,
     & 0.692088d1, 0.694088d1, 0.696088d1, 0.698088d1, 0.700088d1,
     & 0.702088d1, 0.704088d1, 0.706088d1, 0.708088d1, 0.710088d1,
     & 0.712088d1, 0.714088d1, 0.716088d1, 0.718088d1, 0.720088d1,
     & 0.722088d1, 0.724088d1, 0.726088d1, 0.728088d1, 0.730088d1,
     & 0.732088d1, 0.734088d1, 0.736088d1, 0.738088d1, 0.740088d1,
     & 0.742088d1, 0.744088d1, 0.746088d1, 0.748088d1, 0.750088d1,
     & 0.752088d1, 0.754088d1, 0.756088d1, 0.758088d1, 0.760088d1,
     & 0.762088d1, 0.764088d1, 0.766088d1, 0.768088d1, 0.770088d1,
     & 0.772088d1, 0.774088d1, 0.776088d1, 0.778088d1, 0.780088d1,
     & 0.782088d1, 0.784088d1, 0.786088d1, 0.788088d1, 0.790088d1,
     & 0.792088d1, 0.794088d1, 0.796088d1, 0.798088d1, 0.800088d1,
     & 0.802088d1, 0.804088d1, 0.806088d1, 0.808088d1, 0.810088d1,
     & 0.812088d1, 0.814088d1, 0.816088d1, 0.818088d1, 0.820088d1,
     & 0.822088d1, 0.824088d1, 0.826088d1, 0.828088d1, 0.830088d1/

      data ( w(i), i= 951,1045) /
     & 0.832088d1, 0.834088d1, 0.836088d1, 0.838088d1, 0.840088d1,
     & 0.842088d1, 0.844088d1, 0.846088d1, 0.848088d1, 0.850088d1,
     & 0.852088d1, 0.854088d1, 0.856088d1, 0.858088d1, 0.860088d1,
     & 0.862088d1, 0.864088d1, 0.866088d1, 0.868088d1, 0.870088d1,
     & 0.872088d1, 0.874088d1, 0.876088d1, 0.878088d1, 0.880088d1,
     & 0.882088d1, 0.884088d1, 0.886088d1, 0.888088d1, 0.890088d1,
     & 0.892088d1, 0.894088d1, 0.896088d1, 0.898088d1, 0.900088d1,
     & 0.902088d1, 0.904088d1, 0.906088d1, 0.908088d1, 0.910088d1,
     & 0.912088d1, 0.914088d1, 0.916088d1, 0.918088d1, 0.920088d1,
     & 0.922088d1, 0.924088d1, 0.926088d1, 0.928088d1, 0.930088d1,
     & 0.932088d1, 0.934088d1, 0.936088d1, 0.938088d1, 0.940088d1,
     & 0.940338d1, 0.940588d1, 0.940838d1, 0.941088d1, 0.941338d1,
     & 0.941588d1, 0.941838d1, 0.942088d1, 0.942338d1, 0.942588d1,
     & 0.942838d1, 0.943088d1, 0.943338d1, 0.943588d1, 0.943838d1,
     & 0.944088d1, 0.944188d1, 0.944288d1, 0.944388d1, 0.944488d1,
     & 0.944588d1, 0.944688d1, 0.944788d1, 0.944888d1, 0.944988d1,
     & 0.945088d1, 0.945188d1, 0.945288d1, 0.945388d1, 0.945488d1,
     & 0.945588d1, 0.945688d1, 0.945738d1, 0.945788d1, 0.945838d1,
     & 0.945888d1, 0.945938d1, 0.945948d1, 0.945958d1, 0.945968d1/

      data ( w(i), i=1046,1140) /
     & 0.945978d1, 0.945988d1, 0.945998d1, 0.946008d1, 0.946016d1,
     & 0.946019d1, 0.946022d1, 0.946025d1, 0.946027d1, 0.946029d1,
     & 0.946030d1, 0.946031d1, 0.946033d1, 0.946035d1, 0.946045d1,
     & 0.946055d1, 0.946065d1, 0.946075d1, 0.946085d1, 0.946095d1,
     & 0.946105d1, 0.946130d1, 0.946155d1, 0.946180d1, 0.946205d1,
     & 0.946230d1, 0.946255d1, 0.946280d1, 0.946305d1, 0.946355d1,
     & 0.946405d1, 0.946455d1, 0.946505d1, 0.946555d1, 0.946605d1,
     & 0.946655d1, 0.946705d1, 0.946755d1, 0.946805d1, 0.946855d1,
     & 0.946905d1, 0.946955d1, 0.947005d1, 0.947055d1, 0.947105d1,
     & 0.947155d1, 0.947205d1, 0.947255d1, 0.947355d1, 0.947455d1,
     & 0.947555d1, 0.948055d1, 0.948555d1, 0.949055d1, 0.949555d1,
     & 0.950055d1, 0.950555d1, 0.951055d1, 0.951555d1, 0.952055d1,
     & 0.952555d1, 0.953055d1, 0.953555d1, 0.954055d1, 0.954555d1,
     & 0.955055d1, 0.955555d1, 0.956055d1, 0.956555d1, 0.957055d1,
     & 0.957555d1, 0.958055d1, 0.958555d1, 0.959055d1, 0.959555d1,
     & 0.960055d1, 0.960305d1, 0.960555d1, 0.960805d1, 0.961055d1,
     & 0.961305d1, 0.961555d1, 0.961805d1, 0.962055d1, 0.962305d1,
     & 0.962555d1, 0.962805d1, 0.963055d1, 0.963305d1, 0.963555d1,
     & 0.963805d1, 0.964055d1, 0.964305d1, 0.964555d1, 0.964805d1/

      data ( w(i), i=1141,1235) /
     & 0.965055d1, 0.965305d1, 0.965555d1, 0.965805d1, 0.966055d1,
     & 0.966305d1, 0.966555d1, 0.966805d1, 0.967055d1, 0.967305d1,
     & 0.967555d1, 0.967805d1, 0.968055d1, 0.968305d1, 0.968555d1,
     & 0.968805d1, 0.969055d1, 0.969305d1, 0.969555d1, 0.969805d1,
     & 0.970055d1, 0.970305d1, 0.970555d1, 0.970805d1, 0.971055d1,
     & 0.971305d1, 0.971555d1, 0.971805d1, 0.972055d1, 0.972305d1,
     & 0.972555d1, 0.972805d1, 0.973055d1, 0.973305d1, 0.973555d1,
     & 0.973805d1, 0.974055d1, 0.974305d1, 0.974555d1, 0.974805d1,
     & 0.975055d1, 0.975305d1, 0.975555d1, 0.975805d1, 0.976055d1,
     & 0.976305d1, 0.976555d1, 0.976805d1, 0.977055d1, 0.977305d1,
     & 0.977555d1, 0.977805d1, 0.978055d1, 0.978305d1, 0.978555d1,
     & 0.978805d1, 0.979055d1, 0.979305d1, 0.979555d1, 0.979805d1,
     & 0.980055d1, 0.980305d1, 0.980555d1, 0.980805d1, 0.981055d1,
     & 0.981305d1, 0.981555d1, 0.981805d1, 0.982055d1, 0.982305d1,
     & 0.982555d1, 0.982805d1, 0.983055d1, 0.983305d1, 0.983555d1,
     & 0.983805d1, 0.984055d1, 0.984305d1, 0.984555d1, 0.984805d1,
     & 0.985055d1, 0.985305d1, 0.985555d1, 0.985805d1, 0.986055d1,
     & 0.986305d1, 0.986555d1, 0.986805d1, 0.987055d1, 0.987305d1,
     & 0.987555d1, 0.987805d1, 0.988055d1, 0.988305d1, 0.988555d1/

      data ( w(i), i=1236,1330) /
     & 0.988805d1, 0.989055d1, 0.989305d1, 0.989555d1, 0.989805d1,
     & 0.990055d1, 0.990305d1, 0.990555d1, 0.990805d1, 0.991055d1,
     & 0.991305d1, 0.991555d1, 0.991805d1, 0.992055d1, 0.992305d1,
     & 0.992555d1, 0.992805d1, 0.993055d1, 0.993305d1, 0.993555d1,
     & 0.993805d1, 0.994055d1, 0.994305d1, 0.994555d1, 0.994805d1,
     & 0.995055d1, 0.995305d1, 0.995555d1, 0.995805d1, 0.996055d1,
     & 0.996305d1, 0.996555d1, 0.996805d1, 0.997055d1, 0.997305d1,
     & 0.997555d1, 0.997805d1, 0.998055d1, 0.998305d1, 0.998555d1,
     & 0.998805d1, 0.999055d1, 0.999305d1, 0.999555d1, 0.999805d1,
     & 0.100006d2, 0.100016d2, 0.100026d2, 0.100036d2, 0.100046d2,
     & 0.100056d2, 0.100066d2, 0.100076d2, 0.100086d2, 0.100096d2,
     & 0.100106d2, 0.100116d2, 0.100126d2, 0.100136d2, 0.100146d2,
     & 0.100156d2, 0.100161d2, 0.100166d2, 0.100171d2, 0.100176d2,
     & 0.100181d2, 0.100186d2, 0.100191d2, 0.100196d2, 0.100201d2,
     & 0.100206d2, 0.100211d2, 0.100216d2, 0.100221d2, 0.100222d2,
     & 0.100223d2, 0.100224d2, 0.100225d2, 0.100226d2, 0.100227d2,
     & 0.100228d2, 0.100229d2, 0.100230d2, 0.100231d2, 0.100232d2,
     & 0.100232d2, 0.100232d2, 0.100232d2, 0.100232d2, 0.100232d2,
     & 0.100233d2, 0.100233d2, 0.100233d2, 0.100233d2, 0.100233d2/

      data ( w(i), i=1331,1425) /
     & 0.100234d2, 0.100235d2, 0.100236d2, 0.100238d2, 0.100241d2,
     & 0.100246d2, 0.100251d2, 0.100261d2, 0.100271d2, 0.100281d2,
     & 0.100291d2, 0.100301d2, 0.100401d2, 0.100501d2, 0.100601d2,
     & 0.100701d2, 0.100801d2, 0.100901d2, 0.101001d2, 0.101101d2,
     & 0.101201d2, 0.101301d2, 0.101401d2, 0.101501d2, 0.101601d2,
     & 0.101701d2, 0.101801d2, 0.101901d2, 0.102001d2, 0.102101d2,
     & 0.102201d2, 0.102301d2, 0.102401d2, 0.102501d2, 0.102601d2,
     & 0.102701d2, 0.102801d2, 0.102901d2, 0.103001d2, 0.103021d2,
     & 0.103041d2, 0.103061d2, 0.103081d2, 0.103101d2, 0.103121d2,
     & 0.103141d2, 0.103161d2, 0.103181d2, 0.103201d2, 0.103221d2,
     & 0.103241d2, 0.103261d2, 0.103281d2, 0.103301d2, 0.103321d2,
     & 0.103341d2, 0.103361d2, 0.103381d2, 0.103401d2, 0.103421d2,
     & 0.103441d2, 0.103461d2, 0.103481d2, 0.103501d2, 0.103511d2,
     & 0.103521d2, 0.103526d2, 0.103531d2, 0.103536d2, 0.103541d2,
     & 0.103543d2, 0.103545d2, 0.103547d2, 0.103548d2, 0.103549d2,
     & 0.103550d2, 0.103551d2, 0.103551d2, 0.103552d2, 0.103552d2,
     & 0.103552d2, 0.103552d2, 0.103552d2, 0.103552d2, 0.103552d2,
     & 0.103552d2, 0.103552d2, 0.103553d2, 0.103554d2, 0.103555d2,
     & 0.103558d2, 0.103560d2, 0.103565d2, 0.103570d2, 0.103575d2/

      data ( w(i), i=1426,1520) /
     & 0.103580d2, 0.103590d2, 0.103600d2, 0.103625d2, 0.103650d2,
     & 0.103700d2, 0.103800d2, 0.103900d2, 0.104000d2, 0.104100d2,
     & 0.104200d2, 0.104300d2, 0.104400d2, 0.104500d2, 0.104600d2,
     & 0.104700d2, 0.104800d2, 0.104900d2, 0.105000d2, 0.105100d2,
     & 0.105200d2, 0.105300d2, 0.105400d2, 0.105500d2, 0.105600d2,
     & 0.105700d2, 0.105800d2, 0.105900d2, 0.106000d2, 0.106100d2,
     & 0.106200d2, 0.106300d2, 0.106400d2, 0.106500d2, 0.106600d2,
     & 0.106700d2, 0.106800d2, 0.106900d2, 0.107000d2, 0.107100d2,
     & 0.107200d2, 0.107300d2, 0.107400d2, 0.107500d2, 0.107600d2,
     & 0.107700d2, 0.107800d2, 0.107900d2, 0.108000d2, 0.108100d2,
     & 0.108200d2, 0.108300d2, 0.108400d2, 0.108500d2, 0.108600d2,
     & 0.108700d2, 0.108800d2, 0.108900d2, 0.109000d2, 0.109100d2,
     & 0.109200d2, 0.109300d2, 0.109400d2, 0.109500d2, 0.109600d2,
     & 0.109700d2, 0.109800d2, 0.109900d2, 0.110000d2, 0.110500d2,
     & 0.111000d2, 0.111500d2, 0.112000d2, 0.112500d2, 0.113000d2,
     & 0.113500d2, 0.114000d2, 0.114500d2, 0.115000d2, 0.116000d2,
     & 0.117000d2, 0.118000d2, 0.119000d2, 0.120000d2, 0.130000d2,
     & 0.140000d2, 0.150000d2, 0.160000d2, 0.170000d2, 0.180000d2,
     & 0.190000d2, 0.200000d2, 0.210000d2, 0.220000d2, 0.230000d2/

      data ( w(i), i=1521,1542) /
     & 0.240000d2, 0.250000d2, 0.260000d2, 0.270000d2, 0.280000d2,
     & 0.290000d2, 0.300000d2, 0.350000d2, 0.400000d2, 0.450000d2,
     & 0.500000d2, 0.550000d2, 0.600000d2, 0.650000d2, 0.700000d2,
     & 0.750000d2, 0.800000d2, 0.850000d2, 0.900000d2, 0.911876d2,
     & 0.950000d2, 0.100000d3/


      data  ( a_sp(i), i=   1,  95) /
     & 0.124000d-3, 0.494000d-3, 0.111100d-2, 0.197200d-2, 0.307600d-2,
     & 0.443000d-2, 0.601400d-2, 0.783100d-2, 0.987700d-2, 0.121480d-1,
     & 0.146380d-1, 0.173410d-1, 0.202520d-1, 0.233650d-1, 0.266740d-1,
     & 0.301710d-1, 0.338500d-1, 0.377040d-1, 0.417270d-1, 0.459110d-1,
     & 0.502480d-1, 0.547330d-1, 0.593570d-1, 0.641140d-1, 0.689960d-1,
     & 0.739970d-1, 0.791100d-1, 0.889210d-1, 0.990550d-1, 0.109471d0,
     & 0.120131d0, 0.130998d0, 0.142037d0, 0.153216d0, 0.164506d0,
     & 0.175879d0, 0.187309d0, 0.198774d0, 0.210252d0, 0.221725d0,
     & 0.233174d0, 0.244584d0, 0.255943d0, 0.267237d0, 0.278456d0,
     & 0.281449d0, 0.284437d0, 0.287418d0, 0.290392d0, 0.293360d0,
     & 0.296321d0, 0.299275d0, 0.302222d0, 0.305161d0, 0.308094d0,
     & 0.311019d0, 0.313936d0, 0.316845d0, 0.319747d0, 0.322641d0,
     & 0.325527d0, 0.328405d0, 0.331275d0, 0.334136d0, 0.336989d0,
     & 0.339834d0, 0.342671d0, 0.345499d0, 0.348318d0, 0.351129d0,
     & 0.353932d0, 0.356725d0, 0.359510d0, 0.362286d0, 0.363394d0,
     & 0.364501d0, 0.365606d0, 0.366710d0, 0.367812d0, 0.368913d0,
     & 0.370013d0, 0.371111d0, 0.372208d0, 0.373303d0, 0.373522d0,
     & 0.373740d0, 0.373959d0, 0.374178d0, 0.374397d0, 0.374615d0,
     & 0.374834d0, 0.375052d0, 0.375271d0, 0.375489d0, 0.375707d0/

      data ( a_sp(i), i=  96, 190) /
     & 0.375926d0, 0.376144d0, 0.376362d0, 0.376580d0, 0.376798d0,
     & 0.377016d0, 0.377234d0, 0.377452d0, 0.377694d0, 0.377912d0,
     & 0.378129d0, 0.378396d0, 0.378613d0, 0.378831d0, 0.379048d0,
     & 0.379266d0, 0.379508d0, 0.379725d0, 0.379966d0, 0.380184d0,
     & 0.380401d0, 0.380618d0, 0.380835d0, 0.381051d0, 0.381268d0,
     & 0.381485d0, 0.381702d0, 0.381918d0, 0.382135d0, 0.382352d0,
     & 0.382568d0, 0.382785d0, 0.383001d0, 0.383217d0, 0.383434d0,
     & 0.383650d0, 0.383866d0, 0.384136d0, 0.384406d0, 0.384676d0,
     & 0.384946d0, 0.385216d0, 0.385485d0, 0.385755d0, 0.386024d0,
     & 0.386294d0, 0.386563d0, 0.387101d0, 0.387639d0, 0.388177d0,
     & 0.388714d0, 0.389251d0, 0.389787d0, 0.390324d0, 0.390859d0,
     & 0.391395d0, 0.391930d0, 0.392465d0, 0.392999d0, 0.393533d0,
     & 0.394067d0, 0.394600d0, 0.395133d0, 0.395665d0, 0.396198d0,
     & 0.396729d0, 0.397261d0, 0.397792d0, 0.398323d0, 0.398853d0,
     & 0.399383d0, 0.399913d0, 0.400971d0, 0.402028d0, 0.403083d0,
     & 0.404137d0, 0.405190d0, 0.406241d0, 0.407290d0, 0.408338d0,
     & 0.409385d0, 0.410430d0, 0.411474d0, 0.412516d0, 0.413557d0,
     & 0.414596d0, 0.415634d0, 0.416671d0, 0.417706d0, 0.418740d0,
     & 0.419772d0, 0.420803d0, 0.421832d0, 0.422860d0, 0.423887d0/

      data ( a_sp(i), i= 191, 285) /
     & 0.424912d0, 0.425935d0, 0.426957d0, 0.427978d0, 0.428997d0,
     & 0.430015d0, 0.431032d0, 0.432047d0, 0.433060d0, 0.434072d0,
     & 0.435083d0, 0.436092d0, 0.437100d0, 0.438107d0, 0.439112d0,
     & 0.440115d0, 0.441117d0, 0.442118d0, 0.443117d0, 0.444115d0,
     & 0.445112d0, 0.446107d0, 0.447101d0, 0.448093d0, 0.449084d0,
     & 0.450073d0, 0.451061d0, 0.453033d0, 0.454999d0, 0.456960d0,
     & 0.458915d0, 0.460865d0, 0.462809d0, 0.464747d0, 0.466680d0,
     & 0.468608d0, 0.470530d0, 0.472446d0, 0.474357d0, 0.476263d0,
     & 0.478163d0, 0.480058d0, 0.481947d0, 0.483831d0, 0.485710d0,
     & 0.487583d0, 0.489451d0, 0.491314d0, 0.493172d0, 0.495024d0,
     & 0.495255d0, 0.495486d0, 0.495717d0, 0.495948d0, 0.496179d0,
     & 0.496410d0, 0.496640d0, 0.496871d0, 0.497101d0, 0.497332d0,
     & 0.497562d0, 0.497792d0, 0.498043d0, 0.498273d0, 0.498503d0,
     & 0.498733d0, 0.498984d0, 0.499214d0, 0.499443d0, 0.499673d0,
     & 0.499902d0, 0.500132d0, 0.500361d0, 0.500591d0, 0.500820d0,
     & 0.501049d0, 0.501278d0, 0.501507d0, 0.501850d0, 0.502193d0,
     & 0.506750d0, 0.511276d0, 0.515769d0, 0.520231d0, 0.524662d0,
     & 0.529063d0, 0.533433d0, 0.537772d0, 0.542082d0, 0.546363d0,
     & 0.550614d0, 0.554837d0, 0.559031d0, 0.563196d0, 0.567334d0/

      data ( a_sp(i), i= 286, 380) /
     & 0.571444d0, 0.575528d0, 0.579584d0, 0.583613d0, 0.587616d0,
     & 0.591593d0, 0.595545d0, 0.599471d0, 0.603372d0, 0.607248d0,
     & 0.611100d0, 0.614927d0, 0.618731d0, 0.622510d0, 0.626267d0,
     & 0.630000d0, 0.633711d0, 0.637399d0, 0.641065d0, 0.644709d0,
     & 0.648331d0, 0.651932d0, 0.655511d0, 0.659070d0, 0.662608d0,
     & 0.666126d0, 0.669623d0, 0.673100d0, 0.676558d0, 0.679996d0,
     & 0.683415d0, 0.686815d0, 0.690196d0, 0.693559d0, 0.696903d0,
     & 0.700229d0, 0.703537d0, 0.706828d0, 0.710101d0, 0.713357d0,
     & 0.716595d0, 0.719817d0, 0.723022d0, 0.726211d0, 0.729383d0,
     & 0.732539d0, 0.735679d0, 0.738804d0, 0.741913d0, 0.745006d0,
     & 0.748085d0, 0.751148d0, 0.754196d0, 0.757230d0, 0.760249d0,
     & 0.763254d0, 0.766244d0, 0.769221d0, 0.772183d0, 0.775132d0,
     & 0.778067d0, 0.780989d0, 0.783897d0, 0.786793d0, 0.789675d0,
     & 0.792544d0, 0.795401d0, 0.798245d0, 0.801076d0, 0.803895d0,
     & 0.806702d0, 0.809496d0, 0.812279d0, 0.815050d0, 0.817809d0,
     & 0.820557d0, 0.823293d0, 0.826017d0, 0.828731d0, 0.831433d0,
     & 0.834124d0, 0.836804d0, 0.839474d0, 0.844781d0, 0.850046d0,
     & 0.855269d0, 0.860452d0, 0.865596d0, 0.878286d0, 0.890743d0,
     & 0.902979d0, 0.915002d0, 0.926822d0, 0.938447d0, 0.949884d0/

      data ( a_sp(i), i= 381, 475) /
     & 0.961142d0, 0.972227d0, 0.983146d0, 0.993904d0, 0.100451d1,
     & 0.101496d1, 0.102527d1, 0.103544d1, 0.104548d1, 0.105539d1,
     & 0.106517d1, 0.106556d1, 0.106594d1, 0.106633d1, 0.106672d1,
     & 0.106711d1, 0.106750d1, 0.106788d1, 0.106827d1, 0.106866d1,
     & 0.106905d1, 0.106943d1, 0.106982d1, 0.107021d1, 0.107059d1,
     & 0.107098d1, 0.107136d1, 0.107175d1, 0.107213d1, 0.107252d1,
     & 0.107290d1, 0.107329d1, 0.107367d1, 0.107406d1, 0.107444d1,
     & 0.107483d1, 0.107521d1, 0.107559d1, 0.107598d1, 0.107636d1,
     & 0.107674d1, 0.107713d1, 0.107751d1, 0.107760d1, 0.107770d1,
     & 0.107780d1, 0.107789d1, 0.107799d1, 0.107808d1, 0.107818d1,
     & 0.107827d1, 0.107837d1, 0.107846d1, 0.107856d1, 0.107865d1,
     & 0.107875d1, 0.107885d1, 0.107894d1, 0.107904d1, 0.107913d1,
     & 0.107923d1, 0.107932d1, 0.107942d1, 0.107951d1, 0.107961d1,
     & 0.107970d1, 0.107980d1, 0.107990d1, 0.107999d1, 0.108009d1,
     & 0.108018d1, 0.108028d1, 0.108037d1, 0.108047d1, 0.108056d1,
     & 0.108066d1, 0.108075d1, 0.108085d1, 0.108094d1, 0.108104d1,
     & 0.108113d1, 0.108123d1, 0.108133d1, 0.108142d1, 0.108152d1,
     & 0.108161d1, 0.108170d1, 0.108180d1, 0.108185d1, 0.108190d1,
     & 0.108194d1, 0.108199d1, 0.108204d1, 0.108209d1, 0.108213d1/

      data ( a_sp(i), i= 476, 570) /
     & 0.108218d1, 0.108220d1, 0.108222d1, 0.108224d1, 0.108227d1,
     & 0.108228d1, 0.108229d1, 0.108230d1, 0.108231d1, 0.108231d1,
     & 0.108231d1, 0.108232d1, 0.108232d1, 0.108233d1, 0.108235d1,
     & 0.108237d1, 0.108239d1, 0.108241d1, 0.108243d1, 0.108245d1,
     & 0.108247d1, 0.108248d1, 0.108250d1, 0.108252d1, 0.108257d1,
     & 0.108262d1, 0.108266d1, 0.108271d1, 0.108276d1, 0.108281d1,
     & 0.108285d1, 0.108290d1, 0.108300d1, 0.108309d1, 0.108319d1,
     & 0.108328d1, 0.108338d1, 0.108347d1, 0.108357d1, 0.108366d1,
     & 0.108376d1, 0.108385d1, 0.108395d1, 0.108404d1, 0.108414d1,
     & 0.108423d1, 0.108432d1, 0.108442d1, 0.108451d1, 0.108461d1,
     & 0.108471d1, 0.108480d1, 0.108489d1, 0.108499d1, 0.108508d1,
     & 0.108518d1, 0.108527d1, 0.108537d1, 0.108546d1, 0.108556d1,
     & 0.108565d1, 0.108575d1, 0.108584d1, 0.108594d1, 0.108603d1,
     & 0.108613d1, 0.108622d1, 0.108631d1, 0.108641d1, 0.108650d1,
     & 0.108660d1, 0.108669d1, 0.108688d1, 0.108707d1, 0.108726d1,
     & 0.108745d1, 0.108764d1, 0.108783d1, 0.108801d1, 0.108820d1,
     & 0.108839d1, 0.108858d1, 0.108877d1, 0.108896d1, 0.108915d1,
     & 0.108933d1, 0.108952d1, 0.108971d1, 0.108990d1, 0.109009d1,
     & 0.109028d1, 0.109046d1, 0.109065d1, 0.109084d1, 0.109103d1/

      data ( a_sp(i), i= 571, 665) /
     & 0.109122d1, 0.109140d1, 0.109159d1, 0.109178d1, 0.109197d1,
     & 0.109215d1, 0.109234d1, 0.109253d1, 0.109272d1, 0.109291d1,
     & 0.109309d1, 0.109328d1, 0.109347d1, 0.109366d1, 0.109384d1,
     & 0.109403d1, 0.109422d1, 0.109441d1, 0.109459d1, 0.109478d1,
     & 0.109497d1, 0.109515d1, 0.109534d1, 0.109553d1, 0.109571d1,
     & 0.109590d1, 0.109609d1, 0.109628d1, 0.109646d1, 0.109665d1,
     & 0.109684d1, 0.109702d1, 0.109721d1, 0.109739d1, 0.109758d1,
     & 0.109777d1, 0.109795d1, 0.109814d1, 0.109833d1, 0.109851d1,
     & 0.109870d1, 0.109888d1, 0.109907d1, 0.109926d1, 0.109944d1,
     & 0.109963d1, 0.109981d1, 0.110000d1, 0.110019d1, 0.110037d1,
     & 0.110056d1, 0.110074d1, 0.110093d1, 0.110112d1, 0.110130d1,
     & 0.110149d1, 0.110177d1, 0.110362d1, 0.110546d1, 0.110731d1,
     & 0.110915d1, 0.111098d1, 0.111281d1, 0.111464d1, 0.111646d1,
     & 0.111828d1, 0.112010d1, 0.112190d1, 0.112371d1, 0.112551d1,
     & 0.112731d1, 0.112910d1, 0.113089d1, 0.113268d1, 0.113446d1,
     & 0.113624d1, 0.113801d1, 0.114155d1, 0.114507d1, 0.114857d1,
     & 0.115206d1, 0.115554d1, 0.115899d1, 0.116244d1, 0.116587d1,
     & 0.116929d1, 0.117269d1, 0.117353d1, 0.117438d1, 0.117523d1,
     & 0.117607d1, 0.117692d1, 0.117776d1, 0.117861d1, 0.117945d1/

      data ( a_sp(i), i= 666, 760) /
     & 0.118029d1, 0.118113d1, 0.118197d1, 0.118281d1, 0.118364d1,
     & 0.118448d1, 0.118532d1, 0.118548d1, 0.118565d1, 0.118582d1,
     & 0.118599d1, 0.118615d1, 0.118632d1, 0.118649d1, 0.118665d1,
     & 0.118682d1, 0.118699d1, 0.118699d1, 0.118701d1, 0.118704d1,
     & 0.118706d1, 0.118707d1, 0.118708d1, 0.118710d1, 0.118711d1,
     & 0.118713d1, 0.118721d1, 0.118730d1, 0.118738d1, 0.118746d1,
     & 0.118763d1, 0.118780d1, 0.118796d1, 0.118813d1, 0.118830d1,
     & 0.118846d1, 0.118863d1, 0.118880d1, 0.118896d1, 0.118913d1,
     & 0.118930d1, 0.118946d1, 0.118963d1, 0.118979d1, 0.118996d1,
     & 0.119013d1, 0.119029d1, 0.119046d1, 0.119063d1, 0.119079d1,
     & 0.119096d1, 0.119112d1, 0.119195d1, 0.119278d1, 0.119361d1,
     & 0.119443d1, 0.119526d1, 0.119609d1, 0.119691d1, 0.119782d1,
     & 0.119864d1, 0.119946d1, 0.120028d1, 0.120110d1, 0.120192d1,
     & 0.120274d1, 0.120355d1, 0.120437d1, 0.120519d1, 0.120600d1,
     & 0.120763d1, 0.120925d1, 0.121088d1, 0.121249d1, 0.121411d1,
     & 0.121572d1, 0.121733d1, 0.121894d1, 0.122054d1, 0.122214d1,
     & 0.122373d1, 0.122533d1, 0.122692d1, 0.122850d1, 0.123009d1,
     & 0.123167d1, 0.123324d1, 0.123482d1, 0.123639d1, 0.123796d1,
     & 0.123953d1, 0.124109d1, 0.124265d1, 0.124421d1, 0.124576d1/

      data ( a_sp(i), i= 761, 855) /
     & 0.124731d1, 0.124886d1, 0.125041d1, 0.125195d1, 0.125349d1,
     & 0.125503d1, 0.125656d1, 0.125809d1, 0.125962d1, 0.126115d1,
     & 0.126267d1, 0.126419d1, 0.126571d1, 0.126722d1, 0.126873d1,
     & 0.127175d1, 0.127476d1, 0.127775d1, 0.128073d1, 0.128371d1,
     & 0.128667d1, 0.128962d1, 0.129256d1, 0.129549d1, 0.129841d1,
     & 0.130133d1, 0.130423d1, 0.130712d1, 0.131000d1, 0.131287d1,
     & 0.131573d1, 0.131858d1, 0.132143d1, 0.132426d1, 0.132708d1,
     & 0.132990d1, 0.133270d1, 0.133550d1, 0.133828d1, 0.134106d1,
     & 0.134383d1, 0.134659d1, 0.134934d1, 0.135208d1, 0.135481d1,
     & 0.135753d1, 0.136025d1, 0.136296d1, 0.136565d1, 0.136834d1,
     & 0.137102d1, 0.137370d1, 0.137636d1, 0.137902d1, 0.138166d1,
     & 0.138430d1, 0.138693d1, 0.138956d1, 0.139217d1, 0.139478d1,
     & 0.139738d1, 0.139997d1, 0.140255d1, 0.140513d1, 0.140769d1,
     & 0.141025d1, 0.141281d1, 0.141535d1, 0.141789d1, 0.142042d1,
     & 0.142294d1, 0.142545d1, 0.142796d1, 0.143046d1, 0.143295d1,
     & 0.143544d1, 0.143792d1, 0.144039d1, 0.144285d1, 0.144531d1,
     & 0.144776d1, 0.145020d1, 0.145264d1, 0.145507d1, 0.145749d1,
     & 0.145990d1, 0.146231d1, 0.146471d1, 0.146711d1, 0.146950d1,
     & 0.147426d1, 0.147898d1, 0.148369d1, 0.148837d1, 0.149302d1/

      data ( a_sp(i), i= 856, 950) /
     & 0.149765d1, 0.150225d1, 0.150683d1, 0.151139d1, 0.151592d1,
     & 0.152042d1, 0.152491d1, 0.152937d1, 0.153381d1, 0.153822d1,
     & 0.154261d1, 0.154698d1, 0.155133d1, 0.155565d1, 0.155996d1,
     & 0.156424d1, 0.156850d1, 0.157274d1, 0.157696d1, 0.158116d1,
     & 0.158533d1, 0.158949d1, 0.159363d1, 0.159775d1, 0.160184d1,
     & 0.160389d1, 0.160592d1, 0.160795d1, 0.160998d1, 0.161200d1,
     & 0.161402d1, 0.161603d1, 0.161804d1, 0.162005d1, 0.162204d1,
     & 0.162404d1, 0.162603d1, 0.162801d1, 0.162999d1, 0.163197d1,
     & 0.163394d1, 0.163591d1, 0.163787d1, 0.163983d1, 0.164178d1,
     & 0.164373d1, 0.164567d1, 0.164762d1, 0.164955d1, 0.165148d1,
     & 0.165341d1, 0.165533d1, 0.165725d1, 0.165917d1, 0.166108d1,
     & 0.166298d1, 0.166488d1, 0.166678d1, 0.166867d1, 0.167056d1,
     & 0.167244d1, 0.167433d1, 0.167620d1, 0.167807d1, 0.167994d1,
     & 0.168181d1, 0.168367d1, 0.168552d1, 0.168738d1, 0.168922d1,
     & 0.169107d1, 0.169291d1, 0.169474d1, 0.169658d1, 0.169840d1,
     & 0.170023d1, 0.170205d1, 0.170387d1, 0.170568d1, 0.170749d1,
     & 0.170930d1, 0.171110d1, 0.171289d1, 0.171469d1, 0.171648d1,
     & 0.171826d1, 0.172005d1, 0.172183d1, 0.172360d1, 0.172537d1,
     & 0.172714d1, 0.172891d1, 0.173067d1, 0.173242d1, 0.173418d1/

      data ( a_sp(i), i= 951,1045) /
     & 0.173593d1, 0.173767d1, 0.173942d1, 0.174116d1, 0.174289d1,
     & 0.174462d1, 0.174635d1, 0.174808d1, 0.174980d1, 0.175152d1,
     & 0.175323d1, 0.175494d1, 0.175665d1, 0.175836d1, 0.176006d1,
     & 0.176176d1, 0.176345d1, 0.176514d1, 0.176683d1, 0.176852d1,
     & 0.177020d1, 0.177187d1, 0.177355d1, 0.177522d1, 0.177689d1,
     & 0.177855d1, 0.178022d1, 0.178187d1, 0.178353d1, 0.178518d1,
     & 0.178683d1, 0.178848d1, 0.179012d1, 0.179176d1, 0.179339d1,
     & 0.179503d1, 0.179666d1, 0.179828d1, 0.179991d1, 0.180153d1,
     & 0.180315d1, 0.180476d1, 0.180637d1, 0.180798d1, 0.180959d1,
     & 0.181119d1, 0.181279d1, 0.181438d1, 0.181598d1, 0.181757d1,
     & 0.181916d1, 0.182074d1, 0.182232d1, 0.182390d1, 0.182548d1,
     & 0.182567d1, 0.182587d1, 0.182607d1, 0.182626d1, 0.182646d1,
     & 0.182666d1, 0.182685d1, 0.182705d1, 0.182725d1, 0.182744d1,
     & 0.182764d1, 0.182784d1, 0.182803d1, 0.182823d1, 0.182842d1,
     & 0.182862d1, 0.182870d1, 0.182878d1, 0.182885d1, 0.182893d1,
     & 0.182901d1, 0.182909d1, 0.182917d1, 0.182925d1, 0.182933d1,
     & 0.182940d1, 0.182948d1, 0.182956d1, 0.182964d1, 0.182972d1,
     & 0.182980d1, 0.182987d1, 0.182991d1, 0.182995d1, 0.182999d1,
     & 0.183003d1, 0.183007d1, 0.183008d1, 0.183009d1, 0.183009d1/

      data ( a_sp(i), i=1046,1140) /
     & 0.183010d1, 0.183011d1, 0.183012d1, 0.183013d1, 0.183013d1,
     & 0.183013d1, 0.183014d1, 0.183014d1, 0.183014d1, 0.183014d1,
     & 0.183014d1, 0.183014d1, 0.183014d1, 0.183015d1, 0.183015d1,
     & 0.183016d1, 0.183017d1, 0.183018d1, 0.183018d1, 0.183019d1,
     & 0.183020d1, 0.183022d1, 0.183024d1, 0.183026d1, 0.183028d1,
     & 0.183030d1, 0.183032d1, 0.183034d1, 0.183036d1, 0.183040d1,
     & 0.183044d1, 0.183048d1, 0.183051d1, 0.183055d1, 0.183059d1,
     & 0.183063d1, 0.183067d1, 0.183071d1, 0.183075d1, 0.183079d1,
     & 0.183083d1, 0.183087d1, 0.183091d1, 0.183094d1, 0.183098d1,
     & 0.183102d1, 0.183106d1, 0.183110d1, 0.183118d1, 0.183126d1,
     & 0.183133d1, 0.183173d1, 0.183212d1, 0.183251d1, 0.183290d1,
     & 0.183329d1, 0.183368d1, 0.183407d1, 0.183446d1, 0.183485d1,
     & 0.183524d1, 0.183563d1, 0.183601d1, 0.183640d1, 0.183679d1,
     & 0.183718d1, 0.183757d1, 0.183796d1, 0.183834d1, 0.183873d1,
     & 0.183912d1, 0.183950d1, 0.183989d1, 0.184028d1, 0.184067d1,
     & 0.184105d1, 0.184125d1, 0.184144d1, 0.184163d1, 0.184183d1,
     & 0.184202d1, 0.184221d1, 0.184241d1, 0.184260d1, 0.184279d1,
     & 0.184298d1, 0.184318d1, 0.184337d1, 0.184356d1, 0.184375d1,
     & 0.184395d1, 0.184414d1, 0.184433d1, 0.184452d1, 0.184472d1/

      data ( a_sp(i), i=1141,1235) /
     & 0.184491d1, 0.184510d1, 0.184529d1, 0.184549d1, 0.184568d1,
     & 0.184587d1, 0.184606d1, 0.184625d1, 0.184645d1, 0.184664d1,
     & 0.184683d1, 0.184702d1, 0.184721d1, 0.184741d1, 0.184760d1,
     & 0.184779d1, 0.184798d1, 0.184817d1, 0.184837d1, 0.184856d1,
     & 0.184875d1, 0.184894d1, 0.184913d1, 0.184932d1, 0.184951d1,
     & 0.184970d1, 0.184990d1, 0.185009d1, 0.185028d1, 0.185047d1,
     & 0.185066d1, 0.185085d1, 0.185104d1, 0.185123d1, 0.185143d1,
     & 0.185162d1, 0.185181d1, 0.185200d1, 0.185219d1, 0.185238d1,
     & 0.185257d1, 0.185276d1, 0.185295d1, 0.185314d1, 0.185333d1,
     & 0.185352d1, 0.185371d1, 0.185390d1, 0.185409d1, 0.185428d1,
     & 0.185447d1, 0.185466d1, 0.185485d1, 0.185505d1, 0.185523d1,
     & 0.185543d1, 0.185562d1, 0.185580d1, 0.185600d1, 0.185618d1,
     & 0.185637d1, 0.185656d1, 0.185675d1, 0.185694d1, 0.185713d1,
     & 0.185732d1, 0.185751d1, 0.185770d1, 0.185789d1, 0.185808d1,
     & 0.185827d1, 0.185846d1, 0.185865d1, 0.185884d1, 0.185903d1,
     & 0.185922d1, 0.185941d1, 0.185960d1, 0.185978d1, 0.185997d1,
     & 0.186016d1, 0.186035d1, 0.186054d1, 0.186073d1, 0.186092d1,
     & 0.186111d1, 0.186129d1, 0.186148d1, 0.186167d1, 0.186186d1,
     & 0.186205d1, 0.186224d1, 0.186243d1, 0.186261d1, 0.186280d1/

      data ( a_sp(i), i=1236,1330) /
     & 0.186299d1, 0.186318d1, 0.186337d1, 0.186356d1, 0.186374d1,
     & 0.186393d1, 0.186412d1, 0.186431d1, 0.186450d1, 0.186468d1,
     & 0.186487d1, 0.186506d1, 0.186525d1, 0.186544d1, 0.186563d1,
     & 0.186581d1, 0.186600d1, 0.186619d1, 0.186637d1, 0.186656d1,
     & 0.186675d1, 0.186694d1, 0.186712d1, 0.186731d1, 0.186750d1,
     & 0.186769d1, 0.186787d1, 0.186806d1, 0.186825d1, 0.186844d1,
     & 0.186862d1, 0.186881d1, 0.186900d1, 0.186919d1, 0.186937d1,
     & 0.186956d1, 0.186974d1, 0.186993d1, 0.187012d1, 0.187031d1,
     & 0.187049d1, 0.187068d1, 0.187087d1, 0.187105d1, 0.187124d1,
     & 0.187143d1, 0.187150d1, 0.187157d1, 0.187165d1, 0.187172d1,
     & 0.187180d1, 0.187187d1, 0.187195d1, 0.187202d1, 0.187210d1,
     & 0.187217d1, 0.187225d1, 0.187232d1, 0.187240d1, 0.187247d1,
     & 0.187254d1, 0.187258d1, 0.187262d1, 0.187266d1, 0.187269d1,
     & 0.187273d1, 0.187277d1, 0.187280d1, 0.187284d1, 0.187288d1,
     & 0.187292d1, 0.187295d1, 0.187299d1, 0.187303d1, 0.187304d1,
     & 0.187304d1, 0.187305d1, 0.187306d1, 0.187306d1, 0.187307d1,
     & 0.187308d1, 0.187309d1, 0.187309d1, 0.187310d1, 0.187311d1,
     & 0.187311d1, 0.187311d1, 0.187311d1, 0.187312d1, 0.187312d1,
     & 0.187312d1, 0.187312d1, 0.187312d1, 0.187312d1, 0.187312d1/

      data ( a_sp(i), i=1331,1425) /
     & 0.187313d1, 0.187313d1, 0.187314d1, 0.187316d1, 0.187318d1,
     & 0.187322d1, 0.187325d1, 0.187333d1, 0.187340d1, 0.187348d1,
     & 0.187355d1, 0.187363d1, 0.187437d1, 0.187511d1, 0.187586d1,
     & 0.187660d1, 0.187734d1, 0.187808d1, 0.187882d1, 0.187956d1,
     & 0.188030d1, 0.188103d1, 0.188177d1, 0.188251d1, 0.188324d1,
     & 0.188398d1, 0.188471d1, 0.188545d1, 0.188618d1, 0.188691d1,
     & 0.188765d1, 0.188838d1, 0.188911d1, 0.188984d1, 0.189057d1,
     & 0.189130d1, 0.189203d1, 0.189275d1, 0.189348d1, 0.189363d1,
     & 0.189377d1, 0.189392d1, 0.189406d1, 0.189421d1, 0.189435d1,
     & 0.189450d1, 0.189464d1, 0.189479d1, 0.189494d1, 0.189508d1,
     & 0.189522d1, 0.189537d1, 0.189552d1, 0.189566d1, 0.189580d1,
     & 0.189595d1, 0.189610d1, 0.189624d1, 0.189638d1, 0.189653d1,
     & 0.189668d1, 0.189682d1, 0.189696d1, 0.189711d1, 0.189718d1,
     & 0.189725d1, 0.189729d1, 0.189733d1, 0.189736d1, 0.189740d1,
     & 0.189741d1, 0.189743d1, 0.189744d1, 0.189745d1, 0.189746d1,
     & 0.189746d1, 0.189747d1, 0.189748d1, 0.189748d1, 0.189748d1,
     & 0.189748d1, 0.189748d1, 0.189748d1, 0.189748d1, 0.189748d1,
     & 0.189748d1, 0.189748d1, 0.189749d1, 0.189749d1, 0.189750d1,
     & 0.189752d1, 0.189754d1, 0.189757d1, 0.189761d1, 0.189765d1/

      data ( a_sp(i), i=1426,1520) /
     & 0.189768d1, 0.189776d1, 0.189783d1, 0.189801d1, 0.189819d1,
     & 0.189855d1, 0.189927d1, 0.189999d1, 0.190071d1, 0.190144d1,
     & 0.190216d1, 0.190288d1, 0.190359d1, 0.190431d1, 0.190503d1,
     & 0.190575d1, 0.190646d1, 0.190718d1, 0.190789d1, 0.190861d1,
     & 0.190932d1, 0.191003d1, 0.191075d1, 0.191146d1, 0.191217d1,
     & 0.191288d1, 0.191359d1, 0.191430d1, 0.191501d1, 0.191572d1,
     & 0.191643d1, 0.191713d1, 0.191784d1, 0.191855d1, 0.191925d1,
     & 0.191996d1, 0.192066d1, 0.192137d1, 0.192207d1, 0.192277d1,
     & 0.192347d1, 0.192417d1, 0.192488d1, 0.192558d1, 0.192628d1,
     & 0.192698d1, 0.192767d1, 0.192837d1, 0.192907d1, 0.192977d1,
     & 0.193046d1, 0.193116d1, 0.193185d1, 0.193255d1, 0.193324d1,
     & 0.193393d1, 0.193463d1, 0.193532d1, 0.193601d1, 0.193670d1,
     & 0.193739d1, 0.193809d1, 0.193877d1, 0.193946d1, 0.194015d1,
     & 0.194084d1, 0.194153d1, 0.194221d1, 0.194290d1, 0.194632d1,
     & 0.194973d1, 0.195313d1, 0.195651d1, 0.195988d1, 0.196323d1,
     & 0.196657d1, 0.196990d1, 0.197322d1, 0.197652d1, 0.198309d1,
     & 0.198961d1, 0.199608d1, 0.200250d1, 0.200887d1, 0.207008d1,
     & 0.212715d1, 0.218062d1, 0.223089d1, 0.227833d1, 0.232322d1,
     & 0.236583d1, 0.240636d1, 0.244502d1, 0.248196d1, 0.251732d1/

      data ( a_sp(i), i=1521,1542) /
     & 0.255124d1, 0.258382d1, 0.261516d1, 0.264536d1, 0.267449d1,
     & 0.270262d1, 0.272982d1, 0.285375d1, 0.296134d1, 0.305637d1,
     & 0.314145d1, 0.321845d1, 0.328877d1, 0.335346d1, 0.341336d1,
     & 0.346912d1, 0.352128d1, 0.357027d1, 0.361645d1, 0.362704d1,
     & 0.366013d1, 0.370156d1/


      data  ( da_sp(i), i=   1,  95) /
     & 0.800000d-6, 0.320000d-5, 0.710000d-5, 0.127000d-4, 0.198000d-4,
     & 0.284000d-4, 0.386000d-4, 0.503000d-4, 0.635000d-4, 0.782000d-4,
     & 0.942000d-4, 0.111800d-3, 0.130600d-3, 0.150900d-3, 0.172400d-3,
     & 0.195300d-3, 0.219400d-3, 0.244700d-3, 0.271200d-3, 0.298900d-3,
     & 0.327700d-3, 0.357600d-3, 0.388500d-3, 0.420500d-3, 0.453400d-3,
     & 0.487300d-3, 0.522100d-3, 0.589400d-3, 0.659500d-3, 0.732400d-3,
     & 0.807900d-3, 0.885700d-3, 0.965700d-3, 0.104770d-2, 0.113160d-2,
     & 0.121730d-2, 0.130470d-2, 0.139350d-2, 0.148380d-2, 0.157530d-2,
     & 0.166800d-2, 0.176170d-2, 0.185650d-2, 0.195210d-2, 0.204860d-2,
     & 0.207460d-2, 0.210060d-2, 0.212670d-2, 0.215280d-2, 0.217900d-2,
     & 0.220530d-2, 0.223150d-2, 0.225790d-2, 0.228420d-2, 0.231060d-2,
     & 0.233710d-2, 0.236350d-2, 0.239000d-2, 0.241660d-2, 0.244320d-2,
     & 0.246980d-2, 0.249640d-2, 0.252310d-2, 0.254980d-2, 0.257650d-2,
     & 0.260330d-2, 0.263010d-2, 0.265690d-2, 0.268370d-2, 0.271060d-2,
     & 0.273750d-2, 0.276440d-2, 0.279130d-2, 0.281820d-2, 0.282900d-2,
     & 0.283980d-2, 0.285060d-2, 0.286130d-2, 0.287210d-2, 0.288290d-2,
     & 0.289370d-2, 0.290450d-2, 0.291530d-2, 0.292610d-2, 0.292830d-2,
     & 0.293040d-2, 0.293260d-2, 0.293470d-2, 0.293690d-2, 0.293910d-2,
     & 0.294120d-2, 0.294340d-2, 0.294550d-2, 0.294770d-2, 0.294990d-2/

      data ( da_sp(i), i=  96, 190) /
     & 0.295200d-2, 0.295420d-2, 0.295640d-2, 0.295850d-2, 0.296070d-2,
     & 0.296280d-2, 0.296500d-2, 0.296720d-2, 0.296960d-2, 0.297170d-2,
     & 0.297390d-2, 0.297650d-2, 0.297870d-2, 0.298090d-2, 0.298300d-2,
     & 0.298520d-2, 0.298760d-2, 0.298980d-2, 0.299220d-2, 0.299430d-2,
     & 0.299650d-2, 0.299860d-2, 0.300080d-2, 0.300300d-2, 0.300510d-2,
     & 0.300730d-2, 0.300950d-2, 0.301160d-2, 0.301380d-2, 0.301600d-2,
     & 0.301810d-2, 0.302030d-2, 0.302240d-2, 0.302460d-2, 0.302680d-2,
     & 0.302890d-2, 0.303110d-2, 0.303380d-2, 0.303650d-2, 0.303920d-2,
     & 0.304190d-2, 0.304460d-2, 0.304730d-2, 0.305000d-2, 0.305270d-2,
     & 0.305540d-2, 0.305810d-2, 0.306360d-2, 0.306900d-2, 0.307440d-2,
     & 0.307980d-2, 0.308520d-2, 0.309060d-2, 0.309600d-2, 0.310140d-2,
     & 0.310690d-2, 0.311230d-2, 0.311770d-2, 0.312310d-2, 0.312850d-2,
     & 0.313390d-2, 0.313930d-2, 0.314480d-2, 0.315020d-2, 0.315560d-2,
     & 0.316100d-2, 0.316640d-2, 0.317180d-2, 0.317730d-2, 0.318270d-2,
     & 0.318810d-2, 0.319350d-2, 0.320430d-2, 0.321520d-2, 0.322600d-2,
     & 0.323690d-2, 0.324770d-2, 0.325850d-2, 0.326940d-2, 0.328020d-2,
     & 0.329100d-2, 0.330190d-2, 0.331270d-2, 0.332360d-2, 0.333440d-2,
     & 0.334520d-2, 0.335610d-2, 0.336690d-2, 0.337780d-2, 0.338860d-2,
     & 0.339940d-2, 0.341030d-2, 0.342110d-2, 0.343190d-2, 0.344280d-2/

      data ( da_sp(i), i= 191, 285) /
     & 0.345360d-2, 0.346440d-2, 0.347530d-2, 0.348610d-2, 0.349690d-2,
     & 0.350780d-2, 0.351860d-2, 0.352940d-2, 0.354030d-2, 0.355110d-2,
     & 0.356190d-2, 0.357280d-2, 0.358360d-2, 0.359440d-2, 0.360520d-2,
     & 0.361610d-2, 0.362690d-2, 0.363770d-2, 0.364850d-2, 0.365930d-2,
     & 0.367010d-2, 0.368100d-2, 0.369180d-2, 0.370260d-2, 0.371340d-2,
     & 0.372420d-2, 0.373500d-2, 0.375660d-2, 0.377820d-2, 0.379980d-2,
     & 0.382140d-2, 0.384300d-2, 0.386450d-2, 0.388610d-2, 0.390760d-2,
     & 0.392920d-2, 0.395070d-2, 0.397220d-2, 0.399370d-2, 0.401520d-2,
     & 0.403670d-2, 0.405820d-2, 0.407960d-2, 0.410110d-2, 0.412250d-2,
     & 0.414390d-2, 0.416540d-2, 0.418680d-2, 0.420810d-2, 0.422950d-2,
     & 0.423220d-2, 0.423490d-2, 0.423750d-2, 0.424020d-2, 0.424290d-2,
     & 0.424550d-2, 0.424820d-2, 0.425090d-2, 0.425350d-2, 0.425620d-2,
     & 0.425890d-2, 0.426150d-2, 0.426450d-2, 0.426710d-2, 0.426980d-2,
     & 0.427250d-2, 0.427540d-2, 0.427800d-2, 0.428070d-2, 0.428340d-2,
     & 0.428600d-2, 0.428870d-2, 0.429140d-2, 0.429400d-2, 0.429670d-2,
     & 0.429940d-2, 0.430200d-2, 0.430470d-2, 0.430870d-2, 0.431270d-2,
     & 0.436590d-2, 0.441900d-2, 0.447210d-2, 0.452500d-2, 0.457780d-2,
     & 0.463050d-2, 0.468310d-2, 0.473550d-2, 0.478790d-2, 0.484010d-2,
     & 0.489220d-2, 0.494410d-2, 0.499600d-2, 0.504760d-2, 0.509920d-2/

      data ( da_sp(i), i= 286, 380) /
     & 0.515060d-2, 0.520180d-2, 0.525300d-2, 0.530390d-2, 0.535470d-2,
     & 0.540540d-2, 0.545590d-2, 0.550620d-2, 0.555640d-2, 0.560640d-2,
     & 0.565630d-2, 0.570600d-2, 0.575550d-2, 0.580490d-2, 0.585410d-2,
     & 0.590310d-2, 0.595200d-2, 0.600060d-2, 0.604910d-2, 0.609750d-2,
     & 0.614560d-2, 0.619360d-2, 0.624140d-2, 0.628900d-2, 0.633640d-2,
     & 0.638370d-2, 0.643070d-2, 0.647760d-2, 0.652430d-2, 0.657080d-2,
     & 0.661720d-2, 0.666330d-2, 0.670930d-2, 0.675500d-2, 0.680060d-2,
     & 0.684600d-2, 0.689120d-2, 0.693630d-2, 0.698110d-2, 0.702580d-2,
     & 0.707020d-2, 0.711450d-2, 0.715860d-2, 0.720250d-2, 0.724620d-2,
     & 0.728970d-2, 0.733300d-2, 0.737620d-2, 0.741910d-2, 0.746190d-2,
     & 0.750450d-2, 0.754690d-2, 0.758910d-2, 0.763110d-2, 0.767290d-2,
     & 0.771460d-2, 0.775600d-2, 0.779730d-2, 0.783840d-2, 0.787930d-2,
     & 0.792000d-2, 0.796060d-2, 0.800090d-2, 0.804110d-2, 0.808110d-2,
     & 0.812090d-2, 0.816050d-2, 0.820000d-2, 0.823920d-2, 0.827830d-2,
     & 0.831720d-2, 0.835590d-2, 0.839450d-2, 0.843280d-2, 0.847100d-2,
     & 0.850910d-2, 0.854690d-2, 0.858460d-2, 0.862200d-2, 0.865940d-2,
     & 0.869650d-2, 0.873350d-2, 0.877030d-2, 0.884340d-2, 0.891580d-2,
     & 0.898750d-2, 0.905860d-2, 0.912900d-2, 0.930220d-2, 0.947150d-2,
     & 0.963680d-2, 0.979840d-2, 0.995630d-2, 0.101106d-1, 0.102615d-1/

      data ( da_sp(i), i= 381, 475) /
     & 0.104089d-1, 0.105531d-1, 0.106941d-1, 0.108321d-1, 0.109670d-1,
     & 0.110990d-1, 0.112282d-1, 0.113546d-1, 0.114784d-1, 0.115996d-1,
     & 0.117183d-1, 0.117230d-1, 0.117277d-1, 0.117324d-1, 0.117371d-1,
     & 0.117418d-1, 0.117465d-1, 0.117511d-1, 0.117558d-1, 0.117605d-1,
     & 0.117651d-1, 0.117698d-1, 0.117744d-1, 0.117791d-1, 0.117837d-1,
     & 0.117884d-1, 0.117930d-1, 0.117977d-1, 0.118023d-1, 0.118069d-1,
     & 0.118115d-1, 0.118162d-1, 0.118208d-1, 0.118254d-1, 0.118300d-1,
     & 0.118346d-1, 0.118392d-1, 0.118438d-1, 0.118484d-1, 0.118530d-1,
     & 0.118576d-1, 0.118622d-1, 0.118667d-1, 0.118679d-1, 0.118690d-1,
     & 0.118702d-1, 0.118713d-1, 0.118725d-1, 0.118736d-1, 0.118748d-1,
     & 0.118759d-1, 0.118770d-1, 0.118782d-1, 0.118793d-1, 0.118805d-1,
     & 0.118816d-1, 0.118827d-1, 0.118839d-1, 0.118850d-1, 0.118862d-1,
     & 0.118873d-1, 0.118885d-1, 0.118896d-1, 0.118907d-1, 0.118919d-1,
     & 0.118930d-1, 0.118941d-1, 0.118953d-1, 0.118964d-1, 0.118976d-1,
     & 0.118987d-1, 0.118998d-1, 0.119010d-1, 0.119021d-1, 0.119033d-1,
     & 0.119044d-1, 0.119055d-1, 0.119067d-1, 0.119078d-1, 0.119089d-1,
     & 0.119101d-1, 0.119112d-1, 0.119123d-1, 0.119135d-1, 0.119146d-1,
     & 0.119157d-1, 0.119169d-1, 0.119180d-1, 0.119186d-1, 0.119191d-1,
     & 0.119197d-1, 0.119203d-1, 0.119208d-1, 0.119214d-1, 0.119220d-1/

      data ( da_sp(i), i= 476, 570) /
     & 0.119225d-1, 0.119228d-1, 0.119230d-1, 0.119232d-1, 0.119236d-1,
     & 0.119237d-1, 0.119238d-1, 0.119239d-1, 0.119240d-1, 0.119241d-1,
     & 0.119241d-1, 0.119242d-1, 0.119242d-1, 0.119243d-1, 0.119246d-1,
     & 0.119248d-1, 0.119250d-1, 0.119253d-1, 0.119255d-1, 0.119257d-1,
     & 0.119259d-1, 0.119262d-1, 0.119264d-1, 0.119266d-1, 0.119272d-1,
     & 0.119277d-1, 0.119283d-1, 0.119289d-1, 0.119294d-1, 0.119300d-1,
     & 0.119306d-1, 0.119311d-1, 0.119323d-1, 0.119334d-1, 0.119345d-1,
     & 0.119357d-1, 0.119368d-1, 0.119379d-1, 0.119391d-1, 0.119402d-1,
     & 0.119413d-1, 0.119424d-1, 0.119436d-1, 0.119447d-1, 0.119458d-1,
     & 0.119470d-1, 0.119481d-1, 0.119492d-1, 0.119503d-1, 0.119515d-1,
     & 0.119526d-1, 0.119537d-1, 0.119548d-1, 0.119560d-1, 0.119571d-1,
     & 0.119582d-1, 0.119594d-1, 0.119605d-1, 0.119616d-1, 0.119627d-1,
     & 0.119639d-1, 0.119650d-1, 0.119661d-1, 0.119672d-1, 0.119683d-1,
     & 0.119695d-1, 0.119706d-1, 0.119717d-1, 0.119728d-1, 0.119740d-1,
     & 0.119751d-1, 0.119762d-1, 0.119785d-1, 0.119807d-1, 0.119829d-1,
     & 0.119852d-1, 0.119874d-1, 0.119897d-1, 0.119919d-1, 0.119941d-1,
     & 0.119964d-1, 0.119986d-1, 0.120008d-1, 0.120031d-1, 0.120053d-1,
     & 0.120075d-1, 0.120098d-1, 0.120120d-1, 0.120142d-1, 0.120165d-1,
     & 0.120187d-1, 0.120209d-1, 0.120231d-1, 0.120254d-1, 0.120276d-1/

      data ( da_sp(i), i= 571, 665) /
     & 0.120298d-1, 0.120320d-1, 0.120343d-1, 0.120365d-1, 0.120387d-1,
     & 0.120409d-1, 0.120431d-1, 0.120454d-1, 0.120476d-1, 0.120498d-1,
     & 0.120520d-1, 0.120542d-1, 0.120564d-1, 0.120586d-1, 0.120609d-1,
     & 0.120631d-1, 0.120653d-1, 0.120675d-1, 0.120697d-1, 0.120719d-1,
     & 0.120741d-1, 0.120763d-1, 0.120785d-1, 0.120807d-1, 0.120829d-1,
     & 0.120851d-1, 0.120873d-1, 0.120895d-1, 0.120917d-1, 0.120939d-1,
     & 0.120961d-1, 0.120983d-1, 0.121005d-1, 0.121027d-1, 0.121049d-1,
     & 0.121071d-1, 0.121093d-1, 0.121115d-1, 0.121136d-1, 0.121158d-1,
     & 0.121180d-1, 0.121202d-1, 0.121224d-1, 0.121246d-1, 0.121268d-1,
     & 0.121290d-1, 0.121311d-1, 0.121333d-1, 0.121355d-1, 0.121377d-1,
     & 0.121399d-1, 0.121420d-1, 0.121442d-1, 0.121464d-1, 0.121486d-1,
     & 0.121507d-1, 0.121540d-1, 0.121757d-1, 0.121973d-1, 0.122188d-1,
     & 0.122402d-1, 0.122616d-1, 0.122829d-1, 0.123040d-1, 0.123251d-1,
     & 0.123462d-1, 0.123671d-1, 0.123879d-1, 0.124087d-1, 0.124294d-1,
     & 0.124500d-1, 0.124706d-1, 0.124910d-1, 0.125114d-1, 0.125317d-1,
     & 0.125519d-1, 0.125720d-1, 0.126121d-1, 0.126518d-1, 0.126913d-1,
     & 0.127304d-1, 0.127693d-1, 0.128079d-1, 0.128462d-1, 0.128842d-1,
     & 0.129219d-1, 0.129593d-1, 0.129686d-1, 0.129779d-1, 0.129872d-1,
     & 0.129965d-1, 0.130058d-1, 0.130150d-1, 0.130242d-1, 0.130334d-1/

      data ( da_sp(i), i= 666, 760) /
     & 0.130426d-1, 0.130517d-1, 0.130609d-1, 0.130700d-1, 0.130791d-1,
     & 0.130882d-1, 0.130973d-1, 0.130991d-1, 0.131010d-1, 0.131028d-1,
     & 0.131046d-1, 0.131064d-1, 0.131082d-1, 0.131100d-1, 0.131118d-1,
     & 0.131136d-1, 0.131154d-1, 0.131155d-1, 0.131157d-1, 0.131160d-1,
     & 0.131162d-1, 0.131164d-1, 0.131165d-1, 0.131166d-1, 0.131168d-1,
     & 0.131170d-1, 0.131179d-1, 0.131188d-1, 0.131197d-1, 0.131206d-1,
     & 0.131224d-1, 0.131242d-1, 0.131261d-1, 0.131279d-1, 0.131297d-1,
     & 0.131315d-1, 0.131333d-1, 0.131351d-1, 0.131369d-1, 0.131387d-1,
     & 0.131405d-1, 0.131423d-1, 0.131441d-1, 0.131459d-1, 0.131477d-1,
     & 0.131495d-1, 0.131513d-1, 0.131531d-1, 0.131548d-1, 0.131566d-1,
     & 0.131584d-1, 0.131602d-1, 0.131692d-1, 0.131781d-1, 0.131870d-1,
     & 0.131959d-1, 0.132048d-1, 0.132137d-1, 0.132226d-1, 0.132323d-1,
     & 0.132411d-1, 0.132499d-1, 0.132587d-1, 0.132675d-1, 0.132763d-1,
     & 0.132850d-1, 0.132937d-1, 0.133025d-1, 0.133112d-1, 0.133198d-1,
     & 0.133372d-1, 0.133544d-1, 0.133716d-1, 0.133888d-1, 0.134059d-1,
     & 0.134229d-1, 0.134399d-1, 0.134568d-1, 0.134736d-1, 0.134904d-1,
     & 0.135071d-1, 0.135238d-1, 0.135404d-1, 0.135570d-1, 0.135735d-1,
     & 0.135899d-1, 0.136063d-1, 0.136226d-1, 0.136389d-1, 0.136551d-1,
     & 0.136713d-1, 0.136874d-1, 0.137035d-1, 0.137195d-1, 0.137354d-1/

      data ( da_sp(i), i= 761, 855) /
     & 0.137513d-1, 0.137672d-1, 0.137830d-1, 0.137987d-1, 0.138144d-1,
     & 0.138300d-1, 0.138456d-1, 0.138611d-1, 0.138766d-1, 0.138920d-1,
     & 0.139074d-1, 0.139227d-1, 0.139380d-1, 0.139532d-1, 0.139684d-1,
     & 0.139986d-1, 0.140286d-1, 0.140584d-1, 0.140881d-1, 0.141175d-1,
     & 0.141467d-1, 0.141758d-1, 0.142046d-1, 0.142333d-1, 0.142618d-1,
     & 0.142902d-1, 0.143183d-1, 0.143463d-1, 0.143741d-1, 0.144017d-1,
     & 0.144292d-1, 0.144564d-1, 0.144836d-1, 0.145105d-1, 0.145373d-1,
     & 0.145639d-1, 0.145904d-1, 0.146167d-1, 0.146428d-1, 0.146688d-1,
     & 0.146946d-1, 0.147203d-1, 0.147458d-1, 0.147712d-1, 0.147964d-1,
     & 0.148215d-1, 0.148464d-1, 0.148712d-1, 0.148958d-1, 0.149203d-1,
     & 0.149447d-1, 0.149689d-1, 0.149929d-1, 0.150169d-1, 0.150407d-1,
     & 0.150643d-1, 0.150879d-1, 0.151112d-1, 0.151345d-1, 0.151576d-1,
     & 0.151806d-1, 0.152035d-1, 0.152262d-1, 0.152488d-1, 0.152713d-1,
     & 0.152937d-1, 0.153159d-1, 0.153380d-1, 0.153600d-1, 0.153819d-1,
     & 0.154037d-1, 0.154253d-1, 0.154468d-1, 0.154682d-1, 0.154895d-1,
     & 0.155107d-1, 0.155317d-1, 0.155527d-1, 0.155735d-1, 0.155942d-1,
     & 0.156148d-1, 0.156353d-1, 0.156557d-1, 0.156760d-1, 0.156962d-1,
     & 0.157163d-1, 0.157362d-1, 0.157561d-1, 0.157759d-1, 0.157955d-1,
     & 0.158345d-1, 0.158732d-1, 0.159114d-1, 0.159492d-1, 0.159866d-1/

      data ( da_sp(i), i= 856, 950) /
     & 0.160237d-1, 0.160604d-1, 0.160967d-1, 0.161327d-1, 0.161683d-1,
     & 0.162036d-1, 0.162385d-1, 0.162731d-1, 0.163073d-1, 0.163412d-1,
     & 0.163748d-1, 0.164081d-1, 0.164410d-1, 0.164737d-1, 0.165060d-1,
     & 0.165380d-1, 0.165697d-1, 0.166012d-1, 0.166323d-1, 0.166631d-1,
     & 0.166937d-1, 0.167240d-1, 0.167540d-1, 0.167837d-1, 0.168132d-1,
     & 0.168278d-1, 0.168424d-1, 0.168569d-1, 0.168713d-1, 0.168857d-1,
     & 0.169000d-1, 0.169142d-1, 0.169284d-1, 0.169425d-1, 0.169566d-1,
     & 0.169706d-1, 0.169845d-1, 0.169984d-1, 0.170122d-1, 0.170259d-1,
     & 0.170396d-1, 0.170532d-1, 0.170668d-1, 0.170803d-1, 0.170937d-1,
     & 0.171071d-1, 0.171204d-1, 0.171337d-1, 0.171469d-1, 0.171601d-1,
     & 0.171732d-1, 0.171862d-1, 0.171992d-1, 0.172121d-1, 0.172250d-1,
     & 0.172378d-1, 0.172506d-1, 0.172633d-1, 0.172760d-1, 0.172886d-1,
     & 0.173011d-1, 0.173136d-1, 0.173261d-1, 0.173384d-1, 0.173508d-1,
     & 0.173631d-1, 0.173753d-1, 0.173875d-1, 0.173996d-1, 0.174117d-1,
     & 0.174237d-1, 0.174357d-1, 0.174476d-1, 0.174595d-1, 0.174714d-1,
     & 0.174831d-1, 0.174949d-1, 0.175066d-1, 0.175182d-1, 0.175298d-1,
     & 0.175413d-1, 0.175528d-1, 0.175643d-1, 0.175757d-1, 0.175870d-1,
     & 0.175983d-1, 0.176096d-1, 0.176208d-1, 0.176320d-1, 0.176431d-1,
     & 0.176542d-1, 0.176652d-1, 0.176762d-1, 0.176872d-1, 0.176981d-1/

      data ( da_sp(i), i= 951,1045) /
     & 0.177089d-1, 0.177197d-1, 0.177305d-1, 0.177412d-1, 0.177519d-1,
     & 0.177626d-1, 0.177732d-1, 0.177837d-1, 0.177942d-1, 0.178047d-1,
     & 0.178152d-1, 0.178255d-1, 0.178359d-1, 0.178462d-1, 0.178565d-1,
     & 0.178667d-1, 0.178769d-1, 0.178870d-1, 0.178972d-1, 0.179072d-1,
     & 0.179173d-1, 0.179272d-1, 0.179372d-1, 0.179471d-1, 0.179570d-1,
     & 0.179668d-1, 0.179766d-1, 0.179864d-1, 0.179961d-1, 0.180058d-1,
     & 0.180154d-1, 0.180250d-1, 0.180346d-1, 0.180442d-1, 0.180537d-1,
     & 0.180631d-1, 0.180726d-1, 0.180819d-1, 0.180913d-1, 0.181006d-1,
     & 0.181099d-1, 0.181192d-1, 0.181284d-1, 0.181376d-1, 0.181467d-1,
     & 0.181558d-1, 0.181649d-1, 0.181739d-1, 0.181829d-1, 0.181919d-1,
     & 0.182009d-1, 0.182098d-1, 0.182186d-1, 0.182275d-1, 0.182363d-1,
     & 0.182374d-1, 0.182385d-1, 0.182396d-1, 0.182407d-1, 0.182418d-1,
     & 0.182429d-1, 0.182440d-1, 0.182451d-1, 0.182462d-1, 0.182472d-1,
     & 0.182483d-1, 0.182494d-1, 0.182505d-1, 0.182516d-1, 0.182527d-1,
     & 0.182538d-1, 0.182542d-1, 0.182547d-1, 0.182551d-1, 0.182555d-1,
     & 0.182560d-1, 0.182564d-1, 0.182569d-1, 0.182573d-1, 0.182577d-1,
     & 0.182582d-1, 0.182586d-1, 0.182590d-1, 0.182595d-1, 0.182599d-1,
     & 0.182603d-1, 0.182608d-1, 0.182610d-1, 0.182612d-1, 0.182614d-1,
     & 0.182616d-1, 0.182619d-1, 0.182619d-1, 0.182619d-1, 0.182620d-1/

      data ( da_sp(i), i=1046,1140) /
     & 0.182620d-1, 0.182621d-1, 0.182621d-1, 0.182622d-1, 0.182622d-1,
     & 0.182622d-1, 0.182622d-1, 0.182622d-1, 0.182622d-1, 0.182623d-1,
     & 0.182623d-1, 0.182623d-1, 0.182623d-1, 0.182623d-1, 0.182623d-1,
     & 0.182624d-1, 0.182624d-1, 0.182625d-1, 0.182625d-1, 0.182625d-1,
     & 0.182626d-1, 0.182627d-1, 0.182628d-1, 0.182629d-1, 0.182630d-1,
     & 0.182631d-1, 0.182632d-1, 0.182633d-1, 0.182635d-1, 0.182637d-1,
     & 0.182639d-1, 0.182641d-1, 0.182643d-1, 0.182645d-1, 0.182648d-1,
     & 0.182650d-1, 0.182652d-1, 0.182654d-1, 0.182656d-1, 0.182658d-1,
     & 0.182661d-1, 0.182663d-1, 0.182665d-1, 0.182667d-1, 0.182669d-1,
     & 0.182671d-1, 0.182674d-1, 0.182676d-1, 0.182680d-1, 0.182684d-1,
     & 0.182689d-1, 0.182710d-1, 0.182732d-1, 0.182754d-1, 0.182775d-1,
     & 0.182797d-1, 0.182818d-1, 0.182840d-1, 0.182862d-1, 0.182883d-1,
     & 0.182905d-1, 0.182926d-1, 0.182947d-1, 0.182969d-1, 0.182990d-1,
     & 0.183012d-1, 0.183033d-1, 0.183054d-1, 0.183076d-1, 0.183097d-1,
     & 0.183118d-1, 0.183140d-1, 0.183161d-1, 0.183182d-1, 0.183203d-1,
     & 0.183224d-1, 0.183235d-1, 0.183246d-1, 0.183256d-1, 0.183267d-1,
     & 0.183277d-1, 0.183288d-1, 0.183298d-1, 0.183309d-1, 0.183320d-1,
     & 0.183330d-1, 0.183341d-1, 0.183351d-1, 0.183362d-1, 0.183372d-1,
     & 0.183383d-1, 0.183393d-1, 0.183404d-1, 0.183414d-1, 0.183425d-1/

      data ( da_sp(i), i=1141,1235) /
     & 0.183435d-1, 0.183446d-1, 0.183456d-1, 0.183467d-1, 0.183477d-1,
     & 0.183488d-1, 0.183498d-1, 0.183509d-1, 0.183519d-1, 0.183529d-1,
     & 0.183540d-1, 0.183550d-1, 0.183561d-1, 0.183571d-1, 0.183582d-1,
     & 0.183592d-1, 0.183602d-1, 0.183613d-1, 0.183623d-1, 0.183634d-1,
     & 0.183644d-1, 0.183654d-1, 0.183665d-1, 0.183675d-1, 0.183686d-1,
     & 0.183696d-1, 0.183706d-1, 0.183717d-1, 0.183727d-1, 0.183737d-1,
     & 0.183748d-1, 0.183758d-1, 0.183768d-1, 0.183779d-1, 0.183789d-1,
     & 0.183799d-1, 0.183810d-1, 0.183820d-1, 0.183830d-1, 0.183841d-1,
     & 0.183851d-1, 0.183861d-1, 0.183872d-1, 0.183882d-1, 0.183892d-1,
     & 0.183902d-1, 0.183913d-1, 0.183923d-1, 0.183933d-1, 0.183944d-1,
     & 0.183954d-1, 0.183964d-1, 0.183974d-1, 0.183985d-1, 0.183995d-1,
     & 0.184005d-1, 0.184015d-1, 0.184025d-1, 0.184036d-1, 0.184046d-1,
     & 0.184056d-1, 0.184066d-1, 0.184077d-1, 0.184087d-1, 0.184097d-1,
     & 0.184107d-1, 0.184117d-1, 0.184127d-1, 0.184138d-1, 0.184148d-1,
     & 0.184158d-1, 0.184168d-1, 0.184178d-1, 0.184188d-1, 0.184199d-1,
     & 0.184209d-1, 0.184219d-1, 0.184229d-1, 0.184239d-1, 0.184249d-1,
     & 0.184259d-1, 0.184269d-1, 0.184280d-1, 0.184290d-1, 0.184300d-1,
     & 0.184310d-1, 0.184320d-1, 0.184330d-1, 0.184340d-1, 0.184350d-1,
     & 0.184360d-1, 0.184370d-1, 0.184380d-1, 0.184390d-1, 0.184400d-1/

      data ( da_sp(i), i=1236,1330) /
     & 0.184411d-1, 0.184421d-1, 0.184431d-1, 0.184441d-1, 0.184451d-1,
     & 0.184461d-1, 0.184471d-1, 0.184481d-1, 0.184491d-1, 0.184501d-1,
     & 0.184511d-1, 0.184521d-1, 0.184531d-1, 0.184541d-1, 0.184551d-1,
     & 0.184561d-1, 0.184571d-1, 0.184581d-1, 0.184591d-1, 0.184601d-1,
     & 0.184611d-1, 0.184620d-1, 0.184630d-1, 0.184640d-1, 0.184650d-1,
     & 0.184660d-1, 0.184670d-1, 0.184680d-1, 0.184690d-1, 0.184700d-1,
     & 0.184710d-1, 0.184720d-1, 0.184730d-1, 0.184740d-1, 0.184749d-1,
     & 0.184759d-1, 0.184769d-1, 0.184779d-1, 0.184789d-1, 0.184799d-1,
     & 0.184809d-1, 0.184819d-1, 0.184828d-1, 0.184838d-1, 0.184848d-1,
     & 0.184858d-1, 0.184862d-1, 0.184866d-1, 0.184870d-1, 0.184874d-1,
     & 0.184878d-1, 0.184882d-1, 0.184886d-1, 0.184889d-1, 0.184893d-1,
     & 0.184897d-1, 0.184901d-1, 0.184905d-1, 0.184909d-1, 0.184913d-1,
     & 0.184917d-1, 0.184919d-1, 0.184921d-1, 0.184923d-1, 0.184925d-1,
     & 0.184927d-1, 0.184929d-1, 0.184931d-1, 0.184933d-1, 0.184935d-1,
     & 0.184937d-1, 0.184939d-1, 0.184941d-1, 0.184942d-1, 0.184943d-1,
     & 0.184943d-1, 0.184944d-1, 0.184944d-1, 0.184944d-1, 0.184945d-1,
     & 0.184945d-1, 0.184946d-1, 0.184946d-1, 0.184946d-1, 0.184947d-1,
     & 0.184947d-1, 0.184947d-1, 0.184947d-1, 0.184947d-1, 0.184947d-1,
     & 0.184947d-1, 0.184947d-1, 0.184947d-1, 0.184947d-1, 0.184947d-1/

      data ( da_sp(i), i=1331,1425) /
     & 0.184948d-1, 0.184948d-1, 0.184949d-1, 0.184950d-1, 0.184950d-1,
     & 0.184952d-1, 0.184954d-1, 0.184958d-1, 0.184962d-1, 0.184966d-1,
     & 0.184970d-1, 0.184974d-1, 0.185013d-1, 0.185052d-1, 0.185091d-1,
     & 0.185130d-1, 0.185169d-1, 0.185208d-1, 0.185246d-1, 0.185285d-1,
     & 0.185324d-1, 0.185362d-1, 0.185401d-1, 0.185439d-1, 0.185477d-1,
     & 0.185515d-1, 0.185554d-1, 0.185592d-1, 0.185630d-1, 0.185668d-1,
     & 0.185706d-1, 0.185743d-1, 0.185781d-1, 0.185819d-1, 0.185856d-1,
     & 0.185894d-1, 0.185931d-1, 0.185969d-1, 0.186006d-1, 0.186014d-1,
     & 0.186021d-1, 0.186029d-1, 0.186036d-1, 0.186044d-1, 0.186051d-1,
     & 0.186058d-1, 0.186066d-1, 0.186073d-1, 0.186081d-1, 0.186088d-1,
     & 0.186096d-1, 0.186103d-1, 0.186110d-1, 0.186118d-1, 0.186125d-1,
     & 0.186133d-1, 0.186140d-1, 0.186148d-1, 0.186155d-1, 0.186162d-1,
     & 0.186170d-1, 0.186177d-1, 0.186185d-1, 0.186192d-1, 0.186196d-1,
     & 0.186199d-1, 0.186201d-1, 0.186203d-1, 0.186205d-1, 0.186207d-1,
     & 0.186208d-1, 0.186208d-1, 0.186209d-1, 0.186209d-1, 0.186210d-1,
     & 0.186210d-1, 0.186210d-1, 0.186211d-1, 0.186211d-1, 0.186211d-1,
     & 0.186211d-1, 0.186211d-1, 0.186211d-1, 0.186211d-1, 0.186211d-1,
     & 0.186211d-1, 0.186211d-1, 0.186211d-1, 0.186212d-1, 0.186212d-1,
     & 0.186213d-1, 0.186214d-1, 0.186216d-1, 0.186218d-1, 0.186219d-1/

      data ( da_sp(i), i=1426,1520) /
     & 0.186221d-1, 0.186225d-1, 0.186229d-1, 0.186238d-1, 0.186247d-1,
     & 0.186266d-1, 0.186302d-1, 0.186339d-1, 0.186376d-1, 0.186412d-1,
     & 0.186449d-1, 0.186486d-1, 0.186522d-1, 0.186558d-1, 0.186595d-1,
     & 0.186631d-1, 0.186667d-1, 0.186703d-1, 0.186739d-1, 0.186775d-1,
     & 0.186811d-1, 0.186847d-1, 0.186883d-1, 0.186919d-1, 0.186954d-1,
     & 0.186990d-1, 0.187025d-1, 0.187061d-1, 0.187096d-1, 0.187132d-1,
     & 0.187167d-1, 0.187202d-1, 0.187237d-1, 0.187273d-1, 0.187308d-1,
     & 0.187343d-1, 0.187378d-1, 0.187413d-1, 0.187447d-1, 0.187482d-1,
     & 0.187517d-1, 0.187551d-1, 0.187586d-1, 0.187621d-1, 0.187655d-1,
     & 0.187689d-1, 0.187724d-1, 0.187758d-1, 0.187792d-1, 0.187826d-1,
     & 0.187860d-1, 0.187895d-1, 0.187928d-1, 0.187962d-1, 0.187996d-1,
     & 0.188030d-1, 0.188064d-1, 0.188098d-1, 0.188131d-1, 0.188165d-1,
     & 0.188198d-1, 0.188232d-1, 0.188265d-1, 0.188298d-1, 0.188332d-1,
     & 0.188365d-1, 0.188398d-1, 0.188431d-1, 0.188464d-1, 0.188629d-1,
     & 0.188792d-1, 0.188954d-1, 0.189114d-1, 0.189273d-1, 0.189431d-1,
     & 0.189587d-1, 0.189742d-1, 0.189896d-1, 0.190048d-1, 0.190349d-1,
     & 0.190645d-1, 0.190936d-1, 0.191223d-1, 0.191505d-1, 0.194088d-1,
     & 0.196297d-1, 0.198200d-1, 0.199848d-1, 0.201284d-1, 0.202541d-1,
     & 0.203646d-1, 0.204623d-1, 0.205489d-1, 0.206261d-1, 0.206952d-1/

      data ( da_sp(i), i=1521,1542) /
     & 0.207572d-1, 0.208130d-1, 0.208634d-1, 0.209092d-1, 0.209507d-1,
     & 0.209886d-1, 0.210233d-1, 0.211588d-1, 0.212514d-1, 0.213175d-1,
     & 0.213666d-1, 0.214041d-1, 0.214336d-1, 0.214573d-1, 0.214767d-1,
     & 0.214928d-1, 0.215065d-1, 0.215181d-1, 0.215282d-1, 0.215304d-1,
     & 0.215371d-1, 0.215448d-1/


      data  ( a_tm(i), i=   1,  95) /
     &-0.124000d-3,-0.495000d-3,-0.111500d-2,-0.198500d-2,-0.310800d-2,
     &-0.449700d-2,-0.613900d-2,-0.804400d-2,-0.102180d-1,-0.126670d-1,
     &-0.153980d-1,-0.184190d-1,-0.217400d-1,-0.253690d-1,-0.293200d-1,
     &-0.336060d-1,-0.382420d-1,-0.432460d-1,-0.486390d-1,-0.544440d-1,
     &-0.606910d-1,-0.674140d-1,-0.746560d-1,-0.824740d-1,-0.909430d-1,
     &-0.100177d0,-0.110380d0,-0.133747d0,-0.157430d0,-0.180698d0,
     &-0.207212d0,-0.236674d0,-0.251660d0,-0.288005d0,-0.317957d0,
     &-0.353557d0,-0.380928d0,-0.436577d0,-0.475605d0,-0.521481d0,
     &-0.593485d0,-0.647795d0,-0.726592d0,-0.827262d0,-0.920033d0,
     &-0.943150d0,-0.972070d0,-0.997906d0,-0.102423d1,-0.105354d1,
     &-0.108159d1,-0.111373d1,-0.114612d1,-0.117568d1,-0.119919d1,
     &-0.123038d1,-0.125748d1,-0.129387d1,-0.130961d1,-0.133074d1,
     &-0.135018d1,-0.137833d1,-0.138873d1,-0.138398d1,-0.135136d1,
     &-0.133831d1,-0.130305d1,-0.124328d1,-0.120479d1,-0.114121d1,
     &-0.104642d1,-0.948527d0,-0.863222d0,-0.774215d0,-0.710910d0,
     &-0.668868d0,-0.636287d0,-0.617870d0,-0.609462d0,-0.606752d0,
     &-0.617254d0,-0.625812d0,-0.653941d0,-0.746846d0,-0.754775d0,
     &-0.761715d0,-0.770505d0,-0.781137d0,-0.794485d0,-0.812382d0,
     &-0.839051d0,-0.887290d0,-0.924828d0,-0.965899d0,-0.975262d0/

      data ( a_tm(i), i=  96, 190) /
     &-0.970041d0,-0.954063d0,-0.929177d0,-0.896653d0,-0.857726d0,
     &-0.814235d0,-0.766375d0,-0.739443d0,-0.661748d0,-0.573302d0,
     &-0.462851d0,-0.316719d0,-0.131445d0, 0.145687d0, 0.411477d0,
     & 0.748010d0, 0.112713d1, 0.143587d1, 0.188498d1, 0.221019d1,
     & 0.250536d1, 0.271612d1, 0.284194d1, 0.296038d1, 0.303933d1,
     & 0.311767d1, 0.314961d1, 0.312653d1, 0.313570d1, 0.314664d1,
     & 0.315287d1, 0.315112d1, 0.313872d1, 0.311248d1, 0.306669d1,
     & 0.298133d1, 0.288168d1, 0.281848d1, 0.276663d1, 0.272298d1,
     & 0.268287d1, 0.264349d1, 0.260208d1, 0.255307d1, 0.249545d1,
     & 0.243868d1, 0.239903d1, 0.233995d1, 0.229838d1, 0.225985d1,
     & 0.222044d1, 0.217157d1, 0.213687d1, 0.210932d1, 0.208610d1,
     & 0.206629d1, 0.204874d1, 0.203273d1, 0.201769d1, 0.200308d1,
     & 0.198824d1, 0.197051d1, 0.195270d1, 0.193886d1, 0.192674d1,
     & 0.191570d1, 0.190534d1, 0.189546d1, 0.188622d1, 0.187708d1,
     & 0.186756d1, 0.185598d1, 0.183651d1, 0.182060d1, 0.180536d1,
     & 0.178878d1, 0.177055d1, 0.175276d1, 0.173572d1, 0.172043d1,
     & 0.170596d1, 0.169294d1, 0.167944d1, 0.166207d1, 0.163344d1,
     & 0.161139d1, 0.159157d1, 0.157444d1, 0.155870d1, 0.154391d1,
     & 0.153042d1, 0.152068d1, 0.150762d1, 0.149282d1, 0.147767d1/

      data ( a_tm(i), i= 191, 285) /
     & 0.146152d1, 0.144246d1, 0.142464d1, 0.140697d1, 0.138876d1,
     & 0.137125d1, 0.135343d1, 0.133465d1, 0.131568d1, 0.129507d1,
     & 0.127335d1, 0.125226d1, 0.123382d1, 0.122359d1, 0.120422d1,
     & 0.118617d1, 0.116919d1, 0.115135d1, 0.113388d1, 0.111628d1,
     & 0.109849d1, 0.108059d1, 0.106294d1, 0.104474d1, 0.102798d1,
     & 0.101062d1, 0.995327d0, 0.961280d0, 0.922702d0, 0.877599d0,
     & 0.835255d0, 0.791034d0, 0.755829d0, 0.708552d0, 0.662891d0,
     & 0.609722d0, 0.550668d0, 0.485227d0, 0.412800d0, 0.339494d0,
     & 0.263506d0, 0.177061d0, 0.606250d-1,-0.916100d-1,-0.266031d0,
     &-0.486370d0,-0.796694d0,-0.133674d1,-0.218762d1,-0.388398d1,
     &-0.411970d1,-0.438886d1,-0.466068d1,-0.501649d1,-0.533007d1,
     &-0.570440d1,-0.641747d1,-0.697668d1,-0.734924d1,-0.721775d1,
     &-0.678969d1,-0.536595d1,-0.238298d1, 0.939578d0, 0.409532d1,
     & 0.682226d1, 0.841982d1, 0.883048d1, 0.876930d1, 0.828956d1,
     & 0.739882d1, 0.703695d1, 0.677044d1, 0.617411d1, 0.580842d1,
     & 0.554038d1, 0.530992d1, 0.511664d1, 0.484604d1, 0.452506d1,
     & 0.268179d1, 0.204508d1, 0.170259d1, 0.148007d1, 0.138652d1,
     & 0.127962d1, 0.122572d1, 0.112320d1, 0.103977d1, 0.978417d0,
     & 0.939999d0, 0.905704d0, 0.869455d0, 0.827367d0, 0.828354d0/

      data ( a_tm(i), i= 286, 380) /
     & 0.793848d0, 0.758543d0, 0.727109d0, 0.695776d0, 0.672444d0,
     & 0.653715d0, 0.646488d0, 0.625104d0, 0.602278d0, 0.596547d0,
     & 0.576977d0, 0.549525d0, 0.555891d0, 0.533490d0, 0.513697d0,
     & 0.494270d0, 0.498858d0, 0.485416d0, 0.471417d0, 0.468106d0,
     & 0.467208d0, 0.448639d0, 0.469194d0, 0.474967d0, 0.469640d0,
     & 0.470757d0, 0.465444d0, 0.449626d0, 0.419021d0, 0.414518d0,
     & 0.427711d0, 0.445201d0, 0.466875d0, 0.495024d0, 0.530769d0,
     & 0.590851d0, 0.627833d0, 0.658622d0, 0.674574d0, 0.667902d0,
     & 0.629279d0, 0.616122d0, 0.616447d0, 0.622899d0, 0.613453d0,
     & 0.573667d0, 0.567379d0, 0.598477d0, 0.663185d0, 0.690037d0,
     & 0.701253d0, 0.711348d0, 0.720330d0, 0.727782d0, 0.733098d0,
     & 0.736566d0, 0.737561d0, 0.734294d0, 0.725085d0, 0.722833d0,
     & 0.722708d0, 0.724058d0, 0.728248d0, 0.732880d0, 0.752521d0,
     & 0.812034d0, 0.848133d0, 0.833865d0, 0.742940d0, 0.694968d0,
     & 0.720461d0, 0.735456d0, 0.732225d0, 0.719452d0, 0.696570d0,
     & 0.651702d0, 0.602789d0, 0.573583d0, 0.549929d0, 0.541139d0,
     & 0.543395d0, 0.560787d0, 0.594490d0, 0.620756d0, 0.634726d0,
     & 0.646063d0, 0.656733d0, 0.666470d0, 0.690321d0, 0.721136d0,
     & 0.744375d0, 0.762709d0, 0.778677d0, 0.792699d0, 0.805088d0/

      data ( a_tm(i), i= 381, 475) /
     & 0.814722d0, 0.831894d0, 0.870958d0, 0.897379d0, 0.905359d0,
     & 0.904465d0, 0.885933d0, 0.875438d0, 0.878746d0, 0.882651d0,
     & 0.887442d0, 0.887622d0, 0.887781d0, 0.887922d0, 0.888048d0,
     & 0.888160d0, 0.888259d0, 0.888346d0, 0.888422d0, 0.888487d0,
     & 0.888543d0, 0.888589d0, 0.888626d0, 0.888654d0, 0.888673d0,
     & 0.888685d0, 0.888688d0, 0.888684d0, 0.888672d0, 0.888653d0,
     & 0.888626d0, 0.888592d0, 0.888551d0, 0.888502d0, 0.888447d0,
     & 0.888385d0, 0.888316d0, 0.888240d0, 0.888157d0, 0.888068d0,
     & 0.887971d0, 0.887868d0, 0.887759d0, 0.887730d0, 0.887702d0,
     & 0.887672d0, 0.887643d0, 0.887612d0, 0.887582d0, 0.887551d0,
     & 0.887520d0, 0.887488d0, 0.887456d0, 0.887423d0, 0.887390d0,
     & 0.887356d0, 0.887322d0, 0.887288d0, 0.887253d0, 0.887218d0,
     & 0.887183d0, 0.887147d0, 0.887110d0, 0.887073d0, 0.887036d0,
     & 0.886998d0, 0.886960d0, 0.886922d0, 0.886883d0, 0.886843d0,
     & 0.886803d0, 0.886763d0, 0.886723d0, 0.886681d0, 0.886640d0,
     & 0.886598d0, 0.886556d0, 0.886513d0, 0.886469d0, 0.886426d0,
     & 0.886382d0, 0.886337d0, 0.886292d0, 0.886247d0, 0.886201d0,
     & 0.886155d0, 0.886108d0, 0.886061d0, 0.886037d0, 0.886013d0,
     & 0.885989d0, 0.885965d0, 0.885941d0, 0.885916d0, 0.885892d0/

      data ( a_tm(i), i= 476, 570) /
     & 0.885868d0, 0.885858d0, 0.885848d0, 0.885838d0, 0.885821d0,
     & 0.885817d0, 0.885812d0, 0.885808d0, 0.885803d0, 0.885801d0,
     & 0.885798d0, 0.885796d0, 0.885794d0, 0.885789d0, 0.885779d0,
     & 0.885769d0, 0.885759d0, 0.885749d0, 0.885739d0, 0.885729d0,
     & 0.885719d0, 0.885709d0, 0.885699d0, 0.885688d0, 0.885663d0,
     & 0.885637d0, 0.885612d0, 0.885586d0, 0.885560d0, 0.885534d0,
     & 0.885508d0, 0.885482d0, 0.885429d0, 0.885376d0, 0.885322d0,
     & 0.885268d0, 0.885213d0, 0.885158d0, 0.885103d0, 0.885047d0,
     & 0.884990d0, 0.884933d0, 0.884876d0, 0.884818d0, 0.884760d0,
     & 0.884701d0, 0.884642d0, 0.884582d0, 0.884522d0, 0.884461d0,
     & 0.884400d0, 0.884339d0, 0.884277d0, 0.884214d0, 0.884151d0,
     & 0.884087d0, 0.884023d0, 0.883959d0, 0.883894d0, 0.883828d0,
     & 0.883762d0, 0.883696d0, 0.883629d0, 0.883561d0, 0.883493d0,
     & 0.883425d0, 0.883356d0, 0.883286d0, 0.883216d0, 0.883146d0,
     & 0.883075d0, 0.883003d0, 0.882858d0, 0.882712d0, 0.882563d0,
     & 0.882411d0, 0.882258d0, 0.882103d0, 0.881945d0, 0.881785d0,
     & 0.881623d0, 0.881459d0, 0.881292d0, 0.881123d0, 0.880952d0,
     & 0.880778d0, 0.880602d0, 0.880423d0, 0.880242d0, 0.880059d0,
     & 0.879872d0, 0.879684d0, 0.879492d0, 0.879298d0, 0.879102d0/

      data ( a_tm(i), i= 571, 665) /
     & 0.878902d0, 0.878700d0, 0.878495d0, 0.878287d0, 0.878077d0,
     & 0.877863d0, 0.877646d0, 0.877426d0, 0.877203d0, 0.876977d0,
     & 0.876748d0, 0.876515d0, 0.876280d0, 0.876040d0, 0.875797d0,
     & 0.875551d0, 0.875301d0, 0.875047d0, 0.874789d0, 0.874527d0,
     & 0.874262d0, 0.873992d0, 0.873718d0, 0.873439d0, 0.873156d0,
     & 0.872869d0, 0.872576d0, 0.872279d0, 0.871977d0, 0.871669d0,
     & 0.871356d0, 0.871038d0, 0.870713d0, 0.870383d0, 0.870046d0,
     & 0.869702d0, 0.869352d0, 0.868994d0, 0.868629d0, 0.868255d0,
     & 0.867873d0, 0.867482d0, 0.867081d0, 0.866670d0, 0.866248d0,
     & 0.865814d0, 0.865367d0, 0.864905d0, 0.864428d0, 0.863932d0,
     & 0.863416d0, 0.862875d0, 0.862306d0, 0.861701d0, 0.861047d0,
     & 0.860318d0, 0.858880d0, 0.853180d0, 0.849203d0, 0.845950d0,
     & 0.843178d0, 0.840774d0, 0.838674d0, 0.836837d0, 0.835241d0,
     & 0.833869d0, 0.832714d0, 0.831776d0, 0.831061d0, 0.830580d0,
     & 0.830358d0, 0.830429d0, 0.830847d0, 0.831702d0, 0.833156d0,
     & 0.835567d0, 0.840857d0, 0.847302d0, 0.848355d0, 0.846789d0,
     & 0.843097d0, 0.837338d0, 0.829254d0, 0.817891d0, 0.800565d0,
     & 0.787302d0, 0.775160d0, 0.772174d0, 0.769195d0, 0.766221d0,
     & 0.763256d0, 0.760306d0, 0.757392d0, 0.754551d0, 0.751865d0/

      data ( a_tm(i), i= 666, 760) /
     & 0.749545d0, 0.748914d0, 0.746937d0, 0.742858d0, 0.736774d0,
     & 0.730585d0, 0.724036d0, 0.722654d0, 0.721244d0, 0.719805d0,
     & 0.718334d0, 0.716830d0, 0.715290d0, 0.713713d0, 0.712096d0,
     & 0.710436d0, 0.708731d0, 0.708711d0, 0.708463d0, 0.708214d0,
     & 0.707964d0, 0.707839d0, 0.707713d0, 0.707587d0, 0.707461d0,
     & 0.707208d0, 0.706314d0, 0.705407d0, 0.704485d0, 0.703548d0,
     & 0.701625d0, 0.699632d0, 0.697557d0, 0.695389d0, 0.693109d0,
     & 0.690692d0, 0.688092d0, 0.685222d0, 0.681792d0, 0.677741d0,
     & 0.674724d0, 0.672067d0, 0.669643d0, 0.667397d0, 0.665301d0,
     & 0.663342d0, 0.661514d0, 0.659819d0, 0.658269d0, 0.656885d0,
     & 0.655711d0, 0.654833d0, 0.652644d0, 0.640670d0, 0.621242d0,
     & 0.587869d0, 0.559236d0, 0.526707d0, 0.470528d0, 0.447428d0,
     & 0.396984d0, 0.434860d0, 0.503595d0, 0.652725d0, 0.776315d0,
     & 0.906858d0, 0.946412d0, 0.956310d0, 0.925727d0, 0.845058d0,
     & 0.756190d0, 0.719353d0, 0.689824d0, 0.663429d0, 0.645492d0,
     & 0.633594d0, 0.596371d0, 0.538530d0, 0.537549d0, 0.516665d0,
     & 0.529869d0, 0.530541d0, 0.492624d0, 0.504848d0, 0.548468d0,
     & 0.455694d0, 0.447855d0, 0.487773d0, 0.483634d0, 0.392515d0,
     & 0.315728d0, 0.407707d0, 0.567905d0, 0.682843d0, 0.744966d0/

      data ( a_tm(i), i= 761, 855) /
     & 0.859621d0, 0.841179d0, 0.836606d0, 0.848183d0, 0.859250d0,
     & 0.867818d0, 0.886837d0, 0.928228d0, 0.901997d0, 0.962123d0,
     & 0.100578d1, 0.102927d1, 0.108853d1, 0.115763d1, 0.120264d1,
     & 0.118814d1, 0.114002d1, 0.101758d1, 0.968570d0, 0.890117d0,
     & 0.878837d0, 0.866594d0, 0.851115d0, 0.898906d0, 0.913937d0,
     & 0.962922d0, 0.107869d1, 0.111150d1, 0.113889d1, 0.114627d1,
     & 0.111603d1, 0.102554d1, 0.105320d1, 0.111018d1, 0.109275d1,
     & 0.106914d1, 0.106173d1, 0.105939d1, 0.106014d1, 0.106330d1,
     & 0.106862d1, 0.107611d1, 0.108609d1, 0.109950d1, 0.112178d1,
     & 0.114237d1, 0.115636d1, 0.116765d1, 0.117715d1, 0.118525d1,
     & 0.119215d1, 0.119793d1, 0.120259d1, 0.120598d1, 0.120707d1,
     & 0.120785d1, 0.120922d1, 0.121039d1, 0.121107d1, 0.121106d1,
     & 0.121007d1, 0.120767d1, 0.120303d1, 0.119417d1, 0.116865d1,
     & 0.115346d1, 0.116495d1, 0.120517d1, 0.122640d1, 0.124111d1,
     & 0.125271d1, 0.126236d1, 0.127061d1, 0.127774d1, 0.128391d1,
     & 0.128919d1, 0.129359d1, 0.129704d1, 0.129924d1, 0.129854d1,
     & 0.129821d1, 0.129977d1, 0.130203d1, 0.130471d1, 0.130767d1,
     & 0.131088d1, 0.131428d1, 0.131787d1, 0.132164d1, 0.132562d1,
     & 0.133453d1, 0.134473d1, 0.135328d1, 0.136134d1, 0.136918d1/

      data ( a_tm(i), i= 856, 950) /
     & 0.137702d1, 0.138529d1, 0.139511d1, 0.140215d1, 0.140754d1,
     & 0.141150d1, 0.141386d1, 0.141392d1, 0.140800d1, 0.140597d1,
     & 0.140679d1, 0.140911d1, 0.141257d1, 0.141713d1, 0.142358d1,
     & 0.143023d1, 0.143597d1, 0.144152d1, 0.144703d1, 0.145259d1,
     & 0.145837d1, 0.146442d1, 0.146980d1, 0.147481d1, 0.147937d1,
     & 0.148138d1, 0.148310d1, 0.148418d1, 0.148389d1, 0.148543d1,
     & 0.148782d1, 0.149081d1, 0.149433d1, 0.149837d1, 0.150295d1,
     & 0.150813d1, 0.151401d1, 0.152077d1, 0.152869d1, 0.153830d1,
     & 0.155076d1, 0.156968d1, 0.160475d1, 0.161044d1, 0.158471d1,
     & 0.155990d1, 0.155092d1, 0.154862d1, 0.155443d1, 0.156329d1,
     & 0.155896d1, 0.153542d1, 0.151979d1, 0.152691d1, 0.156381d1,
     & 0.159677d1, 0.160974d1, 0.161290d1, 0.160628d1, 0.157715d1,
     & 0.155331d1, 0.154821d1, 0.155314d1, 0.156851d1, 0.160784d1,
     & 0.164230d1, 0.165812d1, 0.166493d1, 0.166348d1, 0.164617d1,
     & 0.163019d1, 0.162362d1, 0.162057d1, 0.161995d1, 0.162245d1,
     & 0.162534d1, 0.162727d1, 0.162899d1, 0.163049d1, 0.163091d1,
     & 0.163223d1, 0.163549d1, 0.164026d1, 0.164696d1, 0.165858d1,
     & 0.166928d1, 0.167640d1, 0.168227d1, 0.168782d1, 0.169602d1,
     & 0.170109d1, 0.170003d1, 0.169407d1, 0.168164d1, 0.165097d1/

      data ( a_tm(i), i= 951,1045) /
     & 0.162611d1, 0.161881d1, 0.162199d1, 0.164077d1, 0.166581d1,
     & 0.167628d1, 0.168196d1, 0.168415d1, 0.168266d1, 0.167281d1,
     & 0.166485d1, 0.166379d1, 0.166651d1, 0.167340d1, 0.169085d1,
     & 0.170534d1, 0.171032d1, 0.171014d1, 0.170470d1, 0.168814d1,
     & 0.167286d1, 0.166464d1, 0.165893d1, 0.165454d1, 0.164979d1,
     & 0.164699d1, 0.164732d1, 0.165003d1, 0.165545d1, 0.166573d1,
     & 0.167909d1, 0.168691d1, 0.169317d1, 0.169864d1, 0.170394d1,
     & 0.170864d1, 0.171259d1, 0.171608d1, 0.171928d1, 0.172259d1,
     & 0.172531d1, 0.172713d1, 0.172820d1, 0.172842d1, 0.172666d1,
     & 0.172521d1, 0.172514d1, 0.172576d1, 0.172721d1, 0.173086d1,
     & 0.173173d1, 0.173049d1, 0.172704d1, 0.171986d1, 0.169791d1,
     & 0.169566d1, 0.169409d1, 0.169304d1, 0.169243d1, 0.169223d1,
     & 0.169241d1, 0.169299d1, 0.169397d1, 0.169540d1, 0.169735d1,
     & 0.169997d1, 0.170366d1, 0.170990d1, 0.171406d1, 0.171719d1,
     & 0.171977d1, 0.172070d1, 0.172158d1, 0.172241d1, 0.172321d1,
     & 0.172397d1, 0.172469d1, 0.172539d1, 0.172606d1, 0.172670d1,
     & 0.172732d1, 0.172792d1, 0.172849d1, 0.172905d1, 0.172959d1,
     & 0.173011d1, 0.173061d1, 0.173086d1, 0.173110d1, 0.173134d1,
     & 0.173157d1, 0.173180d1, 0.173185d1, 0.173189d1, 0.173194d1/

      data ( a_tm(i), i=1046,1140) /
     & 0.173199d1, 0.173203d1, 0.173208d1, 0.173212d1, 0.173216d1,
     & 0.173217d1, 0.173218d1, 0.173219d1, 0.173221d1, 0.173221d1,
     & 0.173222d1, 0.173222d1, 0.173223d1, 0.173224d1, 0.173229d1,
     & 0.173233d1, 0.173237d1, 0.173242d1, 0.173246d1, 0.173251d1,
     & 0.173255d1, 0.173266d1, 0.173277d1, 0.173287d1, 0.173298d1,
     & 0.173308d1, 0.173319d1, 0.173329d1, 0.173339d1, 0.173360d1,
     & 0.173380d1, 0.173399d1, 0.173419d1, 0.173438d1, 0.173457d1,
     & 0.173475d1, 0.173494d1, 0.173512d1, 0.173529d1, 0.173547d1,
     & 0.173564d1, 0.173581d1, 0.173598d1, 0.173614d1, 0.173631d1,
     & 0.173647d1, 0.173662d1, 0.173678d1, 0.173708d1, 0.173738d1,
     & 0.173766d1, 0.173896d1, 0.174005d1, 0.174093d1, 0.174159d1,
     & 0.174194d1, 0.174189d1, 0.174216d1, 0.174248d1, 0.174281d1,
     & 0.174313d1, 0.174342d1, 0.174368d1, 0.174391d1, 0.174410d1,
     & 0.174425d1, 0.174436d1, 0.174442d1, 0.174444d1, 0.174441d1,
     & 0.174432d1, 0.174417d1, 0.174394d1, 0.174361d1, 0.174315d1,
     & 0.174231d1, 0.174190d1, 0.174160d1, 0.174134d1, 0.174111d1,
     & 0.174090d1, 0.174071d1, 0.174053d1, 0.174036d1, 0.174020d1,
     & 0.174005d1, 0.173991d1, 0.173977d1, 0.173963d1, 0.173949d1,
     & 0.173936d1, 0.173924d1, 0.173911d1, 0.173898d1, 0.173886d1/

      data ( a_tm(i), i=1141,1235) /
     & 0.173873d1, 0.173861d1, 0.173849d1, 0.173836d1, 0.173824d1,
     & 0.173812d1, 0.173799d1, 0.173786d1, 0.173773d1, 0.173760d1,
     & 0.173746d1, 0.173732d1, 0.173718d1, 0.173704d1, 0.173689d1,
     & 0.173674d1, 0.173658d1, 0.173642d1, 0.173625d1, 0.173608d1,
     & 0.173590d1, 0.173571d1, 0.173552d1, 0.173531d1, 0.173510d1,
     & 0.173488d1, 0.173464d1, 0.173439d1, 0.173413d1, 0.173385d1,
     & 0.173355d1, 0.173323d1, 0.173288d1, 0.173251d1, 0.173209d1,
     & 0.173164d1, 0.173113d1, 0.173054d1, 0.172984d1, 0.172895d1,
     & 0.172748d1, 0.172641d1, 0.172569d1, 0.172517d1, 0.172477d1,
     & 0.172449d1, 0.172431d1, 0.172422d1, 0.172421d1, 0.172428d1,
     & 0.172443d1, 0.172467d1, 0.172499d1, 0.172540d1, 0.172590d1,
     & 0.172652d1, 0.172727d1, 0.172817d1, 0.172927d1, 0.173071d1,
     & 0.173308d1, 0.173487d1, 0.173617d1, 0.173723d1, 0.173813d1,
     & 0.173890d1, 0.173958d1, 0.174017d1, 0.174069d1, 0.174114d1,
     & 0.174154d1, 0.174189d1, 0.174219d1, 0.174243d1, 0.174264d1,
     & 0.174280d1, 0.174293d1, 0.174301d1, 0.174305d1, 0.174305d1,
     & 0.174302d1, 0.174294d1, 0.174283d1, 0.174267d1, 0.174248d1,
     & 0.174224d1, 0.174195d1, 0.174162d1, 0.174124d1, 0.174081d1,
     & 0.174032d1, 0.173977d1, 0.173914d1, 0.173844d1, 0.173765d1/

      data ( a_tm(i), i=1236,1330) /
     & 0.173676d1, 0.173573d1, 0.173454d1, 0.173313d1, 0.173133d1,
     & 0.172841d1, 0.172623d1, 0.172467d1, 0.172343d1, 0.172241d1,
     & 0.172156d1, 0.172086d1, 0.172028d1, 0.171981d1, 0.171944d1,
     & 0.171917d1, 0.171898d1, 0.171888d1, 0.171886d1, 0.171893d1,
     & 0.171907d1, 0.171929d1, 0.171959d1, 0.171997d1, 0.172043d1,
     & 0.172098d1, 0.172161d1, 0.172233d1, 0.172314d1, 0.172405d1,
     & 0.172506d1, 0.172619d1, 0.172744d1, 0.172882d1, 0.173034d1,
     & 0.173203d1, 0.173391d1, 0.173600d1, 0.173835d1, 0.174100d1,
     & 0.174405d1, 0.174762d1, 0.175199d1, 0.175786d1, 0.176676d1,
     & 0.177203d1, 0.177367d1, 0.177513d1, 0.177643d1, 0.177759d1,
     & 0.177863d1, 0.177956d1, 0.178038d1, 0.178110d1, 0.178174d1,
     & 0.178228d1, 0.178274d1, 0.178312d1, 0.178341d1, 0.178363d1,
     & 0.178378d1, 0.178382d1, 0.178385d1, 0.178385d1, 0.178384d1,
     & 0.178381d1, 0.178376d1, 0.178369d1, 0.178360d1, 0.178349d1,
     & 0.178337d1, 0.178322d1, 0.178306d1, 0.178288d1, 0.178284d1,
     & 0.178280d1, 0.178276d1, 0.178272d1, 0.178267d1, 0.178263d1,
     & 0.178259d1, 0.178254d1, 0.178250d1, 0.178245d1, 0.178240d1,
     & 0.178239d1, 0.178238d1, 0.178238d1, 0.178237d1, 0.178236d1,
     & 0.178236d1, 0.178235d1, 0.178235d1, 0.178235d1, 0.178234d1/

      data ( a_tm(i), i=1331,1425) /
     & 0.178229d1, 0.178224d1, 0.178219d1, 0.178206d1, 0.178192d1,
     & 0.178164d1, 0.178133d1, 0.178066d1, 0.177990d1, 0.177904d1,
     & 0.177808d1, 0.177703d1, 0.175546d1, 0.173357d1, 0.172323d1,
     & 0.171728d1, 0.171452d1, 0.171489d1, 0.172109d1, 0.172766d1,
     & 0.173024d1, 0.173147d1, 0.173185d1, 0.173158d1, 0.173074d1,
     & 0.172930d1, 0.172718d1, 0.172410d1, 0.171859d1, 0.171324d1,
     & 0.171011d1, 0.170787d1, 0.170625d1, 0.170512d1, 0.170443d1,
     & 0.170415d1, 0.170430d1, 0.170492d1, 0.170610d1, 0.170641d1,
     & 0.170676d1, 0.170713d1, 0.170755d1, 0.170800d1, 0.170850d1,
     & 0.170905d1, 0.170966d1, 0.171034d1, 0.171110d1, 0.171197d1,
     & 0.171298d1, 0.171426d1, 0.171624d1, 0.171768d1, 0.171876d1,
     & 0.171966d1, 0.172042d1, 0.172109d1, 0.172168d1, 0.172219d1,
     & 0.172265d1, 0.172305d1, 0.172339d1, 0.172369d1, 0.172383d1,
     & 0.172395d1, 0.172401d1, 0.172407d1, 0.172412d1, 0.172417d1,
     & 0.172419d1, 0.172421d1, 0.172423d1, 0.172424d1, 0.172425d1,
     & 0.172425d1, 0.172426d1, 0.172427d1, 0.172427d1, 0.172427d1,
     & 0.172427d1, 0.172427d1, 0.172427d1, 0.172427d1, 0.172427d1,
     & 0.172427d1, 0.172427d1, 0.172428d1, 0.172429d1, 0.172430d1,
     & 0.172432d1, 0.172434d1, 0.172438d1, 0.172442d1, 0.172445d1/

      data ( a_tm(i), i=1426,1520) /
     & 0.172448d1, 0.172454d1, 0.172459d1, 0.172467d1, 0.172470d1,
     & 0.172461d1, 0.172384d1, 0.172225d1, 0.171977d1, 0.171618d1,
     & 0.171096d1, 0.170148d1, 0.169212d1, 0.168702d1, 0.168364d1,
     & 0.168145d1, 0.168026d1, 0.167999d1, 0.168066d1, 0.168238d1,
     & 0.168555d1, 0.169232d1, 0.169711d1, 0.170036d1, 0.170293d1,
     & 0.170509d1, 0.170696d1, 0.170861d1, 0.171010d1, 0.171145d1,
     & 0.171270d1, 0.171385d1, 0.171492d1, 0.171593d1, 0.171687d1,
     & 0.171776d1, 0.171860d1, 0.171940d1, 0.172015d1, 0.172087d1,
     & 0.172155d1, 0.172219d1, 0.172281d1, 0.172338d1, 0.172393d1,
     & 0.172445d1, 0.172494d1, 0.172539d1, 0.172581d1, 0.172620d1,
     & 0.172656d1, 0.172689d1, 0.172717d1, 0.172742d1, 0.172763d1,
     & 0.172780d1, 0.172792d1, 0.172799d1, 0.172801d1, 0.172796d1,
     & 0.172785d1, 0.172766d1, 0.172739d1, 0.172702d1, 0.172654d1,
     & 0.172594d1, 0.172518d1, 0.172424d1, 0.172307d1, 0.171087d1,
     & 0.168681d1, 0.173733d1, 0.175855d1, 0.177373d1, 0.178611d1,
     & 0.179684d1, 0.180646d1, 0.181527d1, 0.182348d1, 0.183851d1,
     & 0.185220d1, 0.186491d1, 0.187685d1, 0.188818d1, 0.198239d1,
     & 0.205860d1, 0.212513d1, 0.218502d1, 0.223986d1, 0.229062d1,
     & 0.233796d1, 0.238248d1, 0.242446d1, 0.246419d1, 0.250194d1/

      data ( a_tm(i), i=1521,1542) /
     & 0.253791d1, 0.257226d1, 0.260516d1, 0.263672d1, 0.266704d1,
     & 0.269624d1, 0.272439d1, 0.285176d1, 0.296145d1, 0.305785d1,
     & 0.314384d1, 0.322147d1, 0.329223d1, 0.335725d1, 0.341738d1,
     & 0.347332d1, 0.352560d1, 0.357468d1, 0.362093d1, 0.363150d1,
     & 0.366467d1, 0.370614d1/


      data  ( da_tm(i), i=   1,  95) /
     & 0.800000d-6, 0.320000d-5, 0.720000d-5, 0.128000d-4, 0.200000d-4,
     & 0.288000d-4, 0.393000d-4, 0.514000d-4, 0.653000d-4, 0.809000d-4,
     & 0.983000d-4, 0.117500d-3, 0.138500d-3, 0.161500d-3, 0.186500d-3,
     & 0.213500d-3, 0.242800d-3, 0.274300d-3, 0.308200d-3, 0.344600d-3,
     & 0.383800d-3, 0.426000d-3, 0.471500d-3, 0.520600d-3, 0.574000d-3,
     & 0.632200d-3, 0.696600d-3, 0.840500d-3, 0.105790d-2, 0.144900d-2,
     & 0.159380d-2, 0.290160d-2, 0.325870d-2, 0.315450d-2, 0.377170d-2,
     & 0.471270d-2, 0.874420d-2, 0.722540d-2, 0.625900d-2, 0.904680d-2,
     & 0.106611d-1, 0.116108d-1, 0.121965d-1, 0.113937d-1, 0.115813d-1,
     & 0.101389d-1, 0.113337d-1, 0.106904d-1, 0.108268d-1, 0.106188d-1,
     & 0.105789d-1, 0.112305d-1, 0.117596d-1, 0.108296d-1, 0.119356d-1,
     & 0.119825d-1, 0.118688d-1, 0.121649d-1, 0.127853d-1, 0.122116d-1,
     & 0.131932d-1, 0.128244d-1, 0.128283d-1, 0.134781d-1, 0.134266d-1,
     & 0.146332d-1, 0.167460d-1, 0.145811d-1, 0.136219d-1, 0.138198d-1,
     & 0.153453d-1, 0.181867d-1, 0.203059d-1, 0.216225d-1, 0.217267d-1,
     & 0.224299d-1, 0.227771d-1, 0.233518d-1, 0.254999d-1, 0.263009d-1,
     & 0.280305d-1, 0.299554d-1, 0.322816d-1, 0.383525d-1, 0.388812d-1,
     & 0.395382d-1, 0.401873d-1, 0.408135d-1, 0.415224d-1, 0.425848d-1,
     & 0.448463d-1, 0.533273d-1, 0.545712d-1, 0.516094d-1, 0.525128d-1/

      data ( da_tm(i), i=  96, 190) /
     & 0.534847d-1, 0.542106d-1, 0.547290d-1, 0.552574d-1, 0.563206d-1,
     & 0.594100d-1, 0.710471d-1, 0.906107d-1, 0.717788d-1, 0.759486d-1,
     & 0.761904d-1, 0.885063d-1, 0.913454d-1, 0.840290d-1, 0.854693d-1,
     & 0.825364d-1, 0.845393d-1, 0.813888d-1, 0.717945d-1, 0.694140d-1,
     & 0.682757d-1, 0.657860d-1, 0.558977d-1, 0.598866d-1, 0.596036d-1,
     & 0.689129d-1, 0.688794d-1, 0.508131d-1, 0.489944d-1, 0.495822d-1,
     & 0.505074d-1, 0.511523d-1, 0.513107d-1, 0.509920d-1, 0.505889d-1,
     & 0.531027d-1, 0.589639d-1, 0.452031d-1, 0.424983d-1, 0.413712d-1,
     & 0.405504d-1, 0.396734d-1, 0.386934d-1, 0.382852d-1, 0.406532d-1,
     & 0.343191d-1, 0.323504d-1, 0.303849d-1, 0.290772d-1, 0.279077d-1,
     & 0.267228d-1, 0.274292d-1, 0.240622d-1, 0.230730d-1, 0.224082d-1,
     & 0.219192d-1, 0.214825d-1, 0.210435d-1, 0.205784d-1, 0.200830d-1,
     & 0.196090d-1, 0.200787d-1, 0.187185d-1, 0.183989d-1, 0.181948d-1,
     & 0.180153d-1, 0.178409d-1, 0.177195d-1, 0.176452d-1, 0.175914d-1,
     & 0.175943d-1, 0.178629d-1, 0.181227d-1, 0.180815d-1, 0.175901d-1,
     & 0.166544d-1, 0.158181d-1, 0.161593d-1, 0.164834d-1, 0.169593d-1,
     & 0.175539d-1, 0.194322d-1, 0.198887d-1, 0.173015d-1, 0.177512d-1,
     & 0.175114d-1, 0.163983d-1, 0.158272d-1, 0.156290d-1, 0.152997d-1,
     & 0.147553d-1, 0.146220d-1, 0.149464d-1, 0.151192d-1, 0.151438d-1/

      data ( da_tm(i), i= 191, 285) /
     & 0.148386d-1, 0.142307d-1, 0.141716d-1, 0.141592d-1, 0.141623d-1,
     & 0.141535d-1, 0.142601d-1, 0.145138d-1, 0.146994d-1, 0.148746d-1,
     & 0.153388d-1, 0.160760d-1, 0.155623d-1, 0.140337d-1, 0.151053d-1,
     & 0.152091d-1, 0.145997d-1, 0.141957d-1, 0.140736d-1, 0.140120d-1,
     & 0.139284d-1, 0.141508d-1, 0.143035d-1, 0.142286d-1, 0.139804d-1,
     & 0.146862d-1, 0.144774d-1, 0.144542d-1, 0.143336d-1, 0.147347d-1,
     & 0.153530d-1, 0.163831d-1, 0.159257d-1, 0.170188d-1, 0.173105d-1,
     & 0.186117d-1, 0.202044d-1, 0.201677d-1, 0.230061d-1, 0.274305d-1,
     & 0.252088d-1, 0.279998d-1, 0.286158d-1, 0.333016d-1, 0.370263d-1,
     & 0.421488d-1, 0.504105d-1, 0.662342d-1, 0.112766d0, 0.214109d0,
     & 0.204249d0, 0.171976d0, 0.159987d0, 0.191323d0, 0.223919d0,
     & 0.235825d0, 0.238149d0, 0.245302d0, 0.248043d0, 0.325291d0,
     & 0.413216d0, 0.544530d0, 0.716329d0, 0.764856d0, 0.577993d0,
     & 0.512073d0, 0.240128d0, 0.237518d0, 0.377895d0, 0.273782d0,
     & 0.274295d0, 0.300875d0, 0.355471d0, 0.214735d0, 0.178529d0,
     & 0.176270d0, 0.181596d0, 0.187152d0, 0.187346d0, 0.169683d0,
     & 0.642610d-1, 0.430241d-1, 0.344411d-1, 0.306814d-1, 0.321276d-1,
     & 0.279572d-1, 0.284508d-1, 0.280504d-1, 0.223397d-1, 0.228636d-1,
     & 0.198338d-1, 0.190678d-1, 0.194812d-1, 0.210406d-1, 0.216904d-1/

      data ( da_tm(i), i= 286, 380) /
     & 0.199712d-1, 0.201510d-1, 0.184599d-1, 0.185676d-1, 0.186776d-1,
     & 0.191346d-1, 0.196260d-1, 0.199528d-1, 0.206413d-1, 0.212251d-1,
     & 0.221425d-1, 0.229894d-1, 0.241262d-1, 0.254540d-1, 0.269024d-1,
     & 0.282602d-1, 0.305995d-1, 0.323916d-1, 0.350187d-1, 0.404297d-1,
     & 0.433046d-1, 0.471669d-1, 0.510996d-1, 0.594680d-1, 0.834897d-1,
     & 0.746252d-1, 0.657684d-1, 0.609714d-1, 0.561509d-1, 0.523901d-1,
     & 0.463817d-1, 0.457661d-1, 0.413846d-1, 0.378287d-1, 0.329483d-1,
     & 0.318976d-1, 0.318247d-1, 0.268193d-1, 0.312424d-1, 0.294825d-1,
     & 0.294767d-1, 0.313407d-1, 0.275506d-1, 0.314809d-1, 0.308685d-1,
     & 0.287332d-1, 0.321316d-1, 0.281867d-1, 0.304816d-1, 0.321356d-1,
     & 0.305679d-1, 0.332029d-1, 0.339072d-1, 0.395256d-1, 0.396062d-1,
     & 0.394927d-1, 0.452982d-1, 0.462078d-1, 0.494693d-1, 0.528139d-1,
     & 0.561152d-1, 0.714393d-1, 0.717470d-1, 0.732385d-1, 0.713502d-1,
     & 0.626217d-1, 0.844766d-1, 0.902218d-1, 0.106922d0, 0.117320d0,
     & 0.715792d-1, 0.721394d-1, 0.837762d-1, 0.903971d-1, 0.910321d-1,
     & 0.907488d-1, 0.101778d0, 0.943705d-1, 0.920302d-1, 0.984165d-1,
     & 0.101390d0, 0.116734d0, 0.872399d-1, 0.651192d-1, 0.587024d-1,
     & 0.560139d-1, 0.545553d-1, 0.533120d-1, 0.484958d-1, 0.417940d-1,
     & 0.457784d-1, 0.477782d-1, 0.460040d-1, 0.473271d-1, 0.508755d-1/

      data ( da_tm(i), i= 381, 475) /
     & 0.423773d-1, 0.471114d-1, 0.408117d-1, 0.410177d-1, 0.382904d-1,
     & 0.433500d-1, 0.393031d-1, 0.448852d-1, 0.409196d-1, 0.487294d-1,
     & 0.538899d-1, 0.545496d-1, 0.552771d-1, 0.560700d-1, 0.569274d-1,
     & 0.578500d-1, 0.588396d-1, 0.598990d-1, 0.610319d-1, 0.622427d-1,
     & 0.635371d-1, 0.649214d-1, 0.664032d-1, 0.679912d-1, 0.696955d-1,
     & 0.715276d-1, 0.735010d-1, 0.756310d-1, 0.779357d-1, 0.804357d-1,
     & 0.831553d-1, 0.861231d-1, 0.893725d-1, 0.929434d-1, 0.968836d-1,
     & 0.101250d0, 0.106114d0, 0.111559d0, 0.117693d0, 0.124649d0,
     & 0.132598d0, 0.141760d0, 0.152425d0, 0.155369d0, 0.158438d0,
     & 0.161640d0, 0.164984d0, 0.168479d0, 0.172134d0, 0.175962d0,
     & 0.179975d0, 0.184186d0, 0.188609d0, 0.193262d0, 0.198161d0,
     & 0.203327d0, 0.208782d0, 0.214550d0, 0.220658d0, 0.227138d0,
     & 0.234024d0, 0.241354d0, 0.249173d0, 0.257531d0, 0.266484d0,
     & 0.276098d0, 0.286449d0, 0.297622d0, 0.309721d0, 0.322863d0,
     & 0.337190d0, 0.352867d0, 0.370093d0, 0.389110d0, 0.410211d0,
     & 0.433756d0, 0.460194d0, 0.490094d0, 0.524179d0, 0.563395d0,
     & 0.608993d0, 0.662669d0, 0.726781d0, 0.804706d0, 0.901465d0,
     & 0.102486d1, 0.118772d1, 0.141280d1, 0.156113d1, 0.174479d1,
     & 0.197832d1, 0.228564d1, 0.270919d1, 0.333220d1, 0.434338d1/

      data ( da_tm(i), i= 476, 570) /
     & 0.627538d1, 0.764364d1, 0.975968d1, 0.133775d2, 0.301545d2,
     & 0.420948d2, 0.625481d2, 0.941448d2, 0.645355d2, 0.254415d3,
     & 0.717240d3, 0.494734d3, 0.781115d2, 0.992515d2, 0.430703d2,
     & 0.222554d2, 0.141183d2, 0.101355d2, 0.785961d1, 0.641170d1,
     & 0.541683d1, 0.469323d1, 0.414368d1, 0.371208d1, 0.295164d1,
     & 0.245471d1, 0.210356d1, 0.184172d1, 0.163868d1, 0.147648d1,
     & 0.134384d1, 0.123329d1, 0.105947d1, 0.928932d0, 0.827250d0,
     & 0.745786d0, 0.679046d0, 0.623363d0, 0.576199d0, 0.535736d0,
     & 0.500642d0, 0.469915d0, 0.442789d0, 0.418667d0, 0.397076d0,
     & 0.377640d0, 0.360052d0, 0.344062d0, 0.329461d0, 0.316078d0,
     & 0.303766d0, 0.292403d0, 0.281884d0, 0.272119d0, 0.263029d0,
     & 0.254549d0, 0.246618d0, 0.239186d0, 0.232208d0, 0.225643d0,
     & 0.219456d0, 0.213617d0, 0.208096d0, 0.202869d0, 0.197913d0,
     & 0.193209d0, 0.188736d0, 0.184480d0, 0.180425d0, 0.176557d0,
     & 0.172863d0, 0.169333d0, 0.162723d0, 0.156652d0, 0.151059d0,
     & 0.145889d0, 0.141098d0, 0.136646d0, 0.132499d0, 0.128629d0,
     & 0.125007d0, 0.121613d0, 0.118425d0, 0.115426d0, 0.112600d0,
     & 0.109933d0, 0.107412d0, 0.105026d0, 0.102764d0, 0.100618d0,
     & 0.985783d-1, 0.966380d-1, 0.947900d-1, 0.930281d-1, 0.913464d-1/

      data ( da_tm(i), i= 571, 665) /
     & 0.897399d-1, 0.882035d-1, 0.867329d-1, 0.853240d-1, 0.839731d-1,
     & 0.826766d-1, 0.814314d-1, 0.802345d-1, 0.790831d-1, 0.779747d-1,
     & 0.769069d-1, 0.758774d-1, 0.748842d-1, 0.739254d-1, 0.729992d-1,
     & 0.721038d-1, 0.712378d-1, 0.703996d-1, 0.695878d-1, 0.688012d-1,
     & 0.680384d-1, 0.672985d-1, 0.665802d-1, 0.658825d-1, 0.652045d-1,
     & 0.645453d-1, 0.639040d-1, 0.632798d-1, 0.626720d-1, 0.620797d-1,
     & 0.615023d-1, 0.609393d-1, 0.603898d-1, 0.598534d-1, 0.593295d-1,
     & 0.588176d-1, 0.583171d-1, 0.578277d-1, 0.573487d-1, 0.568799d-1,
     & 0.564207d-1, 0.559708d-1, 0.555298d-1, 0.550974d-1, 0.546732d-1,
     & 0.542569d-1, 0.538481d-1, 0.534465d-1, 0.530518d-1, 0.526638d-1,
     & 0.522820d-1, 0.519061d-1, 0.515358d-1, 0.511703d-1, 0.508090d-1,
     & 0.504498d-1, 0.499012d-1, 0.470925d-1, 0.449828d-1, 0.433059d-1,
     & 0.419322d-1, 0.407755d-1, 0.397736d-1, 0.388806d-1, 0.380619d-1,
     & 0.372913d-1, 0.365493d-1, 0.358218d-1, 0.350998d-1, 0.343792d-1,
     & 0.336614d-1, 0.329554d-1, 0.322811d-1, 0.316760d-1, 0.312114d-1,
     & 0.310381d-1, 0.317617d-1, 0.344865d-1, 0.364865d-1, 0.378130d-1,
     & 0.385190d-1, 0.387233d-1, 0.386915d-1, 0.391970d-1, 0.435423d-1,
     & 0.477467d-1, 0.508659d-1, 0.515533d-1, 0.522408d-1, 0.529583d-1,
     & 0.537469d-1, 0.546640d-1, 0.557915d-1, 0.572485d-1, 0.592113d-1/

      data ( da_tm(i), i= 666, 760) /
     & 0.619429d-1, 0.657580d-1, 0.720170d-1, 0.818310d-1, 0.976951d-1,
     & 0.125420d0, 0.181374d0, 0.199909d0, 0.222940d0, 0.252304d0,
     & 0.291010d0, 0.344360d0, 0.422678d0, 0.549219d0, 0.789958d0,
     & 0.143042d1, 0.587475d1, 0.604933d1, 0.895461d1, 0.137208d2,
     & 0.144517d2, 0.374538d2, 0.985154d2, 0.694959d2, 0.156963d2,
     & 0.143876d2, 0.399950d1, 0.192729d1, 0.124224d1, 0.917105d0,
     & 0.606300d0, 0.455499d0, 0.365954d0, 0.306461d0, 0.264007d0,
     & 0.232174d0, 0.207427d0, 0.187655d0, 0.171539d0, 0.158221d0,
     & 0.146960d0, 0.137329d0, 0.129002d0, 0.121728d0, 0.115318d0,
     & 0.109620d0, 0.104516d0, 0.999115d-1, 0.957292d-1, 0.919070d-1,
     & 0.883953d-1, 0.851563d-1, 0.730072d-1, 0.649773d-1, 0.586868d-1,
     & 0.544781d-1, 0.514128d-1, 0.477580d-1, 0.480703d-1, 0.486293d-1,
     & 0.474910d-1, 0.458605d-1, 0.473941d-1, 0.434453d-1, 0.465943d-1,
     & 0.423767d-1, 0.455853d-1, 0.409622d-1, 0.406077d-1, 0.353045d-1,
     & 0.388223d-1, 0.352284d-1, 0.339294d-1, 0.359199d-1, 0.361139d-1,
     & 0.384958d-1, 0.370852d-1, 0.445929d-1, 0.501013d-1, 0.498306d-1,
     & 0.449258d-1, 0.478795d-1, 0.482459d-1, 0.425395d-1, 0.416707d-1,
     & 0.404422d-1, 0.406670d-1, 0.376249d-1, 0.415518d-1, 0.445944d-1,
     & 0.465787d-1, 0.419233d-1, 0.393693d-1, 0.392126d-1, 0.423556d-1/

      data ( da_tm(i), i= 761, 855) /
     & 0.444212d-1, 0.426665d-1, 0.405652d-1, 0.374717d-1, 0.391161d-1,
     & 0.397555d-1, 0.391872d-1, 0.399860d-1, 0.398546d-1, 0.378709d-1,
     & 0.373986d-1, 0.385724d-1, 0.389627d-1, 0.407973d-1, 0.387815d-1,
     & 0.358300d-1, 0.380533d-1, 0.364194d-1, 0.351619d-1, 0.586997d-1,
     & 0.554410d-1, 0.463628d-1, 0.619478d-1, 0.465535d-1, 0.431938d-1,
     & 0.465579d-1, 0.494885d-1, 0.482789d-1, 0.855487d-1, 0.565688d-1,
     & 0.561538d-1, 0.568615d-1, 0.575046d-1, 0.621980d-1, 0.530837d-1,
     & 0.484465d-1, 0.495201d-1, 0.509817d-1, 0.520203d-1, 0.524356d-1,
     & 0.522067d-1, 0.514147d-1, 0.502843d-1, 0.494020d-1, 0.513027d-1,
     & 0.570520d-1, 0.616915d-1, 0.651977d-1, 0.675927d-1, 0.689074d-1,
     & 0.691542d-1, 0.683198d-1, 0.663626d-1, 0.632093d-1, 0.584354d-1,
     & 0.568487d-1, 0.569750d-1, 0.572096d-1, 0.571354d-1, 0.565970d-1,
     & 0.555715d-1, 0.541806d-1, 0.528520d-1, 0.529568d-1, 0.627301d-1,
     & 0.742548d-1, 0.712248d-1, 0.540713d-1, 0.486064d-1, 0.463622d-1,
     & 0.452620d-1, 0.446054d-1, 0.440727d-1, 0.434974d-1, 0.427870d-1,
     & 0.418924d-1, 0.407978d-1, 0.395309d-1, 0.382128d-1, 0.373816d-1,
     & 0.382562d-1, 0.393834d-1, 0.403985d-1, 0.411879d-1, 0.417033d-1,
     & 0.419213d-1, 0.418302d-1, 0.414248d-1, 0.407079d-1, 0.396964d-1,
     & 0.371130d-1, 0.376087d-1, 0.395175d-1, 0.406142d-1, 0.405934d-1/

      data ( da_tm(i), i= 856, 950) /
     & 0.393916d-1, 0.371811d-1, 0.365572d-1, 0.382658d-1, 0.393465d-1,
     & 0.394009d-1, 0.383494d-1, 0.363089d-1, 0.349129d-1, 0.368812d-1,
     & 0.385729d-1, 0.393931d-1, 0.392403d-1, 0.381868d-1, 0.369256d-1,
     & 0.385553d-1, 0.400622d-1, 0.407509d-1, 0.405690d-1, 0.396918d-1,
     & 0.389649d-1, 0.420421d-1, 0.449001d-1, 0.464545d-1, 0.465318d-1,
     & 0.459517d-1, 0.448880d-1, 0.431858d-1, 0.408684d-1, 0.401599d-1,
     & 0.398684d-1, 0.397069d-1, 0.395756d-1, 0.394425d-1, 0.393165d-1,
     & 0.392431d-1, 0.393132d-1, 0.396854d-1, 0.406326d-1, 0.426458d-1,
     & 0.467249d-1, 0.557658d-1, 0.781066d-1, 0.803948d-1, 0.629239d-1,
     & 0.548893d-1, 0.552041d-1, 0.557271d-1, 0.567138d-1, 0.612087d-1,
     & 0.596096d-1, 0.573774d-1, 0.637530d-1, 0.628632d-1, 0.541002d-1,
     & 0.552699d-1, 0.575476d-1, 0.573478d-1, 0.544492d-1, 0.512157d-1,
     & 0.559345d-1, 0.588483d-1, 0.586824d-1, 0.555038d-1, 0.514830d-1,
     & 0.558147d-1, 0.586912d-1, 0.585203d-1, 0.553166d-1, 0.513307d-1,
     & 0.558536d-1, 0.587903d-1, 0.585718d-1, 0.552180d-1, 0.510419d-1,
     & 0.556512d-1, 0.585701d-1, 0.581384d-1, 0.542179d-1, 0.482289d-1,
     & 0.518522d-1, 0.551378d-1, 0.556550d-1, 0.531241d-1, 0.483638d-1,
     & 0.504158d-1, 0.521841d-1, 0.516956d-1, 0.487962d-1, 0.452182d-1,
     & 0.486456d-1, 0.508339d-1, 0.503690d-1, 0.471444d-1, 0.426037d-1/

      data ( da_tm(i), i= 951,1045) /
     & 0.463451d-1, 0.492895d-1, 0.494501d-1, 0.464492d-1, 0.454778d-1,
     & 0.454578d-1, 0.443544d-1, 0.420340d-1, 0.390442d-1, 0.399002d-1,
     & 0.471456d-1, 0.504787d-1, 0.502519d-1, 0.464975d-1, 0.393701d-1,
     & 0.410671d-1, 0.441505d-1, 0.454850d-1, 0.444359d-1, 0.398815d-1,
     & 0.380671d-1, 0.377075d-1, 0.369976d-1, 0.356346d-1, 0.340191d-1,
     & 0.348609d-1, 0.356839d-1, 0.358820d-1, 0.354656d-1, 0.351145d-1,
     & 0.370664d-1, 0.378856d-1, 0.374112d-1, 0.358747d-1, 0.350167d-1,
     & 0.381074d-1, 0.399404d-1, 0.401203d-1, 0.387586d-1, 0.370249d-1,
     & 0.392984d-1, 0.408046d-1, 0.407399d-1, 0.390979d-1, 0.368247d-1,
     & 0.389254d-1, 0.405849d-1, 0.407348d-1, 0.392159d-1, 0.370620d-1,
     & 0.379135d-1, 0.387550d-1, 0.391580d-1, 0.395193d-1, 0.444832d-1,
     & 0.452505d-1, 0.457951d-1, 0.461549d-1, 0.463508d-1, 0.463971d-1,
     & 0.463054d-1, 0.460868d-1, 0.457542d-1, 0.453238d-1, 0.448179d-1,
     & 0.442664d-1, 0.436917d-1, 0.430482d-1, 0.438854d-1, 0.458990d-1,
     & 0.493563d-1, 0.513027d-1, 0.536856d-1, 0.566187d-1, 0.602558d-1,
     & 0.648077d-1, 0.705673d-1, 0.779498d-1, 0.875570d-1, 0.100287d0,
     & 0.117527d0, 0.141513d0, 0.176048d0, 0.228033d0, 0.311096d0,
     & 0.455361d0, 0.738894d0, 0.996347d0, 0.142022d1, 0.219233d1,
     & 0.383349d1, 0.839277d1, 0.102779d2, 0.128843d2, 0.166366d2/

      data ( da_tm(i), i=1046,1140) /
     & 0.223299d2, 0.316047d2, 0.483385d2, 0.838070d2, 0.161580d3,
     & 0.211046d3, 0.287756d3, 0.409124d3, 0.529059d3, 0.393408d3,
     & 0.133603d3, 0.661097d3, 0.798942d3, 0.687683d3, 0.532326d3,
     & 0.411095d3, 0.246397d3, 0.100480d3, 0.552048d2, 0.351100d2,
     & 0.243649d2, 0.121937d2, 0.732057d1, 0.488371d1, 0.349131d1,
     & 0.262118d1, 0.204119d1, 0.163526d1, 0.134011d1, 0.948597d0,
     & 0.708000d0, 0.549698d0, 0.440072d0, 0.361076d0, 0.302317d0,
     & 0.257464d0, 0.222485d0, 0.194710d0, 0.172313d0, 0.154015d0,
     & 0.138894d0, 0.126273d0, 0.115646d0, 0.106629d0, 0.989245d-1,
     & 0.923010d-1, 0.865747d-1, 0.815988d-1, 0.734460d-1, 0.671305d-1,
     & 0.621661d-1, 0.485037d-1, 0.428851d-1, 0.399823d-1, 0.381942d-1,
     & 0.370274d-1, 0.366986d-1, 0.368475d-1, 0.371495d-1, 0.375047d-1,
     & 0.378627d-1, 0.381946d-1, 0.384834d-1, 0.387188d-1, 0.388943d-1,
     & 0.390057d-1, 0.390507d-1, 0.390281d-1, 0.389375d-1, 0.387794d-1,
     & 0.385552d-1, 0.382675d-1, 0.379207d-1, 0.375220d-1, 0.370823d-1,
     & 0.365821d-1, 0.364956d-1, 0.365097d-1, 0.365750d-1, 0.366726d-1,
     & 0.367921d-1, 0.369267d-1, 0.370716d-1, 0.372235d-1, 0.373795d-1,
     & 0.375378d-1, 0.376965d-1, 0.378545d-1, 0.380106d-1, 0.381640d-1,
     & 0.383139d-1, 0.384599d-1, 0.386013d-1, 0.387378d-1, 0.388690d-1/

      data ( da_tm(i), i=1141,1235) /
     & 0.389948d-1, 0.391148d-1, 0.392290d-1, 0.393371d-1, 0.394392d-1,
     & 0.395351d-1, 0.396248d-1, 0.397084d-1, 0.397858d-1, 0.398572d-1,
     & 0.399227d-1, 0.399822d-1, 0.400361d-1, 0.400845d-1, 0.401276d-1,
     & 0.401656d-1, 0.401989d-1, 0.402278d-1, 0.402527d-1, 0.402741d-1,
     & 0.402925d-1, 0.403084d-1, 0.403227d-1, 0.403362d-1, 0.403498d-1,
     & 0.403646d-1, 0.403819d-1, 0.404035d-1, 0.404310d-1, 0.404669d-1,
     & 0.405140d-1, 0.405756d-1, 0.406562d-1, 0.407613d-1, 0.408984d-1,
     & 0.410774d-1, 0.413128d-1, 0.416268d-1, 0.420574d-1, 0.426880d-1,
     & 0.439083d-1, 0.449980d-1, 0.458567d-1, 0.465802d-1, 0.471940d-1,
     & 0.477099d-1, 0.481347d-1, 0.484730d-1, 0.487279d-1, 0.489017d-1,
     & 0.489959d-1, 0.490118d-1, 0.489501d-1, 0.488112d-1, 0.485952d-1,
     & 0.483017d-1, 0.479299d-1, 0.474774d-1, 0.469387d-1, 0.462949d-1,
     & 0.454019d-1, 0.449858d-1, 0.448474d-1, 0.448385d-1, 0.449071d-1,
     & 0.450256d-1, 0.451772d-1, 0.453504d-1, 0.455373d-1, 0.457319d-1,
     & 0.459299d-1, 0.461280d-1, 0.463237d-1, 0.465149d-1, 0.467001d-1,
     & 0.468782d-1, 0.470483d-1, 0.472097d-1, 0.473619d-1, 0.475046d-1,
     & 0.476378d-1, 0.477613d-1, 0.478753d-1, 0.479800d-1, 0.480757d-1,
     & 0.481630d-1, 0.482424d-1, 0.483147d-1, 0.483808d-1, 0.484418d-1,
     & 0.484991d-1, 0.485543d-1, 0.486096d-1, 0.486674d-1, 0.487309d-1/

      data ( da_tm(i), i=1236,1330) /
     & 0.488045d-1, 0.488937d-1, 0.490069d-1, 0.491571d-1, 0.493698d-1,
     & 0.497450d-1, 0.501988d-1, 0.506564d-1, 0.511171d-1, 0.515778d-1,
     & 0.520363d-1, 0.524912d-1, 0.529417d-1, 0.533878d-1, 0.538294d-1,
     & 0.542672d-1, 0.547019d-1, 0.551346d-1, 0.555665d-1, 0.559992d-1,
     & 0.564347d-1, 0.568751d-1, 0.573230d-1, 0.577813d-1, 0.582535d-1,
     & 0.587436d-1, 0.592563d-1, 0.597968d-1, 0.603718d-1, 0.609886d-1,
     & 0.616562d-1, 0.623854d-1, 0.631891d-1, 0.640833d-1, 0.650876d-1,
     & 0.662267d-1, 0.675322d-1, 0.690457d-1, 0.708232d-1, 0.729434d-1,
     & 0.755236d-1, 0.787548d-1, 0.829982d-1, 0.892370d-1, 0.996284d-1,
     & 0.105587d0, 0.107386d0, 0.108959d0, 0.110347d0, 0.111585d0,
     & 0.112705d0, 0.113743d0, 0.114742d0, 0.115759d0, 0.116872d0,
     & 0.118202d0, 0.119934d0, 0.122374d0, 0.126039d0, 0.131840d0,
     & 0.141441d0, 0.148562d0, 0.158003d0, 0.170650d0, 0.187786d0,
     & 0.211302d0, 0.244078d0, 0.290682d0, 0.358746d0, 0.461898d0,
     & 0.626596d0, 0.910168d0, 0.145724d1, 0.272772d1, 0.318201d1,
     & 0.376152d1, 0.451721d1, 0.552910d1, 0.692905d1, 0.894742d1,
     & 0.120187d2, 0.170506d2, 0.262416d2, 0.463129d2, 0.109378d3,
     & 0.151704d3, 0.193041d3, 0.256013d3, 0.354339d3, 0.453740d3,
     & 0.353896d3, 0.515360d2, 0.456274d3, 0.556753d3, 0.458441d3/

      data ( da_tm(i), i=1331,1425) /
     & 0.208912d3, 0.265795d3, 0.428474d3, 0.311973d2, 0.114198d2,
     & 0.365394d1, 0.179025d1, 0.709159d0, 0.387044d0, 0.252087d0,
     & 0.184709d0, 0.147110d0, 0.570248d-1, 0.653453d-1, 0.843646d-1,
     & 0.969878d-1, 0.102644d0, 0.100787d0, 0.859544d-1, 0.730802d-1,
     & 0.690991d-1, 0.674565d-1, 0.667629d-1, 0.664463d-1, 0.662358d-1,
     & 0.660038d-1, 0.657095d-1, 0.653929d-1, 0.652441d-1, 0.665105d-1,
     & 0.683687d-1, 0.703949d-1, 0.724924d-1, 0.746441d-1, 0.768747d-1,
     & 0.792432d-1, 0.818488d-1, 0.848502d-1, 0.885129d-1, 0.893616d-1,
     & 0.902605d-1, 0.912163d-1, 0.922370d-1, 0.933322d-1, 0.945140d-1,
     & 0.957974d-1, 0.972021d-1, 0.987549d-1, 0.100494d0, 0.102477d0,
     & 0.104809d0, 0.107728d0, 0.112291d0, 0.115731d0, 0.118434d0,
     & 0.120793d0, 0.122984d0, 0.125168d0, 0.127588d0, 0.130720d0,
     & 0.135679d0, 0.145495d0, 0.169696d0, 0.243355d0, 0.336194d0,
     & 0.537087d0, 0.731153d0, 0.106690d1, 0.171981d1, 0.326102d1,
     & 0.454066d1, 0.678263d1, 0.113203d2, 0.156396d2, 0.232632d2,
     & 0.392433d2, 0.873484d2, 0.198453d3, 0.247130d3, 0.320616d3,
     & 0.434581d3, 0.550188d3, 0.437767d3, 0.231748d2, 0.483715d3,
     & 0.596379d3, 0.480975d3, 0.126203d3, 0.939161d2, 0.100481d3,
     & 0.141181d3, 0.220292d2, 0.535460d1, 0.241793d1, 0.138150d1/

      data ( da_tm(i), i=1426,1520) /
     & 0.898385d0, 0.478312d0, 0.310321d0, 0.176627d0, 0.145923d0,
     & 0.132336d0, 0.125463d0, 0.118547d0, 0.109013d0, 0.960362d-1,
     & 0.783208d-1, 0.510560d-1, 0.392776d-1, 0.446457d-1, 0.523328d-1,
     & 0.587354d-1, 0.629916d-1, 0.648467d-1, 0.641255d-1, 0.605504d-1,
     & 0.535407d-1, 0.414707d-1, 0.397014d-1, 0.436119d-1, 0.523064d-1,
     & 0.697091d-1, 0.925633d-1, 0.707458d-1, 0.592931d-1, 0.559976d-1,
     & 0.555271d-1, 0.559703d-1, 0.566933d-1, 0.574588d-1, 0.581687d-1,
     & 0.587800d-1, 0.592745d-1, 0.596455d-1, 0.598920d-1, 0.600166d-1,
     & 0.600237d-1, 0.599186d-1, 0.597078d-1, 0.593983d-1, 0.589972d-1,
     & 0.585107d-1, 0.579425d-1, 0.572896d-1, 0.565363d-1, 0.556459d-1,
     & 0.545599d-1, 0.532325d-1, 0.517411d-1, 0.504006d-1, 0.495145d-1,
     & 0.487637d-1, 0.474962d-1, 0.457387d-1, 0.439975d-1, 0.425343d-1,
     & 0.413675d-1, 0.405306d-1, 0.401419d-1, 0.403662d-1, 0.413686d-1,
     & 0.432796d-1, 0.461648d-1, 0.500224d-1, 0.549200d-1, 0.103889d0,
     & 0.201930d0, 0.112305d0, 0.875984d-1, 0.743705d-1, 0.658558d-1,
     & 0.598349d-1, 0.553217d-1, 0.517998d-1, 0.489687d-1, 0.446895d-1,
     & 0.416020d-1, 0.392657d-1, 0.374343d-1, 0.359588d-1, 0.291402d-1,
     & 0.267276d-1, 0.254567d-1, 0.246620d-1, 0.241158d-1, 0.237172d-1,
     & 0.234141d-1, 0.231753d-1, 0.229838d-1, 0.228270d-1, 0.226970d-1/

      data ( da_tm(i), i=1521,1542) /
     & 0.225874d-1, 0.224941d-1, 0.224139d-1, 0.223444d-1, 0.222836d-1,
     & 0.222302d-1, 0.221830d-1, 0.220123d-1, 0.219082d-1, 0.218401d-1,
     & 0.217936d-1, 0.217604d-1, 0.217360d-1, 0.217178d-1, 0.217039d-1,
     & 0.216932d-1, 0.216848d-1, 0.216781d-1, 0.216729d-1, 0.216720d-1,
     & 0.216687d-1, 0.216653d-1/
c begin ====================================================

      if ( ( w_input .lt. w(1) ) .or. ( w(IMAX) .lt. w_input ) ) then
ctt
         write(*,*) "ERROR: w outside range of Delta alpha tabulation"
         a_sp_out  =  0.d0
         da_sp_out = 0.d0
         a_tm_out  =  0.d0
         da_tm_out = 0.d0
         return
      endif

      if ( w_input .eq. w(IMAX) ) then
         a_sp_out  =  a_sp(IMAX)
         da_sp_out = da_sp(IMAX)
         a_tm_out  =  a_tm(IMAX)
         da_tm_out = da_tm(IMAX)
         return
      endif

      do i = 1, IMAX - 1

         if ( ( w(i) .le. w_input ) .and. ( w_input .lt. w(i+1) ) ) then

            a_sp_out =   ( a_sp( i+1 ) -  a_sp( i ) )
     &                / ( w( i+1 ) - w( i ) ) * ( w_input - w( i ) )
     &                + a_sp( i )

            da_sp_out =   ( da_sp( i+1 ) - da_sp( i ) )
     &                / ( w( i+1 ) - w( i ) ) * ( w_input - w( i ) )
     &                + da_sp( i )

            a_tm_out =   ( a_tm( i+1 ) -  a_tm( i ) )
     &                / ( w( i+1 ) - w( i ) ) * ( w_input - w( i ) )
     &                + a_tm( i )

            da_tm_out =   ( da_tm( i+1 ) - da_tm( i ) )
     &                / ( w( i+1 ) - w( i ) ) * ( w_input - w( i ) )
     &                + da_tm( i )

            return

         endif

      enddo

      return
      end

c
ctt
c Routine for R_{had} w/out narrow resonances
ctt
      subroutine r_intpl( w_input, r_out, dr_out )
      implicit NONE
cccc5cccc0ccccccccc0ccccccccc0ccccccccc0ccccccccc0ccccccccc0
c
c Time-stamp: <2008-09-11 01:21 JST>
c
c Returns R(s) and its error by interpolation.
c 
c *** Note that in this particular version the contributions   ***
c *** from J/psi, psi', Ups(1S-6S) are intentionally excluded. ***
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c tmp vars -------------------------------------------------
      integer IMAX, NUMPTS, IMAX_RES, i, j, i_last
      Parameter( IMAX = 1272, NUMPTS = IMAX, IMAX_RES=11 )
c explicit input var. --------------------------------------
      real*8 w_input
c output var. ----------------------------------------------
      real*8 r_out, dr_out
c input as data blocks -------------------------------------
      real*8 w(IMAX), r(IMAX), dr(IMAX) 
      real*8 w_res(8,IMAX_RES), r_res(8,IMAX_RES), dr_res(8,IMAX_RES) 
c data -----------------------------------------------------

      data  ( w(i), i=   1,  95) /
     & 0.325951d0, 0.344601d0, 0.363251d0, 0.381901d0, 0.400551d0,
     & 0.419201d0, 0.437851d0, 0.456501d0, 0.475151d0, 0.493801d0,
     & 0.512451d0, 0.531101d0, 0.549751d0, 0.568401d0, 0.587051d0,
     & 0.605701d0, 0.610701d0, 0.615701d0, 0.620701d0, 0.625701d0,
     & 0.630701d0, 0.635701d0, 0.640701d0, 0.645701d0, 0.650701d0,
     & 0.655701d0, 0.660701d0, 0.665701d0, 0.670701d0, 0.675701d0,
     & 0.680701d0, 0.685701d0, 0.690701d0, 0.695701d0, 0.700701d0,
     & 0.705701d0, 0.710701d0, 0.715701d0, 0.720701d0, 0.725701d0,
     & 0.730701d0, 0.735701d0, 0.740701d0, 0.745701d0, 0.750701d0,
     & 0.752701d0, 0.754701d0, 0.756701d0, 0.758701d0, 0.760701d0,
     & 0.762701d0, 0.764701d0, 0.766701d0, 0.768701d0, 0.770701d0,
     & 0.771101d0, 0.771501d0, 0.771901d0, 0.772301d0, 0.772701d0,
     & 0.773101d0, 0.773501d0, 0.773901d0, 0.774301d0, 0.774701d0,
     & 0.775101d0, 0.775501d0, 0.775901d0, 0.776301d0, 0.776701d0,
     & 0.777101d0, 0.777501d0, 0.777901d0, 0.778301d0, 0.778746d0,
     & 0.779146d0, 0.779546d0, 0.780036d0, 0.780436d0, 0.780836d0,
     & 0.781236d0, 0.781636d0, 0.782081d0, 0.782481d0, 0.782926d0,
     & 0.783326d0, 0.783726d0, 0.784126d0, 0.784526d0, 0.784926d0,
     & 0.785326d0, 0.785726d0, 0.786126d0, 0.786526d0, 0.786926d0 /

      data ( w(i), i=  96, 190) /
     & 0.787326d0, 0.787726d0, 0.788126d0, 0.788526d0, 0.788926d0,
     & 0.789326d0, 0.789726d0, 0.790126d0, 0.790626d0, 0.791126d0,
     & 0.791626d0, 0.792126d0, 0.792626d0, 0.793126d0, 0.793626d0,
     & 0.794126d0, 0.794626d0, 0.795126d0, 0.796126d0, 0.797126d0,
     & 0.798126d0, 0.799126d0, 0.800126d0, 0.801126d0, 0.802126d0,
     & 0.803126d0, 0.804126d0, 0.805126d0, 0.806126d0, 0.807126d0,
     & 0.808126d0, 0.809126d0, 0.810126d0, 0.811126d0, 0.812126d0,
     & 0.813126d0, 0.814126d0, 0.815126d0, 0.816126d0, 0.817126d0,
     & 0.818126d0, 0.819126d0, 0.820126d0, 0.822126d0, 0.824126d0,
     & 0.826126d0, 0.828126d0, 0.830126d0, 0.832126d0, 0.834126d0,
     & 0.836126d0, 0.838126d0, 0.840126d0, 0.842126d0, 0.844126d0,
     & 0.846126d0, 0.848126d0, 0.850126d0, 0.852126d0, 0.854126d0,
     & 0.856126d0, 0.858126d0, 0.860126d0, 0.862126d0, 0.864126d0,
     & 0.866126d0, 0.868126d0, 0.870126d0, 0.872126d0, 0.874126d0,
     & 0.876126d0, 0.878126d0, 0.880126d0, 0.882126d0, 0.884126d0,
     & 0.886126d0, 0.888126d0, 0.890126d0, 0.892126d0, 0.894126d0,
     & 0.896126d0, 0.898126d0, 0.900126d0, 0.902126d0, 0.904126d0,
     & 0.906126d0, 0.908126d0, 0.910126d0, 0.912126d0, 0.914126d0,
     & 0.916126d0, 0.918126d0, 0.920126d0, 0.924126d0, 0.928126d0 /

      data ( w(i), i= 191, 285) /
     & 0.932126d0, 0.936126d0, 0.940126d0, 0.944126d0, 0.948126d0,
     & 0.952126d0, 0.956126d0, 0.960126d0, 0.964126d0, 0.968126d0,
     & 0.972126d0, 0.976126d0, 0.980126d0, 0.984126d0, 0.988126d0,
     & 0.992126d0, 0.996126d0,  1.00013d0,  1.00413d0,  1.00813d0,
     &  1.01213d0,  1.01263d0,  1.01313d0,  1.01363d0,  1.01413d0,
     &  1.01463d0,  1.01513d0,  1.01563d0,  1.01613d0,  1.01663d0,
     &  1.01713d0,  1.01763d0,  1.01813d0,  1.01867d0,  1.01917d0,
     &  1.01967d0,  1.02017d0,  1.02072d0,  1.02122d0,  1.02172d0,
     &  1.02222d0,  1.02272d0,  1.02322d0,  1.02372d0,  1.02422d0,
     &  1.02472d0,  1.02522d0,  1.02572d0,  1.02622d0,  1.02697d0,
     &  1.02772d0,  1.03772d0,  1.04772d0,  1.05772d0,  1.06772d0,
     &  1.07772d0,  1.08772d0,  1.09772d0,  1.10772d0,  1.11772d0,
     &  1.12772d0,  1.13772d0,  1.14772d0,  1.15772d0,  1.16772d0,
     &  1.17772d0,  1.18772d0,  1.19772d0,  1.20772d0,  1.21772d0,
     &  1.22772d0,  1.23772d0,  1.24772d0,  1.25772d0,  1.26772d0,
     &  1.27772d0,  1.28772d0,  1.29772d0,  1.30772d0,  1.31772d0,
     &  1.32772d0,  1.33772d0,  1.34772d0,  1.35772d0,  1.36772d0,
     &  1.37772d0,  1.38772d0,  1.39772d0,  1.40772d0,  1.41772d0,
     &  1.42772d0,  1.43772d0,  1.44772d0,  1.45772d0,  1.46772d0 /

      data ( w(i), i= 286, 380) /
     &  1.47772d0,  1.48772d0,  1.49772d0,  1.50772d0,  1.51772d0,
     &  1.52772d0,  1.53772d0,  1.54772d0,  1.55772d0,  1.56772d0,
     &  1.57772d0,  1.58772d0,  1.59772d0,  1.60772d0,  1.61772d0,
     &  1.62772d0,  1.63772d0,  1.64772d0,  1.65772d0,  1.66772d0,
     &  1.67772d0,  1.68772d0,  1.69772d0,  1.70772d0,  1.71772d0,
     &  1.72772d0,  1.73772d0,  1.74772d0,  1.75772d0,  1.76772d0,
     &  1.77772d0,  1.78772d0,  1.79772d0,  1.80772d0,  1.81772d0,
     &  1.82772d0,  1.83772d0,  1.84772d0,  1.85772d0,  1.86772d0,
     &  1.87772d0,  1.88772d0,  1.89772d0,  1.90772d0,  1.91772d0,
     &  1.92772d0,  1.93772d0,  1.94772d0,  1.95772d0,  1.96772d0,
     &  1.97772d0,  1.98772d0,  1.99772d0,  2.00772d0,  2.02772d0,
     &  2.04772d0,  2.06772d0,  2.08772d0,  2.10772d0,  2.15772d0,
     &  2.20772d0,  2.25772d0,  2.30772d0,  2.35772d0,  2.40772d0,
     &  2.45772d0,  2.50772d0,  2.55772d0,  2.60772d0,  2.65772d0,
     &  2.70772d0,  2.75772d0,  2.80772d0,  2.85772d0,  2.90772d0,
     &  2.95772d0,  3.00772d0,  3.00972d0,  3.01172d0,  3.01372d0,
     &  3.01572d0,  3.01772d0,  3.01972d0,  3.02172d0,  3.02372d0,
     &  3.02572d0,  3.02772d0,  3.02972d0,  3.03172d0,  3.03372d0,
     &  3.03572d0,  3.03772d0,  3.03972d0,  3.04172d0,  3.04372d0 /

      data ( w(i), i= 381, 475) /
     &  3.04572d0,  3.04772d0,  3.04972d0,  3.05172d0,  3.05372d0,
     &  3.05572d0,  3.05772d0,  3.05972d0,  3.06172d0,  3.06372d0,
     &  3.06572d0,  3.06772d0,  3.06972d0,  3.07172d0,  3.07222d0,
     &  3.07272d0,  3.07322d0,  3.07372d0,  3.07422d0,  3.07472d0,
     &  3.07522d0,  3.07572d0,  3.07622d0,  3.07672d0,  3.07722d0,
     &  3.07772d0,  3.07822d0,  3.07872d0,  3.07922d0,  3.07972d0,
     &  3.08022d0,  3.08072d0,  3.08122d0,  3.08172d0,  3.08222d0,
     &  3.08272d0,  3.08322d0,  3.08372d0,  3.08422d0,  3.08472d0,
     &  3.08522d0,  3.08572d0,  3.08622d0,  3.08672d0,  3.08722d0,
     &  3.08772d0,  3.08822d0,  3.08872d0,  3.08922d0,  3.08972d0,
     &  3.09022d0,  3.09032d0,  3.09042d0,  3.09052d0,  3.09062d0,
     &  3.09072d0,  3.09082d0,  3.09092d0,  3.09102d0,  3.09112d0,
     &  3.09122d0,  3.09132d0,  3.09142d0,  3.09152d0,  3.09162d0,
     &  3.09172d0,  3.09182d0,  3.09192d0,  3.09202d0,  3.09212d0,
     &  3.09222d0,  3.09232d0,  3.09242d0,  3.09252d0,  3.09262d0,
     &  3.09272d0,  3.09282d0,  3.09292d0,  3.09302d0,  3.09312d0,
     &  3.09322d0,  3.09332d0,  3.09342d0,  3.09352d0,  3.09362d0,
     &  3.09372d0,  3.09382d0,  3.09392d0,  3.09402d0,  3.09412d0,
     &  3.09422d0,  3.09432d0,  3.09442d0,  3.09452d0,  3.09462d0 /

      data ( w(i), i= 476, 570) /
     &  3.09472d0,  3.09482d0,  3.09492d0,  3.09502d0,  3.09512d0,
     &  3.09522d0,  3.09532d0,  3.09542d0,  3.09552d0,  3.09562d0,
     &  3.09572d0,  3.09582d0,  3.09592d0,  3.09602d0,  3.09612d0,
     &  3.09622d0,  3.09632d0,  3.09642d0,  3.09652d0,  3.09662d0,
     &  3.09672d0,  3.09682d0,  3.09692d0,  3.09702d0,  3.09712d0,
     &  3.09722d0,  3.09732d0,  3.09742d0,  3.09752d0,  3.09762d0,
     &  3.09772d0,  3.09782d0,  3.09792d0,  3.09802d0,  3.09812d0,
     &  3.09822d0,  3.09832d0,  3.09842d0,  3.09852d0,  3.09862d0,
     &  3.09872d0,  3.09882d0,  3.09892d0,  3.09902d0,  3.09912d0,
     &  3.09922d0,  3.09932d0,  3.09942d0,  3.09952d0,  3.09962d0,
     &  3.09972d0,  3.09982d0,  3.09992d0,  3.10002d0,  3.10052d0,
     &  3.10102d0,  3.10152d0,  3.10202d0,  3.10252d0,  3.10302d0,
     &  3.10352d0,  3.10402d0,  3.10452d0,  3.10502d0,  3.10552d0,
     &  3.10602d0,  3.10652d0,  3.10702d0,  3.10752d0,  3.10802d0,
     &  3.10852d0,  3.10902d0,  3.10952d0,  3.11002d0,  3.11052d0,
     &  3.11102d0,  3.11152d0,  3.11202d0,  3.11252d0,  3.11302d0,
     &  3.11352d0,  3.11402d0,  3.11452d0,  3.11502d0,  3.11552d0,
     &  3.11602d0,  3.11652d0,  3.11702d0,  3.11752d0,  3.11802d0,
     &  3.11852d0,  3.11902d0,  3.11952d0,  3.12002d0,  3.12102d0 /

      data ( w(i), i= 571, 665) /
     &  3.12202d0,  3.12302d0,  3.12402d0,  3.12502d0,  3.12602d0,
     &  3.12702d0,  3.12802d0,  3.12902d0,  3.13002d0,  3.13102d0,
     &  3.13202d0,  3.13302d0,  3.13402d0,  3.13502d0,  3.13602d0,
     &  3.13702d0,  3.13802d0,  3.13902d0,  3.14002d0,  3.14102d0,
     &  3.14202d0,  3.14302d0,  3.14402d0,  3.14502d0,  3.14602d0,
     &  3.14702d0,  3.14802d0,  3.14902d0,  3.15002d0,  3.15102d0,
     &  3.15202d0,  3.15302d0,  3.15402d0,  3.15502d0,  3.15602d0,
     &  3.15702d0,  3.15802d0,  3.15902d0,  3.16002d0,  3.16102d0,
     &  3.16202d0,  3.16302d0,  3.16402d0,  3.16502d0,  3.16602d0,
     &  3.16702d0,  3.16802d0,  3.16902d0,  3.17002d0,  3.17102d0,
     &  3.17202d0,  3.17302d0,  3.17402d0,  3.17502d0,  3.17602d0,
     &  3.17702d0,  3.17802d0,  3.17902d0,  3.18002d0,  3.18102d0,
     &  3.18202d0,  3.18302d0,  3.18402d0,  3.18502d0,  3.18602d0,
     &  3.18702d0,  3.18802d0,  3.18902d0,  3.19002d0,  3.19102d0,
     &  3.19202d0,  3.19302d0,  3.19402d0,  3.19502d0,  3.19602d0,
     &  3.19702d0,  3.19802d0,  3.19902d0,  3.20002d0,  3.21002d0,
     &  3.22002d0,  3.23002d0,  3.24002d0,  3.25002d0,  3.26002d0,
     &  3.27002d0,  3.28002d0,  3.29002d0,  3.30002d0,  3.31002d0,
     &  3.32002d0,  3.33002d0,  3.34002d0,  3.35002d0,  3.36002d0 /

      data ( w(i), i= 666, 760) /
     &  3.37002d0,  3.38002d0,  3.39002d0,  3.40002d0,  3.42002d0,
     &  3.44002d0,  3.46002d0,  3.48002d0,  3.50002d0,  3.52002d0,
     &  3.54002d0,  3.56002d0,  3.58002d0,  3.60002d0,  3.60502d0,
     &  3.61002d0,  3.61502d0,  3.62002d0,  3.62502d0,  3.63002d0,
     &  3.63502d0,  3.64002d0,  3.64502d0,  3.65002d0,  3.65502d0,
     &  3.66002d0,  3.66102d0,  3.66202d0,  3.66302d0,  3.66402d0,
     &  3.66502d0,  3.66602d0,  3.66702d0,  3.66802d0,  3.66902d0,
     &  3.67002d0,  3.67102d0,  3.67202d0,  3.67302d0,  3.67402d0,
     &  3.67502d0,  3.67602d0,  3.67702d0,  3.67802d0,  3.67902d0,
     &  3.68002d0,  3.68102d0,  3.68202d0,  3.68302d0,  3.68402d0,
     &  3.68502d0,  3.68602d0,  3.68702d0,  3.68802d0,  3.68902d0,
     &  3.69002d0,  3.69102d0,  3.69202d0,  3.69302d0,  3.69402d0,
     &  3.69502d0,  3.69602d0,  3.69702d0,  3.69802d0,  3.69902d0,
     &  3.70002d0,  3.70102d0,  3.70202d0,  3.70302d0,  3.70402d0,
     &  3.70502d0,  3.70602d0,  3.70702d0,  3.70802d0,  3.70902d0,
     &  3.71002d0,  3.71502d0,  3.72002d0,  3.72502d0,  3.73002d0,
     &  3.73502d0,  3.74002d0,  3.74502d0,  3.75002d0,  3.75502d0,
     &  3.76002d0,  3.76502d0,  3.77002d0,  3.77502d0,  3.78002d0,
     &  3.78502d0,  3.79002d0,  3.79502d0,  3.80002d0,  3.81002d0 /

      data ( w(i), i= 761, 855) /
     &  3.82002d0,  3.83002d0,  3.84002d0,  3.85002d0,  3.86002d0,
     &  3.87002d0,  3.88002d0,  3.89002d0,  3.90002d0,  3.91002d0,
     &  3.92002d0,  3.93002d0,  3.94002d0,  3.95002d0,  3.96002d0,
     &  3.97002d0,  3.98002d0,  3.99002d0,  4.00002d0,  4.01002d0,
     &  4.02002d0,  4.03002d0,  4.04002d0,  4.05002d0,  4.06002d0,
     &  4.07002d0,  4.08002d0,  4.09002d0,  4.10002d0,  4.11002d0,
     &  4.12002d0,  4.13002d0,  4.14002d0,  4.15002d0,  4.16002d0,
     &  4.17002d0,  4.18002d0,  4.19002d0,  4.20002d0,  4.22002d0,
     &  4.24002d0,  4.26002d0,  4.28002d0,  4.30002d0,  4.32002d0,
     &  4.34002d0,  4.36002d0,  4.38002d0,  4.40002d0,  4.42002d0,
     &  4.44002d0,  4.46002d0,  4.48002d0,  4.50002d0,  4.52002d0,
     &  4.54002d0,  4.56002d0,  4.58002d0,  4.60002d0,  4.62002d0,
     &  4.64002d0,  4.66002d0,  4.68002d0,  4.70002d0,  4.72002d0,
     &  4.74002d0,  4.76002d0,  4.78002d0,  4.80002d0,  4.82002d0,
     &  4.84002d0,  4.86002d0,  4.88002d0,  4.90002d0,  4.92002d0,
     &  4.94002d0,  4.96002d0,  4.98002d0,  5.00002d0,  5.02002d0,
     &  5.04002d0,  5.06002d0,  5.08002d0,  5.10002d0,  5.12002d0,
     &  5.14002d0,  5.16002d0,  5.18002d0,  5.20002d0,  5.22002d0,
     &  5.24002d0,  5.26002d0,  5.28002d0,  5.30002d0,  5.32002d0 /

      data ( w(i), i= 856, 950) /
     &  5.34002d0,  5.36002d0,  5.38002d0,  5.40002d0,  5.42002d0,
     &  5.44002d0,  5.46002d0,  5.48002d0,  5.50002d0,  5.52002d0,
     &  5.54002d0,  5.56002d0,  5.58002d0,  5.60002d0,  5.62002d0,
     &  5.64002d0,  5.66002d0,  5.68002d0,  5.70002d0,  5.74002d0,
     &  5.78002d0,  5.82002d0,  5.86002d0,  5.90002d0,  5.94002d0,
     &  5.98002d0,  6.02002d0,  6.06002d0,  6.10002d0,  6.14002d0,
     &  6.18002d0,  6.22002d0,  6.26002d0,  6.30002d0,  6.34002d0,
     &  6.38002d0,  6.42002d0,  6.46002d0,  6.50002d0,  6.54002d0,
     &  6.58002d0,  6.62002d0,  6.66002d0,  6.70002d0,  6.74002d0,
     &  6.78002d0,  6.82002d0,  6.86002d0,  6.90002d0,  6.92002d0,
     &  6.94002d0,  6.96002d0,  6.98002d0,  7.00002d0,  7.02002d0,
     &  7.04002d0,  7.06002d0,  7.08002d0,  7.10002d0,  7.12002d0,
     &  7.14002d0,  7.16002d0,  7.18002d0,  7.20002d0,  7.22002d0,
     &  7.24002d0,  7.26002d0,  7.28002d0,  7.30002d0,  7.32002d0,
     &  7.34002d0,  7.36002d0,  7.38002d0,  7.40002d0,  7.42002d0,
     &  7.44002d0,  7.46002d0,  7.48002d0,  7.50002d0,  7.52002d0,
     &  7.54002d0,  7.56002d0,  7.58002d0,  7.60002d0,  7.62002d0,
     &  7.64002d0,  7.66002d0,  7.68002d0,  7.70002d0,  7.72002d0,
     &  7.74002d0,  7.76002d0,  7.78002d0,  7.80002d0,  7.82002d0 /

      data ( w(i), i= 951,1045) /
     &  7.84002d0,  7.86002d0,  7.88002d0,  7.90002d0,  7.92002d0,
     &  7.94002d0,  7.96002d0,  7.98002d0,  8.00002d0,  8.02002d0,
     &  8.04002d0,  8.06002d0,  8.08002d0,  8.10002d0,  8.12002d0,
     &  8.14002d0,  8.16002d0,  8.18002d0,  8.20002d0,  8.22002d0,
     &  8.24002d0,  8.26002d0,  8.28002d0,  8.30002d0,  8.32002d0,
     &  8.34002d0,  8.36002d0,  8.38002d0,  8.40002d0,  8.42002d0,
     &  8.44002d0,  8.46002d0,  8.48002d0,  8.50002d0,  8.52002d0,
     &  8.54002d0,  8.56002d0,  8.58002d0,  8.60002d0,  8.62002d0,
     &  8.64002d0,  8.66002d0,  8.68002d0,  8.70002d0,  8.72002d0,
     &  8.74002d0,  8.76002d0,  8.78002d0,  8.80002d0,  8.82002d0,
     &  8.84002d0,  8.86002d0,  8.88002d0,  8.90002d0,  8.92002d0,
     &  8.94002d0,  8.96002d0,  8.98002d0,  9.00002d0,  9.02002d0,
     &  9.04002d0,  9.06002d0,  9.08002d0,  9.10002d0,  9.12002d0,
     &  9.14002d0,  9.16002d0,  9.18002d0,  9.20002d0,  9.22002d0,
     &  9.24002d0,  9.26002d0,  9.28002d0,  9.30002d0,  9.30502d0,
     &  9.31002d0,  9.31502d0,  9.32002d0,  9.32502d0,  9.33002d0,
     &  9.33502d0,  9.34002d0,  9.34502d0,  9.35002d0,  9.35502d0,
     &  9.36002d0,  9.36502d0,  9.37002d0,  9.37502d0,  9.38002d0,
     &  9.38502d0,  9.39002d0,  9.39502d0,  9.40002d0,  9.40502d0 /

      data ( w(i), i=1046,1140) /
     &  9.41002d0,  9.41502d0,  9.42002d0,  9.42502d0,  9.43002d0,
     &  9.43502d0,  9.44002d0,  9.44502d0,  9.45002d0,  9.45502d0,
     &  9.46002d0,  9.46502d0,  9.47002d0,  9.47502d0,  9.48002d0,
     &  9.48502d0,  9.49002d0,  9.49502d0,  9.50002d0,  9.50502d0,
     &  9.51002d0,  9.51502d0,  9.52002d0,  9.52502d0,  9.53002d0,
     &  9.53502d0,  9.54002d0,  9.54502d0,  9.55002d0,  9.55502d0,
     &  9.56002d0,  9.56502d0,  9.57002d0,  9.57502d0,  9.58002d0,
     &  9.58502d0,  9.59002d0,  9.59502d0,  9.60002d0,  9.61002d0,
     &  9.62002d0,  9.63002d0,  9.64002d0,  9.65002d0,  9.66002d0,
     &  9.67002d0,  9.68002d0,  9.69002d0,  9.70002d0,  9.71002d0,
     &  9.72002d0,  9.73002d0,  9.74002d0,  9.75002d0,  9.76002d0,
     &  9.77002d0,  9.78002d0,  9.79002d0,  9.80002d0,  9.81002d0,
     &  9.82002d0,  9.83002d0,  9.84002d0,  9.85002d0,  9.86002d0,
     &  9.87002d0,  9.88002d0,  9.89002d0,  9.90002d0,  9.91002d0,
     &  9.92002d0,  9.93002d0,  9.94002d0,  9.95002d0,  9.96002d0,
     &  9.97002d0,  9.98002d0,  9.99002d0,  10.0000d0,  10.0100d0,
     &  10.0200d0,  10.0300d0,  10.0400d0,  10.0500d0,  10.0600d0,
     &  10.0700d0,  10.0800d0,  10.0900d0,  10.1000d0,  10.1100d0,
     &  10.1200d0,  10.1300d0,  10.1400d0,  10.1500d0,  10.1600d0 /

      data ( w(i), i=1141,1235) /
     &  10.1700d0,  10.1800d0,  10.1900d0,  10.2000d0,  10.2100d0,
     &  10.2200d0,  10.2300d0,  10.2400d0,  10.2500d0,  10.2600d0,
     &  10.2700d0,  10.2800d0,  10.2900d0,  10.3000d0,  10.3100d0,
     &  10.3200d0,  10.3300d0,  10.3400d0,  10.3500d0,  10.3600d0,
     &  10.3700d0,  10.3800d0,  10.3900d0,  10.4000d0,  10.4100d0,
     &  10.4200d0,  10.4300d0,  10.4400d0,  10.4500d0,  10.4600d0,
     &  10.4700d0,  10.4800d0,  10.4900d0,  10.5000d0,  10.5100d0,
     &  10.5200d0,  10.5300d0,  10.5400d0,  10.5500d0,  10.5600d0,
     &  10.5700d0,  10.5800d0,  10.5900d0,  10.6000d0,  10.6100d0,
     &  10.6200d0,  10.6300d0,  10.6400d0,  10.6500d0,  10.6600d0,
     &  10.6700d0,  10.6800d0,  10.6900d0,  10.7000d0,  10.7100d0,
     &  10.7200d0,  10.7300d0,  10.7400d0,  10.7500d0,  10.7600d0,
     &  10.7700d0,  10.7800d0,  10.7900d0,  10.8000d0,  10.8100d0,
     &  10.8200d0,  10.8300d0,  10.8400d0,  10.8500d0,  10.8600d0,
     &  10.8700d0,  10.8800d0,  10.8900d0,  10.9000d0,  10.9100d0,
     &  10.9200d0,  10.9300d0,  10.9400d0,  10.9500d0,  10.9600d0,
     &  10.9700d0,  10.9800d0,  10.9900d0,  11.0000d0,  11.0500d0,
     &  11.1000d0,  11.1500d0,  11.2000d0,  11.2500d0,  11.3000d0,
     &  11.3500d0,  11.4000d0,  11.4500d0,  11.5000d0,  11.6000d0 /

      data ( w(i), i=1236,1272) /
     &  11.7000d0,  11.8000d0,  11.9000d0,  12.0000d0,  13.0000d0,
     &  14.0000d0,  15.0000d0,  16.0000d0,  17.0000d0,  18.0000d0,
     &  19.0000d0,  20.0000d0,  21.0000d0,  22.0000d0,  23.0000d0,
     &  24.0000d0,  25.0000d0,  26.0000d0,  27.0000d0,  28.0000d0,
     &  29.0000d0,  30.0000d0,  35.0000d0,  40.0000d0,  45.0000d0,
     &  50.0000d0,  55.0000d0,  60.0000d0,  65.0000d0,  70.0000d0,
     &  75.0000d0,  80.0000d0,  85.0000d0,  90.0000d0,  91.1876d0,
     &  95.0000d0,  100.000d0 /


      data  ( r(i), i=   1,  95) /
     & 0.477315d-1, 0.730798d-1, 0.128833d0, 0.168137d0, 0.177692d0,
     & 0.216959d0, 0.300483d0, 0.313350d0, 0.396199d0, 0.466623d0,
     & 0.546955d0, 0.662661d0, 0.769457d0, 0.904652d0,  1.10271d0,
     &  1.47488d0,  1.56110d0,  1.64164d0,  1.72281d0,  1.80874d0,
     &  1.90643d0,  2.01360d0,  2.18361d0,  2.34498d0,  2.50101d0,
     &  2.65481d0,  2.78433d0,  3.01941d0,  3.23457d0,  3.44427d0,
     &  3.73100d0,  3.99020d0,  4.25163d0,  4.55596d0,  4.88679d0,
     &  5.21198d0,  5.58324d0,  5.96072d0,  6.39861d0,  6.75873d0,
     &  7.16067d0,  7.53990d0,  7.91760d0,  8.24039d0,  8.51259d0,
     &  8.62739d0,  8.73989d0,  8.84975d0,  8.95396d0,  9.03410d0,
     &  9.16360d0,  9.30653d0,  9.52633d0,  9.73563d0,  10.1530d0,
     &  10.2872d0,  10.4201d0,  10.5508d0,  10.6798d0,  10.8070d0,
     &  10.9318d0,  11.0541d0,  11.2200d0,  11.4455d0,  11.7693d0,
     &  12.1219d0,  12.4725d0,  12.8209d0,  13.1671d0,  13.5113d0,
     &  13.8538d0,  14.1949d0,  14.5328d0,  15.0137d0,  15.5679d0,
     &  16.0874d0,  16.5940d0,  17.2481d0,  17.9300d0,  18.3814d0,
     &  18.7719d0,  19.1697d0,  19.1752d0,  19.1021d0,  18.9276d0,
     &  18.3051d0,  17.6295d0,  16.8120d0,  15.9907d0,  15.2532d0,
     &  14.5528d0,  13.8704d0,  13.1861d0,  12.6799d0,  12.2454d0 /

      data ( r(i), i=  96, 190) /
     &  11.8148d0,  11.3859d0,  10.9564d0,  10.5241d0,  10.0872d0,
     &  9.64469d0,  9.20734d0,  9.02797d0,  8.82553d0,  8.63421d0,
     &  8.44258d0,  8.24963d0,  8.05422d0,  7.85540d0,  7.65414d0,
     &  7.49863d0,  7.40332d0,  7.33243d0,  7.18848d0,  7.03909d0,
     &  6.88067d0,  6.71773d0,  6.57728d0,  6.48979d0,  6.39915d0,
     &  6.30642d0,  6.20573d0,  6.10445d0,  6.00260d0,  5.90027d0,
     &  5.79763d0,  5.69485d0,  5.59571d0,  5.52224d0,  5.45195d0,
     &  5.38146d0,  5.31069d0,  5.23955d0,  5.16597d0,  5.09083d0,
     &  5.01504d0,  4.93866d0,  4.86398d0,  4.73219d0,  4.59534d0,
     &  4.45966d0,  4.32856d0,  4.20881d0,  4.10094d0,  3.99604d0,
     &  3.89194d0,  3.78722d0,  3.66916d0,  3.53457d0,  3.43301d0,
     &  3.33378d0,  3.23910d0,  3.15360d0,  3.08114d0,  3.00861d0,
     &  2.93003d0,  2.84911d0,  2.77798d0,  2.71486d0,  2.65142d0,
     &  2.58145d0,  2.50448d0,  2.44249d0,  2.39572d0,  2.35203d0,
     &  2.30183d0,  2.24743d0,  2.18897d0,  2.13360d0,  2.07391d0,
     &  2.01644d0,  1.95794d0,  1.91048d0,  1.85899d0,  1.81598d0,
     &  1.77647d0,  1.74493d0,  1.71064d0,  1.68451d0,  1.65756d0,
     &  1.62750d0,  1.59458d0,  1.56239d0,  1.53325d0,  1.49656d0,
     &  1.46345d0,  1.44849d0,  1.44939d0,  1.38237d0,  1.31116d0 /

      data ( r(i), i= 191, 285) /
     &  1.26758d0,  1.24588d0,  1.22575d0,  1.15968d0,  1.14601d0,
     &  1.09352d0,  1.08127d0,  1.04661d0,  1.03147d0,  1.02071d0,
     &  1.03941d0,  1.04041d0,  1.03263d0, 0.996130d0,  1.01158d0,
     &  1.07228d0,  1.13333d0,  1.19197d0,  1.39547d0,  1.83569d0,
     &  4.94403d0,  5.66149d0,  6.50701d0,  7.40290d0,  8.51785d0,
     &  9.86277d0,  11.2083d0,  12.9083d0,  16.7263d0,  21.2471d0,
     &  26.4084d0,  33.4681d0,  39.4235d0,  47.3697d0,  47.2507d0,
     &  45.4186d0,  40.8596d0,  32.1759d0,  26.2629d0,  19.9914d0,
     &  15.4305d0,  13.2093d0,  11.7785d0,  9.74002d0,  8.28815d0,
     &  7.66192d0,  7.03538d0,  6.46200d0,  5.90792d0,  5.07630d0,
     &  4.37452d0,  1.94165d0,  1.36917d0,  1.12987d0,  1.19667d0,
     &  1.06414d0,  1.06252d0, 0.895505d0, 0.834985d0, 0.823804d0,
     & 0.897128d0, 0.906724d0, 0.914987d0, 0.905310d0, 0.976993d0,
     & 0.956023d0, 0.918454d0, 0.917910d0, 0.931172d0, 0.963192d0,
     &  1.01145d0,  1.05723d0,  1.06763d0,  1.07705d0,  1.12606d0,
     &  1.14347d0,  1.14008d0,  1.21929d0,  1.23624d0,  1.23650d0,
     &  1.28888d0,  1.36548d0,  1.39702d0,  1.42960d0,  1.48763d0,
     &  1.55291d0,  1.59669d0,  1.64601d0,  1.71556d0,  1.73442d0,
     &  1.74734d0,  1.77553d0,  1.78799d0,  1.79627d0,  1.88756d0 /

      data ( r(i), i= 286, 380) /
     &  2.01617d0,  2.13924d0,  2.22825d0,  2.31681d0,  2.39098d0,
     &  2.46454d0,  2.47657d0,  2.41161d0,  2.34289d0,  2.22312d0,
     &  2.10260d0,  2.06632d0,  2.10389d0,  2.14198d0,  2.12616d0,
     &  2.10126d0,  2.12792d0,  2.28713d0,  2.44732d0,  2.43829d0,
     &  2.37794d0,  2.32878d0,  2.29842d0,  2.26812d0,  2.23631d0,
     &  2.20400d0,  2.17151d0,  2.13789d0,  2.10392d0,  2.09708d0,
     &  2.10209d0,  2.10755d0,  2.11776d0,  2.12938d0,  2.15451d0,
     &  2.19617d0,  2.21890d0,  1.99671d0,  1.77289d0,  1.61746d0,
     &  1.77838d0,  1.90154d0,  1.83909d0,  1.77649d0,  1.71356d0,
     &  1.64934d0,  1.58450d0,  1.66204d0,  1.74237d0,  1.86205d0,
     &  1.99391d0,  2.12643d0,  2.25902d0,  2.29538d0,  2.31108d0,
     &  2.32970d0,  2.35290d0,  2.37520d0,  2.39581d0,  2.44509d0,
     &  2.48308d0,  2.48170d0,  2.48239d0,  2.48309d0,  2.48224d0,
     &  2.48742d0,  2.49583d0,  2.52171d0,  2.53293d0,  2.46043d0,
     &  2.38776d0,  2.32042d0,  2.26646d0,  2.29237d0,  2.31384d0,
     &  2.30866d0,  2.29898d0,  2.29763d0,  2.29627d0,  2.29491d0,
     &  2.29355d0,  2.29220d0,  2.29083d0,  2.28947d0,  2.28811d0,
     &  2.28675d0,  2.28538d0,  2.28402d0,  2.28265d0,  2.28129d0,
     &  2.27992d0,  2.27855d0,  2.27718d0,  2.27581d0,  2.27444d0 /

      data ( r(i), i= 381, 475) /
     &  2.27307d0,  2.27169d0,  2.27032d0,  2.26894d0,  2.26757d0,
     &  2.26619d0,  2.26481d0,  2.26343d0,  2.26205d0,  2.26067d0,
     &  2.25929d0,  2.25791d0,  2.25653d0,  2.25514d0,  2.25480d0,
     &  2.25445d0,  2.25410d0,  2.25376d0,  2.25341d0,  2.25307d0,
     &  2.25272d0,  2.25237d0,  2.25203d0,  2.25168d0,  2.25133d0,
     &  2.25099d0,  2.25064d0,  2.25029d0,  2.24995d0,  2.24960d0,
     &  2.24925d0,  2.24890d0,  2.24856d0,  2.24821d0,  2.24786d0,
     &  2.24752d0,  2.24717d0,  2.24682d0,  2.24647d0,  2.24613d0,
     &  2.24578d0,  2.24543d0,  2.24508d0,  2.24473d0,  2.24439d0,
     &  2.24404d0,  2.24369d0,  2.24334d0,  2.24299d0,  2.24265d0,
     &  2.24230d0,  2.24223d0,  2.24216d0,  2.24209d0,  2.24202d0,
     &  2.24195d0,  2.24188d0,  2.24181d0,  2.24174d0,  2.24167d0,
     &  2.24160d0,  2.24153d0,  2.24146d0,  2.24139d0,  2.24132d0,
     &  2.24125d0,  2.24118d0,  2.24111d0,  2.24104d0,  2.24097d0,
     &  2.24091d0,  2.24084d0,  2.24077d0,  2.24070d0,  2.24063d0,
     &  2.24056d0,  2.24049d0,  2.24042d0,  2.24035d0,  2.24028d0,
     &  2.24021d0,  2.24014d0,  2.24007d0,  2.24000d0,  2.23993d0,
     &  2.23986d0,  2.23979d0,  2.23972d0,  2.23965d0,  2.23958d0,
     &  2.23951d0,  2.23944d0,  2.23937d0,  2.23930d0,  2.23923d0 /

      data ( r(i), i= 476, 570) /
     &  2.23916d0,  2.23909d0,  2.23902d0,  2.23895d0,  2.23888d0,
     &  2.23881d0,  2.23874d0,  2.23867d0,  2.23860d0,  2.23853d0,
     &  2.23846d0,  2.23840d0,  2.23833d0,  2.23826d0,  2.23819d0,
     &  2.23812d0,  2.23805d0,  2.23798d0,  2.23791d0,  2.23784d0,
     &  2.23777d0,  2.23770d0,  2.23763d0,  2.23756d0,  2.23749d0,
     &  2.23742d0,  2.23735d0,  2.23728d0,  2.23721d0,  2.23714d0,
     &  2.23707d0,  2.23700d0,  2.23693d0,  2.23686d0,  2.23679d0,
     &  2.23672d0,  2.23665d0,  2.23658d0,  2.23651d0,  2.23644d0,
     &  2.23637d0,  2.23630d0,  2.23623d0,  2.23616d0,  2.23609d0,
     &  2.23602d0,  2.23595d0,  2.23588d0,  2.23581d0,  2.23574d0,
     &  2.23567d0,  2.23560d0,  2.23553d0,  2.23546d0,  2.23511d0,
     &  2.23476d0,  2.23441d0,  2.23407d0,  2.23372d0,  2.23337d0,
     &  2.23302d0,  2.23267d0,  2.23232d0,  2.23197d0,  2.23162d0,
     &  2.23127d0,  2.23092d0,  2.23057d0,  2.23022d0,  2.22987d0,
     &  2.22952d0,  2.22917d0,  2.22882d0,  2.22847d0,  2.22812d0,
     &  2.22776d0,  2.22741d0,  2.22706d0,  2.22671d0,  2.22636d0,
     &  2.22601d0,  2.22566d0,  2.22531d0,  2.22496d0,  2.22461d0,
     &  2.22426d0,  2.22391d0,  2.22355d0,  2.22320d0,  2.22285d0,
     &  2.22250d0,  2.22215d0,  2.22180d0,  2.22145d0,  2.22074d0 /

      data ( r(i), i= 571, 665) /
     &  2.22004d0,  2.21934d0,  2.21863d0,  2.21793d0,  2.21722d0,
     &  2.21652d0,  2.21581d0,  2.21511d0,  2.21440d0,  2.21370d0,
     &  2.21299d0,  2.21229d0,  2.21158d0,  2.21087d0,  2.21017d0,
     &  2.20946d0,  2.20875d0,  2.20805d0,  2.20734d0,  2.20663d0,
     &  2.20592d0,  2.20521d0,  2.20451d0,  2.20380d0,  2.20309d0,
     &  2.20238d0,  2.20167d0,  2.20096d0,  2.20025d0,  2.19954d0,
     &  2.19883d0,  2.19812d0,  2.19741d0,  2.19670d0,  2.19599d0,
     &  2.19528d0,  2.19456d0,  2.19385d0,  2.19314d0,  2.19243d0,
     &  2.19172d0,  2.19100d0,  2.19029d0,  2.18958d0,  2.18886d0,
     &  2.18815d0,  2.18744d0,  2.18672d0,  2.18601d0,  2.18529d0,
     &  2.18458d0,  2.18386d0,  2.18315d0,  2.18243d0,  2.18172d0,
     &  2.18100d0,  2.18029d0,  2.17957d0,  2.17885d0,  2.17814d0,
     &  2.17742d0,  2.17670d0,  2.17598d0,  2.17527d0,  2.17455d0,
     &  2.17383d0,  2.17311d0,  2.17239d0,  2.17168d0,  2.17096d0,
     &  2.17024d0,  2.16952d0,  2.16880d0,  2.16808d0,  2.16736d0,
     &  2.16664d0,  2.16592d0,  2.16520d0,  2.16450d0,  2.17259d0,
     &  2.18070d0,  2.18883d0,  2.19699d0,  2.20518d0,  2.21339d0,
     &  2.22163d0,  2.22989d0,  2.23818d0,  2.24649d0,  2.25483d0,
     &  2.26319d0,  2.27158d0,  2.27999d0,  2.28843d0,  2.29689d0 /

      data ( r(i), i= 666, 760) /
     &  2.30538d0,  2.31390d0,  2.32243d0,  2.33097d0,  2.31175d0,
     &  2.29241d0,  2.27297d0,  2.25341d0,  2.23373d0,  2.21395d0,
     &  2.19405d0,  2.17961d0,  2.17064d0,  2.16163d0,  2.15937d0,
     &  2.15711d0,  2.15484d0,  2.15257d0,  2.15030d0,  2.14802d0,
     &  2.14574d0,  2.14346d0,  2.14117d0,  2.13888d0,  2.13659d0,
     &  2.22404d0,  2.25705d0,  2.29008d0,  2.32311d0,  2.35615d0,
     &  2.38920d0,  2.42226d0,  2.45533d0,  2.48841d0,  2.52150d0,
     &  2.55394d0,  2.54634d0,  2.53873d0,  2.53112d0,  2.52352d0,
     &  2.51590d0,  2.50829d0,  2.50067d0,  2.49306d0,  2.48544d0,
     &  2.47781d0,  2.47019d0,  2.46256d0,  2.45494d0,  2.44730d0,
     &  2.43967d0,  2.43204d0,  2.42440d0,  2.41676d0,  2.40912d0,
     &  2.40148d0,  2.39383d0,  2.38619d0,  2.37854d0,  2.37089d0,
     &  2.36323d0,  2.35558d0,  2.34792d0,  2.34026d0,  2.33260d0,
     &  2.32499d0,  2.32049d0,  2.31599d0,  2.31148d0,  2.30698d0,
     &  2.30247d0,  2.29797d0,  2.29346d0,  2.28895d0,  2.28444d0,
     &  2.27993d0,  2.25735d0,  2.23475d0,  2.21211d0,  2.18990d0,
     &  2.30957d0,  2.42940d0,  2.54939d0,  2.66955d0,  2.78986d0,
     &  2.96693d0,  3.15664d0,  3.34661d0,  3.53683d0,  3.27568d0,
     &  3.00342d0,  2.73149d0,  2.66905d0,  2.60653d0,  2.48149d0 /

      data ( r(i), i= 761, 855) /
     &  2.50486d0,  2.52829d0,  2.55178d0,  2.57533d0,  2.59808d0,
     &  2.62088d0,  2.64375d0,  2.68471d0,  2.79861d0,  2.91281d0,
     &  2.97472d0,  3.03414d0,  3.05462d0,  3.04183d0,  3.10309d0,
     &  3.32137d0,  3.45328d0,  3.45928d0,  3.47632d0,  3.91705d0,
     &  4.35888d0,  4.63407d0,  4.61077d0,  4.58104d0,  4.41290d0,
     &  4.24434d0,  4.17490d0,  4.16920d0,  4.17570d0,  4.19991d0,
     &  4.20766d0,  4.17274d0,  4.16655d0,  4.22009d0,  4.27376d0,
     &  4.24723d0,  4.21997d0,  4.08538d0,  3.88636d0,  3.47965d0,
     &  3.19249d0,  3.11782d0,  3.17540d0,  3.22466d0,  3.23624d0,
     &  3.46312d0,  3.63209d0,  3.80231d0,  3.94651d0,  4.00372d0,
     &  4.05451d0,  3.85564d0,  3.75139d0,  3.66891d0,  3.38866d0,
     &  3.53160d0,  3.58384d0,  3.52466d0,  3.46531d0,  3.49971d0,
     &  3.53426d0,  3.56896d0,  3.60381d0,  3.63881d0,  3.67396d0,
     &  3.70926d0,  3.74471d0,  3.78030d0,  3.81600d0,  3.78768d0,
     &  3.75925d0,  3.73070d0,  3.70203d0,  3.67325d0,  3.64435d0,
     &  3.61533d0,  3.58619d0,  3.55693d0,  3.52757d0,  3.51684d0,
     &  3.50607d0,  3.49525d0,  3.48439d0,  3.47349d0,  3.46254d0,
     &  3.45155d0,  3.44052d0,  3.42944d0,  3.41843d0,  3.53576d0,
     &  3.65353d0,  3.70598d0,  3.69293d0,  3.67983d0,  3.66668d0 /

      data ( r(i), i= 856, 950) /
     &  3.65348d0,  3.64023d0,  3.62693d0,  3.61358d0,  3.60019d0,
     &  3.58674d0,  3.57324d0,  3.55970d0,  3.54611d0,  3.54856d0,
     &  3.55101d0,  3.55347d0,  3.55595d0,  3.55843d0,  3.56092d0,
     &  3.56341d0,  3.56592d0,  3.56844d0,  3.57096d0,  3.57604d0,
     &  3.57376d0,  3.56899d0,  3.56420d0,  3.55937d0,  3.55451d0,
     &  3.54961d0,  3.53890d0,  3.52233d0,  3.50565d0,  3.48886d0,
     &  3.47196d0,  3.45494d0,  3.44539d0,  3.45852d0,  3.47174d0,
     &  3.48503d0,  3.49841d0,  3.51187d0,  3.52542d0,  3.53031d0,
     &  3.53524d0,  3.54020d0,  3.54518d0,  3.55020d0,  3.55525d0,
     &  3.55404d0,  3.55073d0,  3.54739d0,  3.54404d0,  3.54236d0,
     &  3.54067d0,  3.53898d0,  3.53728d0,  3.53559d0,  3.54952d0,
     &  3.56348d0,  3.57749d0,  3.59153d0,  3.60561d0,  3.61974d0,
     &  3.63390d0,  3.64810d0,  3.66235d0,  3.67663d0,  3.69095d0,
     &  3.70531d0,  3.66028d0,  3.55579d0,  3.45112d0,  3.48329d0,
     &  3.51554d0,  3.54788d0,  3.58030d0,  3.61274d0,  3.55277d0,
     &  3.49274d0,  3.58179d0,  3.67108d0,  3.76048d0,  3.69870d0,
     &  3.63676d0,  3.57465d0,  3.51237d0,  3.45004d0,  3.52085d0,
     &  3.59185d0,  3.66304d0,  3.73441d0,  3.80585d0,  3.73808d0,
     &  3.67013d0,  3.60201d0,  3.53371d0,  3.46530d0,  3.47898d0 /

      data ( r(i), i= 951,1045) /
     &  3.49269d0,  3.50643d0,  3.52021d0,  3.53402d0,  3.53580d0,
     &  3.53759d0,  3.53939d0,  3.54118d0,  3.54299d0,  3.55419d0,
     &  3.56541d0,  3.57667d0,  3.58794d0,  3.59923d0,  3.58150d0,
     &  3.56373d0,  3.54591d0,  3.52805d0,  3.51013d0,  3.46436d0,
     &  3.41847d0,  3.37248d0,  3.32637d0,  3.28023d0,  3.32458d0,
     &  3.36904d0,  3.41360d0,  3.45827d0,  3.50300d0,  3.48555d0,
     &  3.46806d0,  3.45052d0,  3.43294d0,  3.41536d0,  3.43819d0,
     &  3.46108d0,  3.48402d0,  3.50702d0,  3.53002d0,  3.48778d0,
     &  3.44544d0,  3.40301d0,  3.36047d0,  3.31789d0,  3.33562d0,
     &  3.35338d0,  3.37119d0,  3.38904d0,  3.40693d0,  3.43795d0,
     &  3.46904d0,  3.50020d0,  3.53142d0,  3.56272d0,  3.56245d0,
     &  3.55687d0,  3.55128d0,  3.54568d0,  3.54006d0,  3.53239d0,
     &  3.52471d0,  3.51702d0,  3.50930d0,  3.50157d0,  3.49039d0,
     &  3.47919d0,  3.46796d0,  3.45671d0,  3.44544d0,  3.44171d0,
     &  3.43798d0,  3.43423d0,  3.43053d0,  3.47930d0,  3.47255d0,
     &  3.46580d0,  3.45905d0,  3.45229d0,  3.44553d0,  3.43877d0,
     &  3.43200d0,  3.42523d0,  3.41846d0,  3.41168d0,  3.40490d0,
     &  3.39811d0,  3.39132d0,  3.38453d0,  3.37773d0,  3.37093d0,
     &  3.36413d0,  3.35732d0,  3.35051d0,  3.43121d0,  3.52084d0 /

      data ( r(i), i=1046,1140) /
     &  3.61052d0,  3.70007d0,  3.73703d0,  3.77401d0,  3.81101d0,
     &  3.84803d0,  3.88507d0,  3.92213d0,  3.95893d0,  3.91074d0,
     &  3.86253d0,  3.81429d0,  3.76602d0,  3.71773d0,  3.66941d0,
     &  3.62107d0,  3.57270d0,  3.52430d0,  3.47589d0,  3.45573d0,
     &  3.45306d0,  3.45038d0,  3.44770d0,  3.44503d0,  3.44235d0,
     &  3.43967d0,  3.43699d0,  3.43430d0,  3.43162d0,  3.42893d0,
     &  3.42625d0,  3.42356d0,  3.42087d0,  3.41818d0,  3.41548d0,
     &  3.41279d0,  3.41009d0,  3.40740d0,  3.40471d0,  3.40338d0,
     &  3.40206d0,  3.40073d0,  3.39940d0,  3.39808d0,  3.39675d0,
     &  3.39541d0,  3.39408d0,  3.39275d0,  3.39141d0,  3.39008d0,
     &  3.38874d0,  3.38740d0,  3.38606d0,  3.38474d0,  3.39654d0,
     &  3.40836d0,  3.42019d0,  3.43204d0,  3.44386d0,  3.43571d0,
     &  3.42755d0,  3.41939d0,  3.41121d0,  3.40303d0,  3.39484d0,
     &  3.38664d0,  3.37843d0,  3.37021d0,  3.36204d0,  3.38310d0,
     &  3.40419d0,  3.42530d0,  3.44642d0,  3.46757d0,  3.48875d0,
     &  3.50994d0,  3.53115d0,  3.55239d0,  3.57359d0,  3.55965d0,
     &  3.54569d0,  3.53172d0,  3.51773d0,  3.50025d0,  3.48276d0,
     &  3.46525d0,  3.44772d0,  3.43018d0,  3.41263d0,  3.40682d0,
     &  3.40099d0,  3.39517d0,  3.38933d0,  3.38349d0,  3.37765d0 /

      data ( r(i), i=1141,1235) /
     &  3.37180d0,  3.36594d0,  3.36008d0,  3.35422d0,  3.35431d0,
     &  3.35441d0,  3.35450d0,  3.35459d0,  3.35469d0,  3.35478d0,
     &  3.35487d0,  3.35497d0,  3.35506d0,  3.35516d0,  3.35723d0,
     &  3.35930d0,  3.36137d0,  3.36345d0,  3.36552d0,  3.36760d0,
     &  3.36968d0,  3.37176d0,  3.37385d0,  3.37594d0,  3.37802d0,
     &  3.38011d0,  3.38224d0,  3.40192d0,  3.42161d0,  3.44133d0,
     &  3.46107d0,  3.48082d0,  3.50060d0,  3.52039d0,  3.54020d0,
     &  3.56000d0,  3.56204d0,  3.56407d0,  3.56611d0,  3.56814d0,
     &  3.57019d0,  3.57223d0,  3.57427d0,  3.57632d0,  3.57837d0,
     &  3.58042d0,  3.58247d0,  3.58452d0,  3.58658d0,  3.58863d0,
     &  3.59069d0,  3.59276d0,  3.59482d0,  3.59688d0,  3.59895d0,
     &  3.60102d0,  3.60309d0,  3.60517d0,  3.60724d0,  3.60932d0,
     &  3.61140d0,  3.61348d0,  3.61556d0,  3.61764d0,  3.61973d0,
     &  3.62182d0,  3.62391d0,  3.62600d0,  3.62810d0,  3.63019d0,
     &  3.63229d0,  3.63439d0,  3.63649d0,  3.63860d0,  3.64070d0,
     &  3.64281d0,  3.64492d0,  3.64703d0,  3.64915d0,  3.65126d0,
     &  3.65338d0,  3.65550d0,  3.65762d0,  3.65974d0,  3.67039d0,
     &  3.90358d0,  3.90324d0,  3.90291d0,  3.90258d0,  3.90226d0,
     &  3.90195d0,  3.90163d0,  3.90133d0,  3.90102d0,  3.90041d0 /

      data ( r(i), i=1236,1272) /
     &  3.89981d0,  3.89921d0,  3.89861d0,  3.89802d0,  3.89213d0,
     &  3.88651d0,  3.88138d0,  3.87678d0,  3.87269d0,  3.86904d0,
     &  3.86576d0,  3.86304d0,  3.86033d0,  3.85786d0,  3.85560d0,
     &  3.85351d0,  3.85159d0,  3.84980d0,  3.84813d0,  3.84657d0,
     &  3.84511d0,  3.84374d0,  3.83790d0,  3.83333d0,  3.82959d0,
     &  3.82646d0,  3.82377d0,  3.82142d0,  3.81935d0,  3.81749d0,
     &  3.81581d0,  3.81429d0,  3.81289d0,  3.81160d0,  3.81133d0,
     &  3.81043d0,  3.80932d0 /


      data  (dr(i), i=   1,  95) /
     & 0.301538d-2, 0.450250d-2, 0.765849d-2, 0.132192d-1, 0.205939d-1,
     & 0.974678d-2, 0.175578d-1, 0.338428d-1, 0.113885d-1, 0.168133d-1,
     & 0.234449d-1, 0.666017d-1, 0.607015d-1, 0.326733d-1, 0.313387d-1,
     & 0.290400d-1, 0.302519d-1, 0.285177d-1, 0.330059d-1, 0.245432d-1,
     & 0.226334d-1, 0.303833d-1, 0.344892d-1, 0.361546d-1, 0.411184d-1,
     & 0.362655d-1, 0.268415d-1, 0.426987d-1, 0.461460d-1, 0.486773d-1,
     & 0.534472d-1, 0.416546d-1, 0.348486d-1, 0.472729d-1, 0.592101d-1,
     & 0.642569d-1, 0.754879d-1, 0.516960d-1, 0.420837d-1, 0.752382d-1,
     & 0.905823d-1, 0.869451d-1, 0.942240d-1, 0.752714d-1, 0.680612d-1,
     & 0.617609d-1, 0.574627d-1, 0.575152d-1, 0.619923d-1, 0.580475d-1,
     & 0.577351d-1, 0.625861d-1, 0.599024d-1, 0.693105d-1, 0.737445d-1,
     & 0.732679d-1, 0.746751d-1, 0.778990d-1, 0.828485d-1, 0.892377d-1,
     & 0.967679d-1, 0.105169d0, 0.101697d0, 0.105588d0, 0.111091d0,
     & 0.112781d0, 0.117797d0, 0.125772d0, 0.136208d0, 0.148597d0,
     & 0.162492d0, 0.177533d0, 0.193868d0, 0.235408d0, 0.252601d0,
     & 0.236695d0, 0.249537d0, 0.270805d0, 0.285290d0, 0.296696d0,
     & 0.292721d0, 0.314823d0, 0.293257d0, 0.304420d0, 0.341769d0,
     & 0.334202d0, 0.333561d0, 0.323740d0, 0.318986d0, 0.298101d0,
     & 0.294796d0, 0.281565d0, 0.250552d0, 0.243062d0, 0.226158d0 /

      data (dr(i), i=  96, 190) /
     & 0.210572d0, 0.196608d0, 0.184606d0, 0.174928d0, 0.167931d0,
     & 0.163912d0, 0.163253d0, 0.131729d0, 0.126749d0, 0.115661d0,
     & 0.105754d0, 0.975037d-1, 0.914747d-1, 0.881920d-1, 0.879742d-1,
     & 0.724393d-1, 0.712968d-1, 0.677650d-1, 0.616992d-1, 0.573870d-1,
     & 0.552112d-1, 0.555323d-1, 0.521916d-1, 0.505657d-1, 0.480177d-1,
     & 0.457952d-1, 0.436983d-1, 0.421486d-1, 0.412111d-1, 0.409264d-1,
     & 0.413017d-1, 0.423108d-1, 0.415876d-1, 0.400670d-1, 0.380169d-1,
     & 0.363046d-1, 0.349906d-1, 0.341369d-1, 0.335942d-1, 0.334614d-1,
     & 0.338098d-1, 0.345984d-1, 0.352863d-1, 0.358034d-1, 0.402810d-1,
     & 0.466440d-1, 0.528651d-1, 0.523309d-1, 0.463845d-1, 0.401229d-1,
     & 0.330267d-1, 0.280765d-1, 0.322050d-1, 0.529963d-1, 0.567763d-1,
     & 0.530180d-1, 0.466335d-1, 0.462351d-1, 0.442800d-1, 0.422596d-1,
     & 0.421029d-1, 0.421084d-1, 0.398357d-1, 0.376802d-1, 0.347983d-1,
     & 0.319784d-1, 0.314042d-1, 0.296626d-1, 0.265054d-1, 0.236609d-1,
     & 0.202456d-1, 0.181316d-1, 0.182049d-1, 0.180100d-1, 0.206338d-1,
     & 0.246117d-1, 0.273674d-1, 0.311423d-1, 0.334146d-1, 0.321334d-1,
     & 0.301827d-1, 0.271936d-1, 0.245265d-1, 0.231290d-1, 0.213057d-1,
     & 0.201762d-1, 0.204377d-1, 0.193912d-1, 0.190297d-1, 0.200651d-1,
     & 0.203686d-1, 0.189439d-1, 0.155834d-1, 0.160366d-1, 0.175899d-1/

      data (dr(i), i= 191, 285) /
     & 0.175521d-1, 0.170618d-1, 0.177879d-1, 0.211031d-1, 0.210623d-1,
     & 0.239084d-1, 0.249057d-1, 0.274937d-1, 0.297922d-1, 0.250505d-1,
     & 0.208528d-1, 0.236404d-1, 0.293432d-1, 0.326583d-1, 0.359200d-1,
     & 0.308303d-1, 0.442873d-1, 0.492136d-1, 0.576629d-1, 0.661671d-1,
     & 0.517597d0, 0.497576d0, 0.579832d0, 0.695151d0, 0.678413d0,
     & 0.540611d0, 0.490962d0, 0.562430d0, 0.626584d0, 0.970839d0,
     & 0.945544d0,  1.50883d0,  1.16894d0,  1.25975d0,  1.39339d0,
     &  1.85135d0,  1.93824d0,  2.19156d0,  1.81914d0,  1.29003d0,
     &  1.12404d0, 0.763678d0, 0.787013d0, 0.732160d0, 0.879144d0,
     & 0.762719d0, 0.649423d0, 0.537644d0, 0.430701d0, 0.295578d0,
     & 0.215568d0, 0.846020d-1, 0.453684d-1, 0.394435d-1, 0.830647d-1,
     & 0.564960d-1, 0.514538d-1, 0.797680d-1, 0.704196d-1, 0.587436d-1,
     & 0.354312d-1, 0.332399d-1, 0.330953d-1, 0.310623d-1, 0.618751d-1,
     & 0.411597d-1, 0.464376d-1, 0.338478d-1, 0.322252d-1, 0.321315d-1,
     & 0.337634d-1, 0.350530d-1, 0.355596d-1, 0.366223d-1, 0.380375d-1,
     & 0.384052d-1, 0.385046d-1, 0.412897d-1, 0.426468d-1, 0.422078d-1,
     & 0.452516d-1, 0.490633d-1, 0.485403d-1, 0.492500d-1, 0.512299d-1,
     & 0.546226d-1, 0.725087d-1, 0.782925d-1, 0.853714d-1, 0.952162d-1,
     & 0.109114d0, 0.215461d0, 0.173626d0, 0.162907d0, 0.164353d0 /

      data (dr(i), i= 286, 380) /
     & 0.175001d0, 0.192837d0, 0.185436d0, 0.192671d0, 0.196804d0,
     & 0.208758d0, 0.211045d0, 0.204664d0, 0.211491d0, 0.190684d0,
     & 0.186034d0, 0.183090d0, 0.181911d0, 0.195913d0, 0.185573d0,
     & 0.185606d0, 0.193639d0, 0.196598d0, 0.216605d0, 0.208991d0,
     & 0.201380d0, 0.199222d0, 0.193399d0, 0.196433d0, 0.191549d0,
     & 0.197420d0, 0.203862d0, 0.187611d0, 0.188853d0, 0.185812d0,
     & 0.189581d0, 0.208775d0, 0.167634d0, 0.134488d0, 0.145382d0,
     & 0.227893d0, 0.338221d0, 0.264535d0, 0.255510d0, 0.283790d0,
     & 0.300118d0, 0.423527d0, 0.352984d0, 0.293001d0, 0.251774d0,
     & 0.239744d0, 0.261481d0, 0.215022d0, 0.267897d0, 0.238380d0,
     & 0.184875d0, 0.163329d0, 0.185873d0, 0.188625d0, 0.173354d0,
     & 0.160316d0, 0.150121d0, 0.143446d0, 0.140889d0, 0.153958d0,
     & 0.177549d0, 0.145083d0, 0.127395d0, 0.132125d0, 0.144436d0,
     & 0.125342d0, 0.157003d0, 0.105883d0, 0.111390d0, 0.103843d0,
     & 0.135714d0, 0.114470d0, 0.141287d0, 0.113295d0, 0.136097d0,
     & 0.100042d0, 0.111103d0, 0.110172d0, 0.109251d0, 0.108342d0,
     & 0.107443d0, 0.106557d0, 0.105682d0, 0.104819d0, 0.103970d0,
     & 0.103133d0, 0.102310d0, 0.101500d0, 0.100705d0, 0.999242d-1,
     & 0.991583d-1, 0.984076d-1, 0.976727d-1, 0.969538d-1, 0.962515d-1/

      data (dr(i), i= 381, 475) /
     & 0.955660d-1, 0.948979d-1, 0.942475d-1, 0.936152d-1, 0.930015d-1,
     & 0.924068d-1, 0.918315d-1, 0.912759d-1, 0.907406d-1, 0.902259d-1,
     & 0.897323d-1, 0.892600d-1, 0.888096d-1, 0.883813d-1, 0.882778d-1,
     & 0.881756d-1, 0.880749d-1, 0.879756d-1, 0.878778d-1, 0.877814d-1,
     & 0.876864d-1, 0.875929d-1, 0.875008d-1, 0.874102d-1, 0.873211d-1,
     & 0.872334d-1, 0.871472d-1, 0.870625d-1, 0.869793d-1, 0.868976d-1,
     & 0.868173d-1, 0.867386d-1, 0.866614d-1, 0.865856d-1, 0.865114d-1,
     & 0.864388d-1, 0.863676d-1, 0.862980d-1, 0.862299d-1, 0.861633d-1,
     & 0.860983d-1, 0.860349d-1, 0.859729d-1, 0.859126d-1, 0.858538d-1,
     & 0.857966d-1, 0.857409d-1, 0.856868d-1, 0.856343d-1, 0.855833d-1,
     & 0.855340d-1, 0.855243d-1, 0.855147d-1, 0.855051d-1, 0.854956d-1,
     & 0.854862d-1, 0.854768d-1, 0.854675d-1, 0.854583d-1, 0.854491d-1,
     & 0.854400d-1, 0.854310d-1, 0.854220d-1, 0.854131d-1, 0.854042d-1,
     & 0.853954d-1, 0.853867d-1, 0.853780d-1, 0.853694d-1, 0.853609d-1,
     & 0.853524d-1, 0.853440d-1, 0.853357d-1, 0.853274d-1, 0.853192d-1,
     & 0.853110d-1, 0.853029d-1, 0.852949d-1, 0.852870d-1, 0.852791d-1,
     & 0.852712d-1, 0.852635d-1, 0.852558d-1, 0.852481d-1, 0.852406d-1,
     & 0.852330d-1, 0.852256d-1, 0.852182d-1, 0.852109d-1, 0.852037d-1,
     & 0.851965d-1, 0.851893d-1, 0.851823d-1, 0.851753d-1, 0.851684d-1/

      data (dr(i), i= 476, 570) /
     & 0.851615d-1, 0.851547d-1, 0.851480d-1, 0.851413d-1, 0.851347d-1,
     & 0.851281d-1, 0.851217d-1, 0.851153d-1, 0.851089d-1, 0.851026d-1,
     & 0.850964d-1, 0.850903d-1, 0.850842d-1, 0.850781d-1, 0.850722d-1,
     & 0.850663d-1, 0.850605d-1, 0.850547d-1, 0.850490d-1, 0.850434d-1,
     & 0.850378d-1, 0.850323d-1, 0.850268d-1, 0.850215d-1, 0.850162d-1,
     & 0.850109d-1, 0.850057d-1, 0.850006d-1, 0.849956d-1, 0.849906d-1,
     & 0.849857d-1, 0.849808d-1, 0.849760d-1, 0.849713d-1, 0.849666d-1,
     & 0.849620d-1, 0.849575d-1, 0.849531d-1, 0.849487d-1, 0.849443d-1,
     & 0.849401d-1, 0.849359d-1, 0.849317d-1, 0.849277d-1, 0.849236d-1,
     & 0.849197d-1, 0.849158d-1, 0.849120d-1, 0.849083d-1, 0.849046d-1,
     & 0.849010d-1, 0.848974d-1, 0.848940d-1, 0.848905d-1, 0.848744d-1,
     & 0.848600d-1, 0.848472d-1, 0.848360d-1, 0.848265d-1, 0.848186d-1,
     & 0.848123d-1, 0.848077d-1, 0.848048d-1, 0.848035d-1, 0.848039d-1,
     & 0.848059d-1, 0.848095d-1, 0.848149d-1, 0.848218d-1, 0.848304d-1,
     & 0.848407d-1, 0.848526d-1, 0.848662d-1, 0.848815d-1, 0.848984d-1,
     & 0.849169d-1, 0.849371d-1, 0.849590d-1, 0.849825d-1, 0.850076d-1,
     & 0.850345d-1, 0.850629d-1, 0.850930d-1, 0.851248d-1, 0.851582d-1,
     & 0.851933d-1, 0.852300d-1, 0.852683d-1, 0.853083d-1, 0.853499d-1,
     & 0.853932d-1, 0.854381d-1, 0.854847d-1, 0.855329d-1, 0.856341d-1/

      data (dr(i), i= 571, 665) /
     & 0.857419d-1, 0.858562d-1, 0.859769d-1, 0.861041d-1, 0.862377d-1,
     & 0.863778d-1, 0.865242d-1, 0.866770d-1, 0.868361d-1, 0.870015d-1,
     & 0.871732d-1, 0.873511d-1, 0.875352d-1, 0.877255d-1, 0.879220d-1,
     & 0.881246d-1, 0.883332d-1, 0.885479d-1, 0.887685d-1, 0.889952d-1,
     & 0.892277d-1, 0.894662d-1, 0.897104d-1, 0.899605d-1, 0.902163d-1,
     & 0.904779d-1, 0.907451d-1, 0.910179d-1, 0.912963d-1, 0.915803d-1,
     & 0.918697d-1, 0.921646d-1, 0.924649d-1, 0.927705d-1, 0.930815d-1,
     & 0.933977d-1, 0.937191d-1, 0.940457d-1, 0.943774d-1, 0.947141d-1,
     & 0.950559d-1, 0.954027d-1, 0.957544d-1, 0.961109d-1, 0.964723d-1,
     & 0.968385d-1, 0.972094d-1, 0.975849d-1, 0.979651d-1, 0.983499d-1,
     & 0.987393d-1, 0.991331d-1, 0.995313d-1, 0.999340d-1, 0.100341d0,
     & 0.100752d0, 0.101168d0, 0.101588d0, 0.102012d0, 0.102440d0,
     & 0.102872d0, 0.103308d0, 0.103748d0, 0.104192d0, 0.104640d0,
     & 0.105092d0, 0.105547d0, 0.106007d0, 0.106470d0, 0.106936d0,
     & 0.107407d0, 0.107880d0, 0.108358d0, 0.108839d0, 0.109323d0,
     & 0.109811d0, 0.110302d0, 0.110797d0, 0.111284d0, 0.109640d0,
     & 0.108299d0, 0.107276d0, 0.106582d0, 0.106227d0, 0.106218d0,
     & 0.106558d0, 0.107248d0, 0.108282d0, 0.109656d0, 0.111359d0,
     & 0.113380d0, 0.115704d0, 0.118318d0, 0.121205d0, 0.124349d0 /

      data (dr(i), i= 666, 760) /
     & 0.127733d0, 0.131342d0, 0.135161d0, 0.139160d0, 0.129845d0,
     & 0.122877d0, 0.118727d0, 0.117751d0, 0.120083d0, 0.125591d0,
     & 0.133935d0, 0.126831d0, 0.103663d0, 0.832930d-1, 0.789179d-1,
     & 0.749409d-1, 0.714314d-1, 0.684642d-1, 0.661155d-1, 0.644563d-1,
     & 0.635438d-1, 0.634134d-1, 0.640733d-1, 0.655026d-1, 0.676558d-1,
     & 0.698336d-1, 0.753894d-1, 0.830809d-1, 0.923778d-1, 0.102847d0,
     & 0.114169d0, 0.126114d0, 0.138524d0, 0.151284d0, 0.164315d0,
     & 0.177261d0, 0.172119d0, 0.167048d0, 0.162056d0, 0.157150d0,
     & 0.152339d0, 0.147631d0, 0.143038d0, 0.138572d0, 0.134244d0,
     & 0.130070d0, 0.126065d0, 0.122245d0, 0.118628d0, 0.115235d0,
     & 0.112086d0, 0.109201d0, 0.106604d0, 0.104315d0, 0.102356d0,
     & 0.100746d0, 0.995024d-1, 0.986396d-1, 0.981678d-1, 0.980930d-1,
     & 0.984165d-1, 0.991345d-1, 0.100239d0, 0.101718d0, 0.103555d0,
     & 0.105657d0, 0.103421d0, 0.101459d0, 0.997876d-1, 0.984216d-1,
     & 0.973741d-1, 0.966558d-1, 0.962744d-1, 0.962342d-1, 0.965358d-1,
     & 0.971763d-1, 0.105141d0, 0.119677d0, 0.138758d0, 0.160639d0,
     & 0.136768d0, 0.117887d0, 0.106720d0, 0.105786d0, 0.115373d0,
     & 0.104986d0, 0.970268d-1, 0.997743d-1, 0.112484d0, 0.101213d0,
     & 0.112728d0, 0.142173d0, 0.121040d0, 0.115418d0, 0.152922d0 /

      data (dr(i), i= 761, 855) /
     & 0.128985d0, 0.123122d0, 0.137813d0, 0.167751d0, 0.134698d0,
     & 0.112276d0, 0.107528d0, 0.112864d0, 0.110069d0, 0.145056d0,
     & 0.116395d0, 0.114036d0, 0.110586d0, 0.106036d0, 0.112057d0,
     & 0.113595d0, 0.122086d0, 0.113311d0, 0.128516d0, 0.123647d0,
     & 0.138054d0, 0.147589d0, 0.139925d0, 0.151926d0, 0.136172d0,
     & 0.141193d0, 0.135226d0, 0.133684d0, 0.136095d0, 0.130623d0,
     & 0.135725d0, 0.130216d0, 0.136192d0, 0.129191d0, 0.142845d0,
     & 0.128897d0, 0.132450d0, 0.126232d0, 0.122734d0, 0.112811d0,
     & 0.992078d-1, 0.942802d-1, 0.101522d0, 0.124252d0, 0.132201d0,
     & 0.119816d0, 0.120609d0, 0.123940d0, 0.127461d0, 0.131293d0,
     & 0.136711d0, 0.147724d0, 0.175216d0, 0.171999d0, 0.192289d0,
     & 0.140244d0, 0.144486d0, 0.132738d0, 0.164814d0, 0.155048d0,
     & 0.148811d0, 0.146609d0, 0.148678d0, 0.154897d0, 0.164848d0,
     & 0.177952d0, 0.193611d0, 0.211298d0, 0.230549d0, 0.209396d0,
     & 0.190315d0, 0.174048d0, 0.161515d0, 0.153704d0, 0.151418d0,
     & 0.154972d0, 0.164053d0, 0.177879d0, 0.195475d0, 0.182394d0,
     & 0.171646d0, 0.163733d0, 0.159121d0, 0.158145d0, 0.160913d0,
     & 0.167282d0, 0.176904d0, 0.189320d0, 0.203998d0, 0.162353d0,
     & 0.163790d0, 0.178583d0, 0.173014d0, 0.168301d0, 0.164528d0 /

      data (dr(i), i= 856, 950) /
     & 0.161773d0, 0.160103d0, 0.159564d0, 0.160181d0, 0.161952d0,
     & 0.164853d0, 0.168839d0, 0.173847d0, 0.179792d0, 0.173866d0,
     & 0.168745d0, 0.164514d0, 0.161256d0, 0.159043d0, 0.157931d0,
     & 0.157954d0, 0.159125d0, 0.161431d0, 0.164836d0, 0.174710d0,
     & 0.168204d0, 0.158096d0, 0.151613d0, 0.149318d0, 0.151490d0,
     & 0.158034d0, 0.157925d0, 0.150634d0, 0.147109d0, 0.147702d0,
     & 0.152444d0, 0.161045d0, 0.166935d0, 0.157389d0, 0.150779d0,
     & 0.147569d0, 0.148050d0, 0.152256d0, 0.159952d0, 0.153210d0,
     & 0.149904d0, 0.150330d0, 0.154524d0, 0.162259d0, 0.173120d0,
     & 0.167628d0, 0.158493d0, 0.152564d0, 0.150290d0, 0.150606d0,
     & 0.151901d0, 0.154158d0, 0.157344d0, 0.161405d0, 0.158055d0,
     & 0.155774d0, 0.154618d0, 0.154623d0, 0.155799d0, 0.158129d0,
     & 0.161573d0, 0.166071d0, 0.171549d0, 0.177925d0, 0.185115d0,
     & 0.193036d0, 0.168710d0, 0.153859d0, 0.200986d0, 0.172933d0,
     & 0.152414d0, 0.142826d0, 0.146442d0, 0.162417d0, 0.143589d0,
     & 0.199333d0, 0.166021d0, 0.170751d0, 0.211175d0, 0.185581d0,
     & 0.170914d0, 0.170142d0, 0.183549d0, 0.208464d0, 0.184217d0,
     & 0.171775d0, 0.173809d0, 0.189962d0, 0.217148d0, 0.190537d0,
     & 0.175141d0, 0.174081d0, 0.187709d0, 0.213273d0, 0.187096d0 /

      data (dr(i), i= 951,1045) /
     & 0.172844d0, 0.173603d0, 0.189301d0, 0.216760d0, 0.189991d0,
     & 0.175301d0, 0.175865d0, 0.191658d0, 0.219461d0, 0.191021d0,
     & 0.171614d0, 0.164577d0, 0.171542d0, 0.191035d0, 0.170355d0,
     & 0.159042d0, 0.159192d0, 0.170858d0, 0.191983d0, 0.169852d0,
     & 0.157195d0, 0.156422d0, 0.167782d0, 0.189135d0, 0.167941d0,
     & 0.156858d0, 0.158119d0, 0.171536d0, 0.194642d0, 0.172416d0,
     & 0.160173d0, 0.160312d0, 0.172886d0, 0.195544d0, 0.173385d0,
     & 0.161546d0, 0.162392d0, 0.175826d0, 0.199349d0, 0.173284d0,
     & 0.151314d0, 0.135514d0, 0.128256d0, 0.131025d0, 0.124162d0,
     & 0.120819d0, 0.121314d0, 0.125627d0, 0.133399d0, 0.126113d0,
     & 0.121991d0, 0.121381d0, 0.124359d0, 0.130702d0, 0.126974d0,
     & 0.126293d0, 0.131127d0, 0.140942d0, 0.154801d0, 0.142794d0,
     & 0.136324d0, 0.136226d0, 0.142554d0, 0.154537d0, 0.142145d0,
     & 0.135450d0, 0.135343d0, 0.141883d0, 0.154236d0, 0.138184d0,
     & 0.136021d0, 0.148446d0, 0.172298d0, 0.154763d0, 0.149928d0,
     & 0.145251d0, 0.140750d0, 0.136442d0, 0.132347d0, 0.128486d0,
     & 0.124880d0, 0.121555d0, 0.118533d0, 0.115839d0, 0.113497d0,
     & 0.111530d0, 0.109958d0, 0.108801d0, 0.108071d0, 0.107778d0,
     & 0.107926d0, 0.108514d0, 0.109537d0, 0.123498d0, 0.176019d0 /

      data (dr(i), i=1046,1140) /
     & 0.243899d0, 0.317075d0, 0.280358d0, 0.268974d0, 0.286010d0,
     & 0.327091d0, 0.384621d0, 0.452394d0, 0.526083d0, 0.474416d0,
     & 0.423219d0, 0.372698d0, 0.323185d0, 0.275242d0, 0.229872d0,
     & 0.188963d0, 0.156093d0, 0.137200d0, 0.138177d0, 0.142499d0,
     & 0.140431d0, 0.138582d0, 0.136961d0, 0.135577d0, 0.134437d0,
     & 0.133549d0, 0.132916d0, 0.132545d0, 0.132436d0, 0.132592d0,
     & 0.133011d0, 0.133693d0, 0.134632d0, 0.135824d0, 0.137264d0,
     & 0.138943d0, 0.140853d0, 0.142987d0, 0.145319d0, 0.141781d0,
     & 0.138649d0, 0.135954d0, 0.133723d0, 0.131981d0, 0.130750d0,
     & 0.130047d0, 0.129880d0, 0.130254d0, 0.131167d0, 0.132608d0,
     & 0.134562d0, 0.137009d0, 0.139924d0, 0.143258d0, 0.134326d0,
     & 0.129818d0, 0.130208d0, 0.135468d0, 0.145056d0, 0.139584d0,
     & 0.135105d0, 0.131725d0, 0.129534d0, 0.128595d0, 0.128942d0,
     & 0.130567d0, 0.133427d0, 0.137449d0, 0.142519d0, 0.137278d0,
     & 0.133652d0, 0.131779d0, 0.131739d0, 0.133541d0, 0.137116d0,
     & 0.142337d0, 0.149035d0, 0.157026d0, 0.166053d0, 0.204013d0,
     & 0.330101d0, 0.479342d0, 0.635337d0, 0.531258d0, 0.429342d0,
     & 0.331693d0, 0.243648d0, 0.180101d0, 0.171139d0, 0.162342d0,
     & 0.155103d0, 0.149652d0, 0.146197d0, 0.144888d0, 0.145789d0 /

      data (dr(i), i=1141,1235) /
     & 0.148865d0, 0.153993d0, 0.160983d0, 0.169579d0, 0.161617d0,
     & 0.157669d0, 0.158049d0, 0.162740d0, 0.171399d0, 0.183478d0,
     & 0.198361d0, 0.215479d0, 0.234351d0, 0.254533d0, 0.239858d0,
     & 0.232433d0, 0.232975d0, 0.241453d0, 0.257104d0, 0.278743d0,
     & 0.305115d0, 0.335122d0, 0.367890d0, 0.402759d0, 0.439242d0,
     & 0.476981d0, 0.515557d0, 0.459893d0, 0.404533d0, 0.349649d0,
     & 0.295536d0, 0.242749d0, 0.192434d0, 0.147210d0, 0.113427d0,
     & 0.103115d0, 0.102859d0, 0.103488d0, 0.104988d0, 0.107325d0,
     & 0.110448d0, 0.114295d0, 0.118798d0, 0.123887d0, 0.129496d0,
     & 0.135561d0, 0.142027d0, 0.148842d0, 0.155963d0, 0.163352d0,
     & 0.170974d0, 0.178803d0, 0.186812d0, 0.194982d0, 0.203294d0,
     & 0.211733d0, 0.220285d0, 0.228939d0, 0.237684d0, 0.246513d0,
     & 0.255418d0, 0.264391d0, 0.273427d0, 0.282522d0, 0.291670d0,
     & 0.300867d0, 0.310110d0, 0.319396d0, 0.328722d0, 0.338086d0,
     & 0.347484d0, 0.356916d0, 0.366379d0, 0.375872d0, 0.385393d0,
     & 0.394941d0, 0.404515d0, 0.414113d0, 0.423734d0, 0.433378d0,
     & 0.443044d0, 0.452730d0, 0.462437d0, 0.472163d0, 0.521065d0,
     & 0.160814d-1, 0.155864d-1, 0.151189d-1, 0.146766d-1, 0.142577d-1,
     & 0.138605d-1, 0.134835d-1, 0.131254d-1, 0.127852d-1, 0.121548d-1/

      data (dr(i), i=1236,1272) /
     & 0.115853d-1, 0.110684d-1, 0.105985d-1, 0.101707d-1, 0.749852d-2,
     & 0.640855d-2, 0.590842d-2, 0.562789d-2, 0.543383d-2, 0.527870d-2,
     & 0.512546d-2, 0.505866d-2, 0.496626d-2, 0.482836d-2, 0.469769d-2,
     & 0.457790d-2, 0.446794d-2, 0.436679d-2, 0.427352d-2, 0.418730d-2,
     & 0.410738d-2, 0.403309d-2, 0.372808d-2, 0.350083d-2, 0.332327d-2,
     & 0.318449d-2, 0.306417d-2, 0.296184d-2, 0.287333d-2, 0.279568d-2,
     & 0.272680d-2, 0.266508d-2, 0.260935d-2, 0.255866d-2, 0.254489d-2,
     & 0.251003d-2, 0.246752d-2/


      data ( w_res( 1, i ), i= 1,11 ) /
     &   3.0965424d0,   3.0967292d0,   3.0968226d0,   3.0968693d0,
     &   3.0968927d0,   3.0969160d0,   3.0969393d0,   3.0969627d0,
     &   3.0970094d0,   3.0971028d0,   3.0972896d0 /

      data ( r_res( 1, i ), i= 1,11 ) /
     &   2.2378883d0,   2.2377579d0,   2.2376927d0,   2.2376601d0,
     &   2.2376438d0,   2.2376276d0,   2.2376113d0,   2.2375950d0,
     &   2.2375624d0,   2.2374972d0,   2.2373668d0 /

      data (dr_res( 1, i ), i= 1,11 ) /
     &   0.0850475d0,   0.0850371d0,   0.0850319d0,   0.0850294d0,
     &   0.0850281d0,   0.0850268d0,   0.0850256d0,   0.0850243d0,
     &   0.0850218d0,   0.0850169d0,   0.0850071d0 /

      data ( w_res( 2, i ), i= 1,11 ) /
     &   3.6849850d0,   3.6855390d0,   3.6858160d0,   3.6859545d0,
     &   3.6860237d0,   3.6860930d0,   3.6861623d0,   3.6862315d0,
     &   3.6863700d0,   3.6866470d0,   3.6872010d0 /

      data ( r_res( 2, i ), i= 1,11 ) /
     &   2.4399092d0,   2.4356800d0,   2.4335651d0,   2.4325077d0,
     &   2.4319789d0,   2.4314501d0,   2.4309214d0,   2.4303926d0,
     &   2.4293350d0,   2.4272197d0,   2.4229885d0 /

      data (dr_res( 2, i ), i= 1,11 ) /
     &   0.1121795d0,   0.1105427d0,   0.1097560d0,   0.1093707d0,
     &   0.1091801d0,   0.1089909d0,   0.1088030d0,   0.1086166d0,
     &   0.1082479d0,   0.1075275d0,   0.1061565d0 /

      data ( w_res( 3, i ), i= 1,11 ) /
     &   9.4600839d0,   9.4601920d0,   9.4602460d0,   9.4602730d0,
     &   9.4602865d0,   9.4603000d0,   9.4603135d0,   9.4603270d0,
     &   9.4603540d0,   9.4604080d0,   9.4605161d0 /

      data ( r_res( 3, i ), i= 1,11 ) /
     &   3.8618729d0,   3.8608308d0,   3.8603097d0,   3.8600492d0,
     &   3.8599189d0,   3.8597887d0,   3.8596584d0,   3.8595281d0,
     &   3.8592676d0,   3.8587465d0,   3.8577043d0 /

      data (dr_res( 3, i ), i= 1,11 ) /
     &   0.4225272d0,   0.4214277d0,   0.4208780d0,   0.4206032d0,
     &   0.4204658d0,   0.4203285d0,   0.4201911d0,   0.4200537d0,
     &   0.4197790d0,   0.4192296d0,   0.4181310d0 /

      data ( w_res( 4, i ), i= 1,11 ) /
     &  10.0231321d0,  10.0231960d0,  10.0232280d0,  10.0232440d0,
     &  10.0232520d0,  10.0232600d0,  10.0232680d0,  10.0232760d0,
     &  10.0232920d0,  10.0233240d0,  10.0233879d0 /

      data ( r_res( 4, i ), i= 1,11 ) /
     &   3.5413395d0,   3.5412502d0,   3.5412055d0,   3.5411832d0,
     &   3.5411720d0,   3.5411609d0,   3.5411497d0,   3.5411385d0,
     &   3.5411162d0,   3.5410715d0,   3.5409822d0 /

      data (dr_res( 4, i ), i= 1,11 ) /
     &   0.3753248d0,   0.3762684d0,   0.3767404d0,   0.3769765d0,
     &   0.3770945d0,   0.3772126d0,   0.3773306d0,   0.3774487d0,
     &   0.3776849d0,   0.3781573d0,   0.3791025d0 /

      data ( w_res( 5, i ), i= 1,11 ) /
     &  10.3551187d0,  10.3551594d0,  10.3551797d0,  10.3551898d0,
     &  10.3551949d0,  10.3552000d0,  10.3552051d0,  10.3552102d0,
     &  10.3552203d0,  10.3552406d0,  10.3552813d0 /

      data ( r_res( 5, i ), i= 1,11 ) /
     &   3.3665824d0,   3.3665909d0,   3.3665951d0,   3.3665972d0,
     &   3.3665983d0,   3.3665993d0,   3.3666004d0,   3.3666014d0,
     &   3.3666035d0,   3.3666078d0,   3.3666162d0 /

      data (dr_res( 5, i ), i= 1,11 ) /
     &   0.2674783d0,   0.2675667d0,   0.2676110d0,   0.2676331d0,
     &   0.2676442d0,   0.2676553d0,   0.2676663d0,   0.2676774d0,
     &   0.2676995d0,   0.2677439d0,   0.2678325d0 /

      data ( w_res( 6, i ), i= 1, 9 ) /
     &  10.5594000d0,  10.5694000d0,  10.5744000d0,  10.5769000d0,
     &  10.5794000d0,  10.5819000d0,  10.5844000d0,  10.5894000d0,
     &  10.5994000d0 /

      data ( r_res( 6, i ), i= 1, 9 ) /
     &   3.5680194d0,   3.5700595d0,   3.5710803d0,   3.5715909d0,
     &   3.5721016d0,   3.5726124d0,   3.5731233d0,   3.5741456d0,
     &   3.5761915d0 /

      data (dr_res( 6, i ), i= 1, 9 ) /
     &   0.1071577d0,   0.1102339d0,   0.1120491d0,   0.1130224d0,
     &   0.1140381d0,   0.1150950d0,   0.1161921d0,   0.1185025d0,
     &   0.1235577d0 /

      data ( w_res( 7, i ), i= 1, 9 ) /
     &  10.8450000d0,  10.8550000d0,  10.8600000d0,  10.8625000d0,
     &  10.8650000d0,  10.8675000d0,  10.8700000d0,  10.8750000d0,
     &  10.8850000d0 /

      data ( r_res( 7, i ), i= 1, 9 ) /
     &   3.6270458d0,   3.6291411d0,   3.6301894d0,   3.6307138d0,
     &   3.6312383d0,   3.6317629d0,   3.6322876d0,   3.6333374d0,
     &   3.6354385d0 /

      data (dr_res( 7, i ), i= 1, 9 ) /
     &   0.3240394d0,   0.3333844d0,   0.3380707d0,   0.3404171d0,
     &   0.3427657d0,   0.3451165d0,   0.3474693d0,   0.3521812d0,
     &   0.3616289d0 /

      data ( w_res( 8, i ), i= 1, 9 ) /
     &  10.9940000d0,  11.0065000d0,  11.0127500d0,  11.0158750d0,
     &  11.0190000d0,  11.0221250d0,  11.0252500d0,  11.0315000d0,
     &  11.0440000d0 /

      data ( r_res( 8, i ), i= 1, 9 ) /
     &   3.6584656d0,   3.6611210d0,   3.6624498d0,   3.6631145d0,
     &   3.6637794d0,   3.6644445d0,   3.6651098d0,   3.6664408d0,
     &   3.6691053d0 /

      data (dr_res( 8, i ), i= 1, 9 ) /
     &   0.4663094d0,   0.4784794d0,   0.4845753d0,   0.4876259d0,
     &   0.4906782d0,   0.4937323d0,   0.4967882d0,   0.5029049d0,
     &   0.5151585d0 /

c begin ====================================================

      if ( ( w_input .lt. w(1) ) .or. ( w(NUMPTS) .lt. w_input ) ) then
ctt
         write(*,*) "ERROR: w outside range of R tabulation"
         r_out = 0.d0
         dr_out = 0.d0
         return
      endif 

      do i = 1, NUMPTS - 1

         if ( ( w(i) .le. w_input ) .and. ( w_input .lt. w(i+1) ) ) then

            r_out =   ( r( i+1 ) - r( i ) ) 
     &                / ( w( i+1 ) - w( i ) ) * ( w_input - w( i ) ) 
     &                + r( i )

            dr_out =   ( dr( i+1 ) - dr( i ) ) 
     &                / ( w( i+1 ) - w( i ) ) * ( w_input - w( i ) ) 
     &                + dr( i )

            goto 999

         endif

      enddo

 999  continue

c special treatment close to resonances --------------------

      do j = 1, 8

         i_last = 11
         if (j .ge. 6) i_last = 9

         if ( ( w_res(j,1) .le. w_input ) .and.
     &        ( w_input .lt. w_res(j,i_last) ) ) then
            
            do i = 1, i_last - 1

               if (( w_res(j,i) .le. w_input ) .and. 
     &             ( w_input .lt. w_res(j,i+1) )) then

                  r_out =   ( r_res( j,i+1 ) - r_res( j,i ) ) 
     &                    / ( w_res( j,i+1 ) - w_res( j,i ) ) 
     &                    * ( w_input - w_res( j,i ) ) 
     &                    + r_res( j,i )

                  dr_out =   ( dr_res( j,i+1 ) - dr_res( j,i ) ) 
     &                 / ( w_res( j,i+1 ) - w_res( j,i ) ) 
     &                 * ( w_input - w_res( j,i ) ) 
     &                 + dr_res( j,i )

                  return

               endif

            enddo

         endif

      enddo

      return
      end

c
c
ctt
c Routine for \Delta\alpha_{lep}
ctt
      real*8 function alf_lep(gen_lep, s)
      implicit NONE
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c Calculates Leptonic Contribution \Delta \alpha_lep(s) 
c at LO, NLO and NNLO
c
c   Pi0 := ( Pi(qsq) - Pi(0) )_LO ,                   
c   Pi1 := ( Pi(qsq) - Pi(0) )_NLO ,                  
c
c (Taking real part of Pi is assumed.)
c
c LO and NLO results are checked against the results given in 
c Steinhauser, hep-ph/9803313 
c
c Test at s = Mz^2 using PDG97 values for a comparison with 
c Table 1 of Steinhauser, hep-ph/9803313.  Perfect agreement!
c
c          e             mu            tau
c LO  0.0174346533  0.00917841908  0.00480593422  *1
c LO  0.0174346533  0.00917841908  0.00480592861  *2
c LO  0.0174346531  0.00917841908  0.00480592861  (full formula)
c NLO 0.0000379829  0.00002359991  0.00001603387  (full formula)
c NNLO0.0000003821  0.00000036614  0.00000031449  *3
c
c *1 An expansion up to and including M^2/s terms is used.
c *2 An expansion up to and including M^4/s^2 terms is used.
c *3 The expansion given in hep-ph/9803313 (up to and including 
c    M^2/s terms) is used.
c
c Aug 2009: expression for Pi_1 at q^2/m^2 << 1 improved.
c Mar 2010: CERNLIB no longer necessary to evaluate ReF and ImG
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c input ----------------------------------------------------
      integer gen_lep
      real*8 s
c const ----------------------------------------------------
      real*8 Me, Mmu, Mtau, ALPHA, PI, ZETA2, ZETA3, ZETA5
      Parameter(Me=0.510998902d-3, Mmu=0.1056583568d0, Mtau=1.77699d0)!PDG03 
      Parameter( ALPHA = 1.d0/137.03599976d0 ) !PDG03
      Parameter( PI = 3.141592653589793238d0, ZETA2 = PI ** 2 / 6.d0 )
      Parameter( ZETA3 = 1.2020569032d0,      ZETA5 = 1.0369277551d0 )
c function, tmp var. ---------------------------------------
      real*8 Pi0, Pi1, eta, mlep
      real*8 PiA, Piell, PiF, Pih, eta1, eta2, stepf, y
      real*8 alf_lepLO, alf_lepNLO, alf_lepNNLO 
c begin ====================================================
c define functions -----------------------------------------
c NNLO -----------------------------------------------------

      stepf( y ) = ( 1.d0 + abs( y ) / y ) / 2.d0

      PiA( eta ) = 1.d0/(16.d0 * PI **2) * 
     &   ( -121.d0/48.d0 + ( -5.d0 + 8.d0 * Log(2.d0) ) * ZETA2 
     &     - 99.d0/16.d0 * ZETA3 + 10.d0 * ZETA5
     &     +  1.d0/ 8.d0 * Log( abs( 1.d0/eta ) ) )

      Piell( eta1, eta2 ) = 1.d0/(16.d0 * PI**2) * 
     & ( -116.d0/27.d0 + 4.d0/3.d0 * ZETA2 + 38.d0/9.d0 * ZETA3
     &  +  14.d0/9.d0 * Log( abs(1.d0/eta1) ) 
     &  + ( 5.d0/18.d0 - 4.d0/3.d0 * ZETA3 ) * Log( abs(1.d0/eta2) )  
     &  +   1.d0/6.d0 * ( Log( abs(1.d0/eta1) ) **2 
     &                    - PI ** 2 * stepf( - eta1 ) )
     &  -   1.d0/3.d0 * ( Log( abs(1.d0/eta1) ) * Log( abs(1.d0/eta2) )  
     &                    - PI ** 2 * stepf( - eta1 ) ) ) 

      PiF( eta ) = 1.d0/(16.d0 * PI **2) * 
     &  ( -307.d0/216.d0 - 8.d0/3 * ZETA2 + 545.d0/144.d0 * ZETA3
     &  + ( 11.d0/6.d0 - 4.d0/3.d0 * ZETA3 ) * Log( abs(1.d0/eta) ) 
     &  -    1.d0/6.d0 * ( Log( abs(1.d0/eta) ) **2 
     &                     - PI **2 * stepf( - eta ) ) )

      Pih( eta ) = 1.d0/(16.d0 * PI **2) * 
     & ( -37.d0/6.d0 + 38.d0/9.d0 * ZETA3 
     &  +  ( 11.d0/6.d0 - 4.d0/3.d0 * ZETA3 ) * Log( abs(1.d0/eta) )  
     &  -  1.d0/6.d0 * ( Log( abs(1.d0/eta) ) **2 
     &                   - PI **2 * stepf( - eta ) ) ) 

c calc contributions to \Delta \alpha ----------------------

      if ( gen_lep .eq. 1 ) mlep = Me 
      if ( gen_lep .eq. 2 ) mlep = Mmu 
      if ( gen_lep .eq. 3 ) mlep = Mtau 

      alf_lepLO = - 4.d0 * PI * ALPHA * Pi0( - mlep **2 / s ) 

      alf_lepNLO = - 4.d0 * PI * ALPHA * ( ALPHA / PI ) *
     &             Pi1( - mlep **2 / s ) 

      if ( gen_lep .eq. 1 ) then

         alf_lepNNLO = - 4.d0 * PI * ALPHA * ( ALPHA / PI )**2 * ( 
     &         PiA( - me**2/ s ) 
     &      +  PiF( - me**2/ s ) 
     &      +  Pih( - mmu**2 / s ) 
     &      +  Pih( - mtau**2/ s ) 
     &         )

      else if ( gen_lep .eq. 2 ) then

         alf_lepNNLO = - 4.d0 * PI * ALPHA * ( ALPHA / PI )**2 * ( 
     &        PiA( - mmu**2/ s ) 
     &      + Piell( - mmu**2/ s, - me**2/ s ) 
     &      + PiF( - mmu**2/ s ) 
     &      + Pih( - mtau**2/ s ) 
     &        )

      else if ( gen_lep .eq. 3 ) then

         alf_lepNNLO = - 4.d0 * PI * ALPHA * ( ALPHA / PI )**2 * ( 
     &        PiA( - mtau**2/ s ) 
     &      + Piell( - mtau**2/ s, - me**2 / s ) 
     &      + Piell( - mtau**2/ s, - mmu**2/ s ) 
     &      + PiF( - mtau**2/ s ) 
     &        ) 

      end if

c default
      alf_lep = alf_lepLO + alf_lepNLO + alf_lepNNLO
c default, end

      return
      end


      real*8 function Pi0( eta )
      implicit NONE
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      real*8 eta, PI
      Parameter( PI = 3.141592653589793238d0 )

      if ( eta .gt. 0.d0 ) then  ! spacelike (above the threshold)

         Pi0 = (
     &      5.d0 - 12.d0 * eta
     &       + 3.d0 * ( -1.d0 + 2.d0 * eta ) * sqrt( 1.d0 + 4.d0 * eta )
     &              * log(   ( 1.d0 + sqrt( 1.d0 + 4.d0 * eta ) )
     &                     / (-1.d0 + sqrt( 1.d0 + 4.d0 * eta ) ) )
     &      ) / ( 36.d0 * PI **2 )

      else if ( ( eta .ge. -0.25d0 ) .and. ( eta .lt. 0.d0 ) ) then
                 ! timelike, above the threshold

         Pi0 = (
     &      5.d0 - 12.d0 * eta
     &       + 3.d0 * ( -1.d0 + 2.d0 * eta ) * sqrt( 1.d0 + 4.d0 * eta ) 
     &              * log(   ( 1.d0 + sqrt( 1.d0 + 4.d0 * eta ) )
     &                  / abs( 1.d0 - sqrt( 1.d0 + 4.d0 * eta ) ) ) 
     &      ) / ( 36.d0 * PI **2 )

      else if ( ( -0.5d0 .lt. eta ) .and. ( eta .lt. -0.25d0 ) ) then 

         Pi0 = (
     &      5.d0 - 12.d0 * eta
     &       + 3.d0 * ( -1.d0 + 2.d0 * eta ) * sqrt(-1.d0 - 4.d0 * eta ) 
     &              * ( PI + atan( sqrt( - 1.d0 - 4.d0 * eta )
     &                               / ( - 1.d0 - 2.d0 * eta ) ) ) 
     &      ) / ( 36.d0 * PI **2 )

      else if ( eta .eq. -0.5d0 ) then 

         Pi0 = (
     &      5.d0 - 12.d0 * eta
     &       + 3.d0 * ( -1.d0 + 2.d0 * eta ) * sqrt(-1.d0 - 4.d0 * eta ) 
     &              * ( PI / 2.d0 )
     &      ) / ( 36.d0 * PI **2 )

      else if ( eta .lt. -0.5d0 ) then 

         Pi0 = (
     &      5.d0 - 12.d0 * eta
     &       + 3.d0 * ( -1.d0 + 2.d0 * eta ) * sqrt(-1.d0 - 4.d0 * eta ) 
     &              * ( atan( sqrt( - 1.d0 - 4.d0 * eta )
     &                          / ( - 1.d0 - 2.d0 * eta ) ) ) 
     &      ) / ( 36.d0 * PI **2 )

      endif

      return
      end



      real*8 function Pi1( eta )
      implicit NONE
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      real*8 y, f, g, eta, ReF, ImG, x, a, stepf, theta, alpha
      real*8 dli3, dli2, PI, ZETA3
      Parameter( PI = 3.141592653589793238d0 )
      Parameter( ZETA3 = 1.2020569032d0 )

      stepf( y ) = ( 1.d0 + abs( y ) / y ) / 2.d0

      f( y ) =   6.d0 * dli3( y ) 
     &         - 4.d0 * dli2( y ) * Log( abs( y ) ) 
     &         - ( log( abs( y ) )**2 - stepf( - y ) * PI ** 2 ) 
     &           * log( 1.d0 - y )

      g( y ) =   2.d0 * dli2( y ) 
     &         + 2.d0 * log( abs( y ) ) * Log( 1.d0 - y ) 
     &         + y / ( 1.d0 - y ) 
     &           * ( log( abs( y ) ) **2 - stepf( - y ) * PI ** 2 )

      x( a ) = 4.d0 * a / ( 1.d0 + sqrt( 1.d0 + 4.d0 * a ) ) **2

      if ( eta .gt. 0.d0 ) then      ! spacelike (below the threshold)

         Pi1 = 1.d0  / (16.d0 * PI **2) * (
     &     5.d0/6.d0 - 26.d0/3.d0 * eta
     &  + sqrt( 1.d0 + 4.d0 * eta ) * ( 1.d0 - 6.d0 * eta )
     &    * log( x( eta ) )
     &  - 2.d0/3.d0 * eta * ( 4.d0 + eta ) * log( x( eta ) ) **2
     &  + 2.d0/3.d0 * ( 4.d0 * eta **2 - 1.d0 )
     &    * ( 6.d0 * ZETA3 + f( x( eta )**2 ) - 2.d0 * f( x( eta ) ) )
     &  - 4.d0 / 3.d0 * ( 1.d0 - 2.d0 * eta )
     &    * Sqrt( 1.d0 + 4.d0 * eta )
     &    * ( g( x( eta )**2 ) - g( x( eta ) ) )    )

      else if ( ( eta .lt. 0.d0 ) .and. ( -0.25d0 .lt. eta ) ) then
                  ! timelike, above the threshold

         Pi1 = 1.d0  / (16.d0 * PI **2) * ( 
     &     5.d0/6.d0 - 26.d0/3.d0 * eta
     &  + sqrt( 1.d0 + 4.d0 * eta ) * ( 1.d0 - 6.d0 * eta ) 
     &    * log( - x( eta ) )
     &  - 2.d0/3.d0 * eta * ( 4.d0 + eta ) 
     &    * ( log( - x( eta ) ) **2 - PI ** 2 )
     &  + 2.d0/3.d0 * ( 4.d0 * eta **2 - 1.d0 ) 
     &    * ( 6.d0 * ZETA3
     &       + f( x( eta )**2 ) - 2.d0 * f( x( eta ) ) )  
     &  - 4.d0 / 3.d0 * ( 1.d0 - 2.d0 * eta ) 
     &    * Sqrt( 1.d0 + 4.d0 * eta ) 
     &    * ( g( x( eta )**2 ) - g( x( eta ) ) )    ) 

      else if ( eta .le. -0.25d0 ) then      ! below the threshold

         alpha = sqrt( - 1.d0 - 4.d0 * eta )

         if ( - 0.5d0 .lt. eta ) then
            theta = PI + atan( 2.d0 * alpha / ( alpha ** 2 - 1.d0 ) )
         else if ( eta .lt. - 0.5d0 ) then
            theta = atan( 2.d0 * alpha / ( alpha ** 2 - 1.d0 ) )
         else if ( eta .eq. - 0.5d0 ) then
            theta = PI / 2.d0
         endif

         Pi1 = 1.d0 / (16.d0 * PI **2) * ( 
     &     5.d0/6.d0 - 26.d0/3.d0 * eta
     &  - alpha * ( 1.d0 - 6.d0 * eta ) * theta
     &  + 2.d0/3.d0 * eta * ( 4.d0 + eta ) * theta ** 2
     &  + 2.d0/3.d0 * ( 4.d0 * eta **2 - 1.d0 ) 
     &    * ( 6.d0 * ZETA3 + ReF( 2.d0 * theta ) - 2.d0 * ReF( theta ) )  
     &  + 4.d0 / 3.d0 * ( 1.d0 - 2.d0 * eta ) * alpha
     &    * ( ImG( 2.d0 * theta ) - ImG( theta ) )    
     &                                     ) 

      endif

c added, Aug 2009 
      if ( abs(eta) .ge. 30.d0 ) then

         Pi1 = 1.d0 / (16.d0 * PI **2) * (
     &            82.d0/81.d0   / ( - eta ) 
     &         + 449.d0/2700.d0 / ( - eta ) **2
     &       + 62479.d0/1984500.d0 / ( - eta ) **3 )

      endif
c added, Aug 2009, end 

      return
      end



      real*8 function ReF( phi )
      implicit NONE
      real*8 ZETA3, phi, intlnsin, inttlnsin 
      Parameter( ZETA3 = 1.2020569032d0 )

      if ( phi .le. 0.01d0 ) then

         ReF =  6.d0 * ZETA3          - 0.5d0 * phi **2
     &        - 1.d0/144.d0 * phi **4 - 1.d0/7200.d0 * phi **6

      else

         ReF =  6.d0 * ZETA3 + 2.d0 * phi * intlnsin( phi )
     &        - 6.d0 * inttlnsin( phi )
     &        + phi **2 * log( sin( phi / 2.d0 ) )

      endif

      return
      end


      real*8 function ImG( phi )
      implicit NONE
      real*8 phi, intlnsin

      if ( phi .le. 0.01d0 ) then

         ImG = phi + 1.d0 / 36.d0 * phi **3 + 1.d0 / 1200.d0 * phi **5

      else

         ImG = - 2.d0 * intlnsin( phi ) 
     &      + phi * log( sin( phi / 2.d0 ) ** 2 ) 
     &      - phi **2 / 2.d0 * sin( phi ) / ( 1.d0 - cos( phi ) )

      endif

      return
      end

c ----------------------------------------------------------

      real*8 function intlnsin( x )
      implicit NONE
c ----------------------------------------------------------
c
c function which returns an approximate value of
c   \int_0^x dt ln(sin(t/2))
c for 0 <= x < 2 \pi
c
c The relative accuracy 
c   \delta \int_0^x dt ln(sin(t/2)) / \int_0^x dt ln(sin(t/2))
c is better than 1 x 10^{-9} for 0 <= x < 2 \pi.
c
c ----------------------------------------------------------
      real*8 PI, x, lnsinapprox
      Parameter ( PI = 3.141592653589793238d0 )
      
      if ( x .le. PI ) intlnsin = lnsinapprox( x )

      if ( ( x .gt. PI ) .and. ( x .le. 2.d0 * PI ) )
     &     intlnsin = 2.d0 * lnsinapprox( PI ) 
     &     - lnsinapprox( 2.d0 * PI - x )

      end


      real*8 function lnsinapprox( x )
      implicit NONE
      real*8 PI, x, t
      Parameter ( PI = 3.141592653589793238d0 )

      if ( x.le.1.18d0 ) then

         lnsinapprox = x * log( x / 2.d0 ) - x 
     &     - x **3 / 72.d0      - x **5 / 14400.d0 
     &     - x **7 / 1270080.d0 - x **9 / 87091200.d0 
     &     - x **11 / 5269017600.d0

      elseif ( x.lt. 2.1d0 ) then

         t = PI / 2.d0 - x

         lnsinapprox = - 2.0047586393d0   + t / 2.d0 * log( 2.d0 ) 
     &        + t **2 / 4.d0              + t **3 / 12.d0 
     &        + t **4 / 48.d0             + t **5 / 120.d0 
     &        + t **6 / 288.d0            + t **7 / 630.d0 
     &        + t **8 * 61.d0 / 80640.d0  + t **9 * 17.d0 / 45360.d0 
     &        + t **10 * 277.d0 / 1451520.d0 
     &        + t **11 * 31.d0 / 28350.d0 / 11.d0 
     &        + t **12 * 50521.d0 / 79833600.d0 / 12.d0 
     &        + t **13 * 691.d0 / 1871100.d0 / 13.d0 

      elseif ( x.le. PI ) then

         t = x - PI

         lnsinapprox = - 2.1775860903d0  - 1.d0/24.d0 * t**3
     &        - 1.d0/960.d0 * t**5       - 1.d0/20160.d0 * t**7 
     &        - 17.d0/5806080.d0 * t**9  - 31.d0/159667200.d0 * t**11 
     &        - 691.d0/49816166400.d0 * t**13

      endif

      if ( x .eq. 0.d0 ) lnsinapprox = 0.d0

      end

c ----------------------------------------------------------

      real*8 function inttlnsin( x )
      implicit NONE
c ----------------------------------------------------------
c 
c function which returns an approximate value of
c   \int_0^x dt t ln(sin(t/2))
c for 0 <= x <= 2 \pi
c 
c The relative accuracy 
c   \delta \int_0^x dt t ln(sin(t/2)) / \int_0^x dt t ln(sin(t/2))
c is better than 1 x 10^{-9} for 0 <= x < 2 \pi.
c 
c ----------------------------------------------------------
      real*8 tlnsindata(10, 2),  PI, x, x0, tmpfnc, xx, xx0, t
      Parameter ( PI = 3.141592653589793238d0 )

      tmpfnc( xx, xx0 ) = xx0 * log( sin( xx0 /2.d0 ) ) * ( xx - xx0 )  
     &     + ( xx0 / tan( xx0 /2.d0 ) /2.d0 + log( sin( xx0 / 2.d0 ) ) ) 
     &       * ( xx - xx0 )**2 /2.d0 
     &     + ( 1.d0/tan( xx0 /2.d0 ) - xx0/tan( xx0/2.d0)**2 /4.d0 
     &          - xx0 / 4.d0 ) * ( xx - xx0 )**3 /6.d0 
     &     + ( xx0/tan( xx0 /2.d0 )/4.d0 - 3.d0/tan( xx0/2.d0 )**2 /4.d0
     &         + xx0/tan( xx0/2.d0)**3 /4.d0 - 3.d0 / 4.d0 )
     &       * ( xx - xx0 )**4  /24.d0
     &     + ( -xx0/8.d0 + 1.d0 / tan( xx0/2.d0 )
     &         - xx0/ 2.d0 / tan( xx0/2.d0 ) **2
     &         + 1.d0 / tan( xx0/2.d0 ) **3 
     &         - 3.d0 * xx0 / tan( xx0/2.d0 ) **4/8.d0 )
     &       * ( xx - xx0 )**5  /120.d0
     &     + ( -5.d0 * ( 1.d0 + 2.d0 * cos( xx0/2.d0 ) **2 )
     &          / 8.d0 / sin( xx0/2.d0 ) **4
     &         + xx0 * cos( xx0/2.d0 ) * ( 2.d0 + cos( xx0/2.d0 ) **2 )
     &          / 4.d0 / sin( xx0/2.d0 ) **5 )
     &       * ( xx - xx0 )**6  /720.d0
 
      tlnsindata(1,1) = 1.2d0
      tlnsindata(1,2) = -0.74957027697528111d0

      tlnsindata(2,1) =  PI / 2.d0 
      tlnsindata(2,2) =-0.97918171095541506d0

      tlnsindata(3,1) = 1.75d0
      tlnsindata(3,2) =-1.0695176269999971d0

      tlnsindata(4,1) = 2.d0
      tlnsindata(4,2) =-1.1705580876018851d0

      tlnsindata(5,1) = 2.2d0
      tlnsindata(5,2) =-1.2303353255931651d0

      tlnsindata(6,1) = PI
      tlnsindata(6,2) =-1.316944651399270d0

      tlnsindata(7,1) = 4.d0
      tlnsindata(7,2) =-1.4186521368805918d0

      tlnsindata(8,1) = 4.25d0
      tlnsindata(8,2) =-1.5499027740341007d0

      tlnsindata(9,1) = 1.5d0 * PI
      tlnsindata(9,2) =-2.0650886115962104d0

      tlnsindata(10,1) = 2.d0 * PI
      tlnsindata(10,2) =-13.682176927713458d0

      if ( x.lt. 1.15d0 ) then

         inttlnsin = x **2 * log( x / 2.d0 ) / 2.d0 - x **2 / 4.d0 
     &        - x **4 / 96.d0 - x **6 / 17280.d0 
     &        - x **8 / 1451520.d0 - x **10 / 96768000.d0 
     &        - x **12 / 5748019200.d0 

      elseif ( x.lt. 1.3d0 ) then

         inttlnsin = tlnsindata( 1,2 ) + tmpfnc( x, tlnsindata(1,1) )

      elseif ( x.lt. 1.7d0 ) then

         t = x - PI / 2.d0

         inttlnsin = tlnsindata( 2,2 )
     &        - x **2 / 4.d0 * log( 2.d0 ) + PI **2 / 16.d0 * log( 2.d0)
     &        + PI / 8.d0 * t **2 
     &        - ( PI - 4.d0 ) / 24.d0 * t **3 
     &        + ( PI - 6.d0 ) / 96.d0 * t **4 
     &        - ( PI - 4.d0 ) / 240.d0 * t **5 
     &        + ( PI - 4.d0 ) / 576.d0 * t **6 
     &        - ( 4.d0 * PI - 15.d0 ) / 5040.d0 * t **7 
     &        + ( 61.d0 * PI - 224.d0 ) /161280.d0 * t **8
     &        - ( 17.d0 * PI - 61.d0 ) /90720.d0 * t **9 
     &        + ( 1385.d0 * PI - 4896.d0 ) /14515200.d0 * t **10

      elseif ( x.lt. 1.87d0 ) then

         inttlnsin = tlnsindata( 3,2 ) + tmpfnc( x, tlnsindata( 3,1 ) )

      elseif ( x.lt. 2.1d0 ) then

         inttlnsin = tlnsindata( 4,2 ) + tmpfnc( x, tlnsindata( 4,1 ) )

      elseif ( x.lt. 2.35d0 ) then

         inttlnsin = tlnsindata( 5,2 ) + tmpfnc( x, tlnsindata( 5,1 ) )

      elseif ( x.le. 3.9d0 ) then

         t = x - PI

         inttlnsin = tlnsindata( 6,2 ) 
     &        - PI / 24.d0 * t **3      - 1.d0 / 32.d0 * t **4 
     &        - PI / 960.d0 * t **5     - 1.d0 / 1152.d0 * t **6
     &        - PI / 20160.d0 * t **7   - 1.d0 / 23040.d0 * t **8
     &        - 17.d0 * PI / 5806080.d0 * t **9 
     &        - 17.d0 / 6451200.d0 * t **10 
     &        - 31.d0 * PI / 159667200.d0 * t **11
     &        - 31.d0 / 174182400.d0 * t **12 
     &        - 691.d0 * PI / 49816166400.d0 * t **13 
     &        - 691.d0 / 53648179200.d0 * t **14

      elseif ( x.le. 4.12d0 ) then

         inttlnsin = tlnsindata( 7,2 ) + tmpfnc( x, tlnsindata( 7,1 ) )

      elseif ( x.le. 4.37d0 ) then

         inttlnsin = tlnsindata( 8,2 ) + tmpfnc( x, tlnsindata( 8,1 ) )

      elseif ( x.le. 5.1d0 ) then

         t = x - 1.5d0 * PI

         inttlnsin = tlnsindata( 9,2 ) 
     &          - x**2 / 4.d0 * log( 2.d0 ) 
     &          + 9.d0 * PI **2 / 16.d0 * log( 2.d0 ) 
     &          - 3.d0 * PI / 8.d0 * t**2 
     &          - ( 3.d0 * PI + 4.d0 ) / 24.d0 * t**3 
     &          - ( PI + 2.d0 ) / 32.d0 * t**4 
     &          - ( 3.d0 * PI + 4.d0 ) / 240.d0 * t**5
     &          - ( 3.d0 * PI + 4.d0 ) / 576.d0 * t**6
     &          - ( 4.d0 * PI + 5.d0 ) /1680.d0 * t**7
     &          - (183.d0 *PI +224.d0)/161280.d0 * t**8
     &          - ( 51.d0 *PI + 61.d0)/90720.d0 * t**9
     &          - (1385.d0*PI +1632.d0)/4838400.d0 * t**10 
     &          - (5952.d0*PI +6925.d0)/39916800.d0 * t**11 
     &          - (151563.d0*PI+174592.d0) /1916006400.d0   * t**12 
     &          - (44224.d0 * PI + 50521.d0) /1037836800.d0 * t**13

      elseif ( x.le. 2.d0 * PI ) then

         t = x - 2.d0 * PI

         inttlnsin = tlnsindata( 10,2 )
     &        - ( 2.d0 * PI **2 - x **2/2.d0 ) * log( PI - x / 2.d0 ) 
     &        + 4.d0 * PI * ( PI - x / 2.d0 ) 
     &        - ( PI - x / 2.d0 ) **2       - PI / 36.d0 * t **3 
     &        - 1.d0 / 96.d0 * t **4        - PI / 7200.d0 * t **5 
     &        - 1.d0 / 17280.d0 * t **6     - PI / 635040.d0 * t **7 
     &        - 1.d0 / 1451520.d0 * t **8   - PI / 43545600.d0 * t **9 
     &        - 1.d0 / 96768000.d0 * t **10 - PI / 2634508800.d0 * t**11 
     &        - 1.d0 / 5748019200.d0 * t **12 

      endif

      if ( x .eq. 0.d0 ) inttlnsin = 0.d0

      end

c ----------------------------------------------------------

C
c
c Special functions  dli2, dli3 and ds12
c
      real*8 function dli2(x)
c
      implicit real*8(a-h,o-z)
      common/bern/bcli2(0:40),bcli3(0:40),bcs12(0:40),intb
cc      common/bern/intb,bcli2(0:40),bcli3(0:40),bcs12(0:40)
      parameter (z2=1.64493406684823d0)
      save
c
      if (intb.ne.999) call initbe

      if (x.eq.1.d0) then 
         dli2=z2
         goto 20
      endif
      if (dabs(x).le.0.5d0) then
         xx=x
         dli2=0.d0
         rm=1.d0
      else
         if(x.ge.0.d0) then
            xx=1.d0-x
            dli2=dlog(x)*dlog(1.d0-x)-z2
            rm=-1.d0
         else
            if (x.lt.-2.d0) then 
               xx=1.d0/x
               dli2=0.5d0*(dlog(-xx)**2)+z2
               rm=-1.d0
            else
               if (x.lt.-1.d0) then
                  xx=1.d0/(1.d0-x)
                  dlx=dlog(xx)
                  dli2=dlx*dlog(1.d0-xx)-0.5d0*dlx**2-z2
                  rm=1.d0
               else
                  xx=x/(x-1.d0)
                  dli2=0.5d0*(dlog(1.d0-xx))**2
                  rm=-1.d0
               endif
            endif
         endif
      endif
      u=-dlog(1.d0-xx)
      do 10 i=0,40
         if (bcli2(i).eq.0.d0) goto 10
         dli2=dli2+bcli2(i)*u**(i+1)
   10 continue
      dli2=dli2*rm
   20 continue
      return
      end


c      real*8 function dli3(x)

c      implicit real*8(a-h,o-z)
c      common/bern/bcli2(0:40),bcli3(0:40),bcs12(0:40),intb
c      parameter (z2=1.64493406684823d0)
c      parameter (z3=1.20205690315959d0)
c      save

c      external dli2,ds12

c      if (intb.ne.999) call initbe

c      if (x.eq.1.d0) then 
c         dli3=z3
c         goto 20
c      endif
c      if (dabs(x).le.0.5d0) then
c         xx=x
c         dli3=0.d0
c         rm=1.d0
c      else
c         if (x.gt.0.d0) then
c            xx=1.d0-x
c            ds=ds12(xx)
c            dl2=dli2(xx)
c            dlgx=dlog(x)
c            dlgxx=dlog(xx)
c            dli3=-ds-dlgx*dl2-0.5d0*dlgxx*dlgx**2+z2*dlgx+z3  
c            goto 20
c         else
c            if (x.lt.-2.d0) then
c               xx=1.d0/x
c               dlx=dlog(-xx)
c               dli3=dlx**3/6.d0+z2*dlx
c               rm=1.d0
c            else
c               if (x.lt.-1.d0) then
c                  xx=1.d0/(1.d0-x)
c                  ds=ds12(xx)
c                  dl2=dli2(xx)
c                  dlgx=dlog(xx)
c                  dlgx1=dlog(1.d0-xx)
c                  dli3=-ds-dlgx1*dl2-dlgx**3/6.d0-(z2-
c     .                  0.5d0*dlgx*dlgx1)*(dlgx-dlgx1)
c                  rm=-1.d0
c               else
c                  xx=x/(x-1.d0)    
c                  ds=ds12(xx)
c                  dl2=dli2(xx)
c                  dlgx1=dlog(1.d0-xx)                  
c                  dli3=-ds-dlgx1*dl2-1.d0/6.d0*dlgx1**3
c                  rm=-1.d0
c               endif
c            endif
c         endif
c      endif
c
c      u=-dlog(1.d0-xx)
c      do 10 i=0,40
c         if (bcli3(i).eq.0.d0) goto 10
c         dli3=dli3+bcli3(i)*u**(i+1)
c   10 continue
c      dli3=rm*dli3
c   20 continue
c      return
c      end
c
c
      real*8 function ds12(x)
c
      implicit real*8(a-h,o-z)
      common/bern/bcli2(0:40),bcli3(0:40),bcs12(0:40),intb
      parameter (z3=1.20205690315959d0)
      save
c
      external dli2,dli3
c
      if (intb.ne.999) call initbe

      if (x.eq.1.d0) then 
         ds12=z3
         goto 20
      endif
c
      if (dabs(x).le.0.5d0) then
         xx=x
         rm=1.d0
         ds12=0.d0
      else
         if (x.gt.0.d0) then
            xx=1.d0-x
            dl3=dli3(xx)
            dl2=dli2(xx)
            dlgx=dlog(x)
            dlgxx=dlog(xx)
            ds12=-dl3+dlgxx*dl2+0.5d0*dlgx*dlgxx**2+z3  
            goto 20
         else
            if (x.lt.-2.d0) then
               xx=1.d0/x
               dl3=dli3(xx)
               dl2=dli2(xx)
               dlgx=dlog(-xx)
               ds12=-dl3+1.d0/6.d0*dlgx**3+dlgx*dl2-z3
               rm=-1.d0
            else
               if (x.lt.-1.d0) then
                  xx=1.d0/(1.d0-x)
                  dl3=dli3(xx)
                  dl2=dli2(xx)
                  dlgx=dlog(xx)
                  dlgx1=dlog(1.d0-xx)
                  ds12=-dl3+dlgx*dl2+0.5d0*dlgx**2*dlgx1-
     .                 dlgx**3/6.d0+z3
                  goto 20
               else
                  xx=x/(x-1.d0)
                  ds12=-1.d0/6.d0*(dlog(1.d0-xx))**3
                  rm=1.d0
               endif
            endif
         endif
      endif
c
      u=-dlog(1.d0-xx)
      do 10 i=0,40
         if (bcs12(i).eq.0.d0) goto 10
         ds12=ds12+bcs12(i)*u**(i+2)
   10 continue
      ds12=rm*ds12
   20 continue
      return
      end
c
c
c Needed for Bernoulli numbers
c
      subroutine initbe
c
      implicit real*8(a-h,o-z)
      dimension b(0:40),fac(0:42)
      common/bern/bcli2(0:40),bcli3(0:40),bcs12(0:40),intb
      common/bern2/bcli4(0:40),bcs13(0:40)
c
      data  b/1.d0, -5.d-1, 1.666666667d-1, 0.d0, -3.333333333d-2,
     .        0.d0, 2.380952381d-2, 0.d0, -3.333333333d-2, 0.d0,
     .        7.575757576d-2, 0.d0, -2.531135531d-1, 0.d0,
     .        1.166666667d0,
     .        0.d0, -7.092156863d0, 0.d0, 5.497117794d1, 0.d0,
     .        -5.291242424d2, 0.d0, 6.192123188d3, 0.d0,
     .        -8.656025311d4,
     .        0.d0, 1.425517167d6, 0.d0, -2.729823107d7, 0.d0,
     .        6.015808739d8, 0.d0, -1.511631577d10, 0.d0, 
     .        4.296146431d11,
     .        0.d0, -1.371165521d13, 0.d0, 4.883323190d14, 0.d0,
     .        -1.929657934d16/
      save
c
      fac(0)=1.d0
      bcli2(0)=b(0)
      bcli3(0)=b(0)
      bcs12(0)=0.25d0*b(0)
      bcs13(0)=b(0)/18.d0
      bcli4(0)=b(0)
c
      do 10 i=1,42
         fac(i)=fac(i-1)*real(i)
   10 continue
c
      do 20 j=1,40
         bcli2(j)=b(j)/fac(j+1)
         bcs12(j)=0.5d0*real(j+1)*b(j)/fac(j+2)
         bcs13(j)=b(j)/fac(j)/6.d0/real(j+3)
         bcli3(j)=0.d0
         bcli4(j)=0.d0
         do 15 k=0,j
            bcli3(j)=bcli3(j)+b(k)*b(j-k)/fac(k+1)/fac(j-k)
            do 14 l=0,k
               bcli4(j)=bcli4(j)+b(l)*b(k-l)*b(j-k)/fac(k-l)/fac(j-k)
     .                  /fac(l+1)/real(k+1)
   14       continue
   15    continue
         bcli3(j)=bcli3(j)/real(j+1)
         bcli4(j)=bcli4(j)/real(j+1)
   20 continue
c
      intb=999
      return
      end

c
ctt
c Routine for R_{lep}
ctt
      real*8 function R_lepton( s )
      implicit NONE
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c Calculate R_{lep}(s)
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c input ----------------------------------------------------
      real*8 s
c tmp vars -------------------------------------------------
      real*8 m, qsq, R_e, R_mu, R_tau, sqrts, beta 
c const ----------------------------------------------------
      real*8 ALPHA_0, MMUON, MTAU, PI
      Parameter( ALPHA_0 = 1.d0 / 137.035 999 11d0 ) ! PDG06
      Parameter( MMUON = 105.658369d-3, MTAU = 1.77699d0 ) ! PDG06
      Parameter( PI = 3.141592653589793238d0 )
c ==========================================================

      beta( m, qsq ) = sqrt( 1.d0 - 4.d0 * m **2 / qsq )

      sqrts = sqrt( s )

      R_e = 1.d0 + 3.d0/4.d0 * ALPHA_0 / PI

      R_mu = 0.d0
      R_tau = 0.d0

      if ( ( 2.d0 * MMUON ) .lt. sqrts ) 
     &   R_mu = beta( MMUON, s ) * ( 3.d0 - beta( MMUON, s )**2 ) / 2.d0
     &        + 3.d0/4.d0 * ALPHA_0/PI 
     &          * ( 1.d0 + 12.d0 * MMUON**2 / s 
     &              + ( 10.d0 - 24.d0 * log( MMUON**2 / s ) ) 
     &                * MMUON**4 / s **2 )

      if ( ( 2.d0 * MTAU ) .lt. sqrts )
     &   R_tau = beta( MTAU, s ) * ( 3.d0 - beta( MTAU, s )**2 ) / 2.d0
     &        + 3.d0/4.d0 * ALPHA_0/PI 
     &          * ( 1.d0 + 12.d0 * MTAU**2 / s 
     &              + ( 10.d0 - 24.d0 * log( MTAU**2 / s ) ) 
     &                * MTAU**4 / s **2 )

      R_lepton = R_e + R_mu + R_tau

      return
      end
c
c
ctt
c Routine for \Delta\alpha_{top}
ctt
      real*8 function alf_top( s )
      implicit NONE
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c Calculates Top Contribution \Delta \alpha_top(s) at LO and NLO
c
c   Pi0 := ( Pi(qsq) - Pi(0) )_LO ,                   
c   Pi1 := ( Pi(qsq) - Pi(0) )_NLO ,                  
c
c (Taking real part of Pi is assumed.)
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c input ----------------------------------------------------
      real*8 s
c const ----------------------------------------------------
      real*8 Mtop, ALPHA, ALPHAS, PI, Nc, Qt
      Parameter( Mtop = 171.2d0 )               ! PDG08
      Parameter( ALPHA  = 1.d0/137.03599976d0 ) ! PDG03
      Parameter( ALPHAS = 0.1176d0 )            ! PDG08
      Parameter( PI = 3.141592653589793238d0, Nc = 3.d0, Qt = 2.d0/3.d0)
c function, tmp var. ---------------------------------------
      real*8 Pi0t, Pi1t, ss, alf_topLO, alf_topNLO
c begin ====================================================
c LO -------------------------------------------------------

      Pi0t( ss ) = Nc * Qt ** 2 * (
     &    4.d0/  15.d0 *  ss / Mtop **2 
     &  + 1.d0/  35.d0 * ( ss / Mtop **2 ) **2
     &  + 1.d0/ 945.d0 * ( ss / Mtop **2 ) **3 
     &  + 1.d0/5544.d0 * ( ss / Mtop **2 ) **4 
     &  + 1.d0/30030.d0 * ( ss / Mtop **2 ) **5 
     &  + 1.d0/154440.d0 * ( ss/ Mtop **2 ) **6 
     &  + 1.d0/765765.d0 * ( ss/ Mtop **2 ) **7 
     &   ) / ( 16.d0 * PI **2 )

c NLO ------------------------------------------------------

      Pi1t( ss ) =  
     & (        82.d0/81.d0 * ss / Mtop **2  
     &     +   449.d0/2700.d0 * ( ss / Mtop **2 ) **2
     &     + 62479.d0/1984500.d0 * ( ss / Mtop **2 ) **3 
     &  ) / ( 16.d0 * PI **2 )

c calc contributions to \Delta \alpha ----------------------

      alf_topLO = - 4.d0 * PI * ALPHA * Pi0t( s ) 

      alf_topNLO = - 4.d0 * PI * ALPHA * ( Nc**2 - 1.d0 ) / 2.d0
     &             * Qt**2 * ( ALPHAS / PI ) * Pi1t( s ) 

      alf_top = alf_topLO + alf_topNLO

      return
      end
